@@ -3,13 +3,11 @@
 /***************************************************************
 *  Inline-Relational-Record Editing
 *
-* $Id: jsfunc.inline.js 5302 2009-04-09 07:55:25Z ohader $
-*
 *
 *
 *  Copyright notice
 *
-*  (c) 2006-2008 Oliver Hader <oh@inpublica.de>
+*  (c) 2006-2011 Oliver Hader <oh@inpublica.de>
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
@@ -30,11 +28,13 @@
 ***************************************************************/
 
 var inline = {
+	structureSeparator: '-',
 	prependFormFieldNames: 'data',
 	noTitleString: '[No title]',
 	lockedAjaxMethod: {},
 	sourcesLoaded: {},
 	data: {},
+	isLoading: false,
 
 	addToDataArray: function(object) {
 		$H(object).each(function(pair) {
@@ -44,9 +44,22 @@ var inline = {
 	setPrependFormFieldNames: function(value) {	this.prependFormFieldNames = value; },
 	setNoTitleString: function(value) { this.noTitleString = value; },
 
-	expandCollapseRecord: function(objectId, expandSingle) {
-		var currentUid = this.parseFormElementName('none', objectId, 1);
-		var objectPrefix = this.parseFormElementName('full', objectId, 0, 1);
+	expandCollapseRecord: function(objectId, expandSingle, returnURL) {
+		var currentUid = this.parseObjectId('none', objectId, 1);
+		var objectPrefix = this.parseObjectId('full', objectId, 0, 1);
+
+			// if content is not loaded yet, get it now from server
+		if(($(objectId+'_fields') && $("irre-loading-indicator"+objectId)) || inline.isLoading) {
+			return false;
+		} else if ($(objectId+'_fields') && $(objectId+'_fields').innerHTML.substr(0,16) == '<!--notloaded-->') {
+			inline.isLoading = true;
+				// add loading-indicator
+			if ($(objectId + '_icon')) {
+				$(objectId + '_icon').hide();
+				$(objectId + '_iconcontainer').addClassName('loading-indicator');
+			}
+			return this.getRecordDetails(objectId, returnURL);
+		}
 
 		var currentState = '';
 		var collapse = new Array();
@@ -74,7 +87,7 @@ var inline = {
 
 	collapseAllRecords: function(objectId, objectPrefix, callingUid) {
 			// get the form field, where all records are stored
-		var objectName = this.prependFormFieldNames+this.parseFormElementName('parts', objectId, 3, 2);
+		var objectName = this.prependFormFieldNames+this.parseObjectId('parts', objectId, 3, 2, true);
 		var formObj = document.getElementsByName(objectName);
 		var collapse = [];
 
@@ -84,7 +97,7 @@ var inline = {
 
 			var records = formObj[0].value.split(',');
 			for (var i=0; i<records.length; i++) {
-				recObjectId = objectPrefix+'['+records[i]+']';
+				recObjectId = objectPrefix + this.structureSeparator + records[i];
 				if (records[i] != callingUid && Element.visible(recObjectId+'_fields')) {
 					Element.hide(recObjectId+'_fields');
 					if (this.isNewRecord(recObjectId)) this.updateExpandedCollapsedStateLocally(recObjectId, 0);
@@ -97,17 +110,22 @@ var inline = {
 	},
 
 	updateExpandedCollapsedStateLocally: function(objectId, value) {
-		var ucName = 'uc[inlineView]'+this.parseFormElementName('parts', objectId, 3, 2);
+		var ucName = 'uc[inlineView]'+this.parseObjectId('parts', objectId, 3, 2, true);
 		var ucFormObj = document.getElementsByName(ucName);
 		if (ucFormObj.length) {
 			ucFormObj[0].value = value;
 		}
 	},
 
+	getRecordDetails: function(objectId, returnURL) {
+		inline.makeAjaxCall('getRecordDetails', [inline.getNumberOfRTE(), objectId, returnURL], true);
+		return false;
+	},
+
 	createNewRecord: function(objectId, recordUid) {
 		if (this.isBelowMax(objectId)) {
 			if (recordUid) {
-				objectId += '['+recordUid+']';
+				objectId += this.structureSeparator + recordUid;
 			}
 			this.makeAjaxCall('createNewRecord', [this.getNumberOfRTE(), objectId], true);
 		} else {
@@ -128,7 +146,7 @@ var inline = {
 	makeAjaxCall: function(method, params, lock) {
 		var max, url='', urlParams='', options={};
 		if (method && params && params.length && this.lockAjaxMethod(method, lock)) {
-			url = 'ajax.php';
+			url = TBE_EDITOR.getBackendPath() + 'ajax.php';
 			urlParams = '&ajaxID=t3lib_TCEforms_inline::'+method;
 			for (var i=0, max=params.length; i<max; i++) {
 				urlParams += '&ajax['+i+']='+params[i];
@@ -136,8 +154,8 @@ var inline = {
 			options = {
 				method:		'post',
 				parameters:	urlParams,
-				onSuccess:	function(xhr) { inline.processAjaxResponse(method, xhr); },
-				onFailure:	function(xhr) { inline.showAjaxFailure(method, xhr); }
+				onSuccess:	function(xhr) { inline.isLoading = false; inline.processAjaxResponse(method, xhr); },
+				onFailure:	function(xhr) { inline.isLoading = false; inline.showAjaxFailure(method, xhr); }
 			};
 
 			new Ajax.Request(url, options);
@@ -204,6 +222,7 @@ var inline = {
 			if (json.scriptCall && json.scriptCall.length) {
 				$A(json.scriptCall).each(function(value) { eval(value); });
 			}
+			TYPO3.TCEFORMS.convertDateFieldsToDatePicker();
 		}
 	},
 
@@ -256,7 +275,7 @@ var inline = {
 	importElement: function(objectId, table, uid, type) {
 		window.setTimeout(
 			function() {
-				inline.makeAjaxCall('createNewRecord', [this.getNumberOfRTE(), objectId, uid], true);
+				inline.makeAjaxCall('createNewRecord', [inline.getNumberOfRTE(), objectId, uid], true);
 			},
 			10
 		);
@@ -297,37 +316,71 @@ var inline = {
 		// alert(objectId+'/'+table+'/'+uid+'/'+recordUid);
 		this.setUnique(objectId, recordUid, uid);
 	},
-
+		// Remove all select items already used
+		// from a newly retrieved/expanded record
+	removeUsed: function(objectId, recordUid) {
+		if (this.data.unique && this.data.unique[objectId]) {
+			var unique = this.data.unique[objectId];
+			if (unique.type == 'select') {
+				var formName = this.prependFormFieldNames+this.parseObjectId('parts', objectId, 3, 1, true);
+				var formObj = document.getElementsByName(formName);
+				var recordObj = document.getElementsByName(this.prependFormFieldNames+'['+unique.table+']['+recordUid+']['+unique.field+']');
+				var values = $H(unique.used).values();
+				if (recordObj.length) {
+					var selectedValue = recordObj[0].options[recordObj[0].selectedIndex].value;
+					for (var i=0; i<values.length; i++) {
+						if (values[i] != selectedValue) {
+							this.removeSelectOption(recordObj[0], values[i]);
+						}
+					}
+				}
+			}
+		}
+	},
 		// this function is applied to a newly inserted record by AJAX
 		// it removes the used select items, that should be unique
 	setUnique: function(objectId, recordUid, selectedValue) {
 		if (this.data.unique && this.data.unique[objectId]) {
 			var unique = this.data.unique[objectId];
-
 			if (unique.type == 'select') {
-					// remove used items from each select-field of the child records
 				if (!(unique.selector && unique.max == -1)) {
-					var elName = this.parseFormElementName('full', objectId, 1)+'['+recordUid+']['+unique.field+']';
-					var formName = this.prependFormFieldNames+this.parseFormElementName('parts', objectId, 3, 1);
-
-					var fieldObj = document.getElementsByName(elName);
+					var formName = this.prependFormFieldNames+this.parseObjectId('parts', objectId, 3, 1, true);
+					var formObj = document.getElementsByName(formName);
+					var recordObj = document.getElementsByName(this.prependFormFieldNames+'['+unique.table+']['+recordUid+']['+unique.field+']');
 					var values = $H(unique.used).values();
-
-					if (fieldObj.length) {
+					var selector = $(objectId+'_selector');
+					if (selector.length) {
 							// remove all items from the new select-item which are already used in other children
-						for (var i=0; i<values.length; i++) this.removeSelectOption(fieldObj[0], values[i]);
-							// set the selected item automatically to the first of the remaining items if no selector is used
-						if (!unique.selector) {
-							selectedValue = fieldObj[0].options[0].value;
-							fieldObj[0].options[0].selected = true;
-							this.updateUnique(fieldObj[0], objectId, formName, recordUid);
-							this.handleChangedField(fieldObj[0], objectId+'['+recordUid+']');
+						if (recordObj.length) {
+							for (var i=0; i<values.length; i++) {
+								this.removeSelectOption(recordObj[0], values[i]);
+							}
+								// set the selected item automatically to the first of the remaining items if no selector is used
+							if (!unique.selector) {
+								selectedValue = recordObj[0].options[0].value;
+								recordObj[0].options[0].selected = true;
+								this.updateUnique(recordObj[0], objectId, formName, recordUid);
+								this.handleChangedField(recordObj[0], objectId+'['+recordUid+']');
+							}
+						}
+						for (var i=0; i<values.length; i++) {
+							this.removeSelectOption(selector, values[i]);
 						}
 						if (typeof this.data.unique[objectId].used.length != 'undefined') {
 							this.data.unique[objectId].used = {};
 						}
 						this.data.unique[objectId].used[recordUid] = selectedValue;
 					}
+						// remove the newly used item from each select-field of the child records
+					if (formObj.length && selectedValue) {
+						var records = formObj[0].value.split(',');
+						for (var i=0; i<records.length; i++) {
+							recordObj = document.getElementsByName(this.prependFormFieldNames+'['+unique.table+']['+records[i]+']['+unique.field+']');
+							if (recordObj.length && records[i] != recordUid) {
+								this.removeSelectOption(recordObj[0], selectedValue);
+							}
+						}
+					}
 				}
 			} else if (unique.type == 'groupdb') {
 					// add the new record to the used items:
@@ -351,6 +404,30 @@ var inline = {
 				new Insertion.After(insertObject, htmlData);
 		}
 	},
+	domAddRecordDetails: function(objectId, objectPrefix, expandSingle, htmlData) {
+		var objectDiv = $(objectId + '_fields');
+		if (!objectDiv || objectDiv.innerHTML.substr(0,16) != '<!--notloaded-->')
+			return;
+
+		var elName = this.parseObjectId('full', objectId, 2, 0, true);
+
+		var formObj = document.getElementsByName(elName+'[hidden]_0')[0];
+		var tempHiddenValue = formObj.checked;
+		formObj.remove();
+		document.getElementsByName(elName+'[hidden]')[0].remove();
+
+		objectDiv.update(htmlData);
+		document.getElementsByName(elName+'[hidden]')[0].value = tempHiddenValue ? 1 : 0;
+		document.getElementsByName(elName+'[hidden]_0')[0].checked = tempHiddenValue;
+
+			// remove loading-indicator
+		if ($(objectId + '_icon')) {
+			$(objectId + '_iconcontainer').removeClassName('loading-indicator');
+			$(objectId + '_icon').show();
+		}
+			// now that the content is loaded, set the expandState
+		this.expandCollapseRecord(objectId, expandSingle);
+	},
 
 		// Get script and link elements from head tag:
 	getDomHeadChildren: function(head) {
@@ -404,13 +481,13 @@ var inline = {
 	},
 
 	changeSorting: function(objectId, direction) {
-		var objectName = this.prependFormFieldNames+this.parseFormElementName('parts', objectId, 3, 2);
-		var objectPrefix = this.parseFormElementName('full', objectId, 0, 1);
+		var objectName = this.prependFormFieldNames+this.parseObjectId('parts', objectId, 3, 2, true);
+		var objectPrefix = this.parseObjectId('full', objectId, 0, 1);
 		var formObj = document.getElementsByName(objectName);
 
 		if (formObj.length) {
 				// the uid of the calling object (last part in objectId)
-			var callingUid = this.parseFormElementName('none', objectId, 1);
+			var callingUid = this.parseObjectId('none', objectId, 1);
 			var records = formObj[0].value.split(',');
 			var current = records.indexOf(callingUid);
 			var changed = false;
@@ -432,8 +509,8 @@ var inline = {
 				formObj[0].value = records.join(',');
 				var cAdj = direction > 0 ? 1 : 0; // adjustment
 				$(objectId+'_div').parentNode.insertBefore(
-					$(objectPrefix+'['+records[current-cAdj]+']_div'),
-					$(objectPrefix+'['+records[current+1-cAdj]+']_div')
+					$(objectPrefix + this.structureSeparator + records[current-cAdj] + '_div'),
+					$(objectPrefix + this.structureSeparator + records[current+1-cAdj] + '_div')
 				);
 				this.redrawSortingButtons(objectPrefix, records);
 			}
@@ -444,7 +521,7 @@ var inline = {
 
 	dragAndDropSorting: function(element) {
 		var objectId = element.getAttribute('id').replace(/_records$/, '');
-		var objectName = inline.prependFormFieldNames+inline.parseFormElementName('parts', objectId, 3);
+		var objectName = inline.prependFormFieldNames+inline.parseObjectId('parts', objectId, 3, 0, true);
 		var formObj = document.getElementsByName(objectName);
 
 		if (formObj.length) {
@@ -464,7 +541,7 @@ var inline = {
 
 			if (inline.data.config && inline.data.config[objectId]) {
 				var table = inline.data.config[objectId].table;
-				inline.redrawSortingButtons(objectId+'['+table+']', checked);
+				inline.redrawSortingButtons(objectId + inline.structureSeparator + table, checked);
 			}
 		}
 	},
@@ -474,7 +551,7 @@ var inline = {
 		Sortable.create(
 			objectId,
 			{
-				format: /^[^_\-](?:[A-Za-z0-9\[\]\-\_]*)\[(.*)\]_div$/,
+				format: /^[^_\-](?:[A-Za-z0-9\-\_]*)-(.*)_div$/,
 				onUpdate: inline.dragAndDropSorting,
 				tag: 'div',
 				handle: 'sortableHandle',
@@ -496,7 +573,7 @@ var inline = {
 			// if no records were passed, fetch them from form field
 		if (typeof records == 'undefined') {
 			records = new Array();
-			var objectName = this.prependFormFieldNames+this.parseFormElementName('parts', objectPrefix, 3, 1);
+			var objectName = this.prependFormFieldNames+this.parseObjectId('parts', objectPrefix, 3, 1, true);
 			var formObj = document.getElementsByName(objectName);
 			if (formObj.length) records = formObj[0].value.split(',');
 		}
@@ -504,7 +581,7 @@ var inline = {
 		for (i=0; i<records.length; i++) {
 			if (!records[i].length) continue;
 
-			headerObj = $(objectPrefix+'['+records[i]+']_header');
+			headerObj = $(objectPrefix + this.structureSeparator + records[i] + '_header');
 			sortingObj[0] = Element.select(headerObj, '.sortingUp');
 			sortingObj[1] = Element.select(headerObj, '.sortingDown');
 
@@ -519,7 +596,7 @@ var inline = {
 
 	memorizeAddRecord: function(objectPrefix, newUid, afterUid, selectedValue) {
 		if (this.isBelowMax(objectPrefix)) {
-			var objectName = this.prependFormFieldNames+this.parseFormElementName('parts', objectPrefix, 3, 1);
+			var objectName = this.prependFormFieldNames+this.parseObjectId('parts', objectPrefix, 3, 1, true);
 			var formObj = document.getElementsByName(objectName);
 
 			if (formObj.length) {
@@ -549,7 +626,7 @@ var inline = {
 
 			// if we reached the maximum off possible records after this action, hide the new buttons
 		if (!this.isBelowMax(objectPrefix)) {
-			var objectParent = this.parseFormElementName('full', objectPrefix, 0 , 1);
+			var objectParent = this.parseObjectId('full', objectPrefix, 0 , 1);
 			var md5 = this.getObjectMD5(objectParent);
 			this.hideElementsWithClassName('.inlineNewButton'+(md5 ? '.'+md5 : ''), objectParent);
 		}
@@ -618,7 +695,7 @@ var inline = {
 					}
 
 					if (!(unique.selector && unique.max == -1)) {
-						var formName = this.prependFormFieldNames+this.parseFormElementName('parts', objectPrefix, 3, 1);
+						var formName = this.prependFormFieldNames+this.parseObjectId('parts', objectPrefix, 3, 1, true);
 						var formObj = document.getElementsByName(formName);
 						if (formObj.length) {
 							var records = formObj[0].value.split(',');
@@ -639,16 +716,22 @@ var inline = {
 	},
 
 	enableDisableRecord: function(objectId) {
-		var elName = this.parseFormElementName('full', objectId, 2);
-		var imageObj = $(objectId+'_disabled');
-		var valueObj = document.getElementsByName(elName+'[hidden]');
-		var formObj = document.getElementsByName(elName+'[hidden]_0');
-		var imagePath = '';
+		var elName = this.parseObjectId('full', objectId, 2, 0, true);
+		var currentUid = this.parseObjectId('none', objectId, 1);
+		var objectPrefix = this.parseObjectId('full', objectId, 0, 1);
+		var formObj = document.getElementsByName(elName+'[hidden]_0')[0];
 
-		if (valueObj && formObj) {
-			formObj[0].click();
-			imagePath = this.parsePath(imageObj.src);
-			imageObj.src = imagePath+(valueObj[0].value > 0 ? 'button_unhide.gif' : 'button_hide.gif');
+		formObj.click();
+
+		document.getElementsByName(elName+'[hidden]')[0].value = formObj.checked?1:0;
+		TBE_EDITOR.fieldChanged(objectPrefix,'1','hidden',elName+'[hidden]');
+
+		if($(objectId+'_disabled').hasClassName('t3-icon-edit-hide')) {
+			$(objectId+'_disabled').removeClassName ('t3-icon-edit-hide');
+			$(objectId+'_disabled').addClassName('t3-icon-edit-unhide');
+		} else {
+			$(objectId+'_disabled').removeClassName ('t3-icon-edit-unhide');
+			$(objectId+'_disabled').addClassName('t3-icon-edit-hide');
 		}
 
 		return false;
@@ -656,10 +739,10 @@ var inline = {
 
 	deleteRecord: function(objectId, options) {
 		var i, j, inlineRecords, records, childObjectId, childTable;
-		var objectPrefix = this.parseFormElementName('full', objectId, 0 , 1);
-		var elName = this.parseFormElementName('full', objectId, 2);
-		var shortName = this.parseFormElementName('parts', objectId, 2);
-		var recordUid = this.parseFormElementName('none', objectId, 1);
+		var objectPrefix = this.parseObjectId('full', objectId, 0 , 1);
+		var elName = this.parseObjectId('full', objectId, 2, 0, true);
+		var shortName = this.parseObjectId('parts', objectId, 2, 0, true);
+		var recordUid = this.parseObjectId('none', objectId, 1);
 		var beforeDeleteIsBelowMax = this.isBelowMax(objectPrefix);
 
 			// revert the unique settings if available
@@ -684,6 +767,12 @@ var inline = {
 			TBE_EDITOR.removeElementArray(removeStack);
 		}
 
+			// Mark this container as deleted
+		var deletedRecordContainer = $(objectId + '_div');
+		if (deletedRecordContainer) {
+			deletedRecordContainer.addClassName('inlineIsDeletedRecord');
+		}
+
 			// If the record is new and was never saved before, just remove it from DOM:
 		if (this.isNewRecord(objectId) || options && options.forceDirectRemoval) {
 			this.fadeAndRemove(objectId+'_div');
@@ -694,18 +783,18 @@ var inline = {
 		}
 
 		var recordCount = this.memorizeRemoveRecord(
-			this.prependFormFieldNames+this.parseFormElementName('parts', objectId, 3, 2),
+			this.prependFormFieldNames+this.parseObjectId('parts', objectId, 3, 2, true),
 			recordUid
 		);
 
 		if (recordCount <= 1) {
-			this.destroyDragAndDropSorting(this.parseFormElementName('full', objectId, 0 , 2)+'_records');
+			this.destroyDragAndDropSorting(this.parseObjectId('full', objectId, 0 , 2)+'_records');
 		}
 		this.redrawSortingButtons(objectPrefix);
 
 			// if the NEW-button was hidden and now we can add again new children, show the button
 		if (!beforeDeleteIsBelowMax && this.isBelowMax(objectPrefix)) {
-			var objectParent = this.parseFormElementName('full', objectPrefix, 0 , 1);
+			var objectParent = this.parseObjectId('full', objectPrefix, 0 , 1);
 			var md5 = this.getObjectMD5(objectParent);
 			this.showElementsWithClassName('.inlineNewButton'+(md5 ? '.'+md5 : ''), objectParent);
 		}
@@ -726,16 +815,13 @@ var inline = {
 		return path;
 	},
 
-	parseFormElementName: function(wrap, objectId, rightCount, skipRight) {
-			// remove left and right side "data[...|...]" -> '...|...'
-		objectId = objectId.substr(0, objectId.lastIndexOf(']')).substr(objectId.indexOf('[')+1);
+	parseFormElementName: function(wrap, formElementName, rightCount, skipRight) {
+		var idParts = this.splitFormElementName(formElementName);
 
 		if (!wrap) wrap = 'full';
 		if (!skipRight) skipRight = 0;
 
-		var elReturn;
 		var elParts = new Array();
-		var idParts = objectId.split('][');
 		for (var i=0; i<skipRight; i++) idParts.pop();
 
 		if (rightCount > 0) {
@@ -745,12 +831,74 @@ var inline = {
 			elParts = idParts;
 		}
 
+		var elReturn = this.constructFormElementName(wrap, elParts);
+
+		return elReturn;
+	},
+
+	splitFormElementName: function(formElementName) {
+		// remove left and right side "data[...|...]" -> '...|...'
+		formElementName = formElementName.substr(0, formElementName.lastIndexOf(']')).substr(formElementName.indexOf('[')+1);
+		var parts = objectId.split('][');
+
+		return parts;
+	},
+
+	splitObjectId: function(objectId) {
+		objectId = objectId.substr(objectId.indexOf(this.structureSeparator)+1);
+		var parts = objectId.split(this.structureSeparator);
+
+		return parts;
+	},
+
+	constructFormElementName: function(wrap, parts) {
+		var elReturn;
+
 		if (wrap == 'full') {
-			elReturn = this.prependFormFieldNames+'['+elParts.join('][')+']';
+			elReturn = this.prependFormFieldNames+'['+parts.join('][')+']';
 		} else if (wrap == 'parts') {
-			elReturn = '['+elParts.join('][')+']';
+			elReturn = '['+parts.join('][')+']';
 		} else if (wrap == 'none') {
-			elReturn = elParts.length > 1 ? elParts : elParts.join('');
+			elReturn = parts.length > 1 ? parts : parts.join('');
+		}
+
+		return elReturn;
+	},
+
+	constructObjectId: function(wrap, parts) {
+		var elReturn;
+
+		if (wrap == 'full') {
+			elReturn = this.prependFormFieldNames+this.structureSeparator+parts.join(this.structureSeparator);
+		} else if (wrap == 'parts') {
+			elReturn = this.structureSeparator+parts.join(this.structureSeparator);
+		} else if (wrap == 'none') {
+			elReturn = parts.length > 1 ? parts : parts.join('');
+		}
+
+		return elReturn;
+	},
+
+	parseObjectId: function(wrap, objectId, rightCount, skipRight, returnAsFormElementName) {
+		var idParts = this.splitObjectId(objectId);
+
+		if (!wrap) wrap = 'full';
+		if (!skipRight) skipRight = 0;
+
+		var elParts = new Array();
+		for (var i=0; i<skipRight; i++) idParts.pop();
+
+		if (rightCount > 0) {
+			for (var i=0; i<rightCount; i++) elParts.unshift(idParts.pop());
+		} else {
+			for (var i=0; i<-rightCount; i++) idParts.shift();
+			elParts = idParts;
+		}
+
+		if (returnAsFormElementName) {
+			var elReturn = this.constructFormElementName(wrap, elParts);
+		} else {
+			var elReturn = this.constructObjectId(wrap, elParts);
 		}
 
 		return elReturn;
@@ -786,7 +934,7 @@ var inline = {
 
 	isBelowMax: function(objectPrefix) {
 		var isBelowMax = true;
-		var objectName = this.prependFormFieldNames+this.parseFormElementName('parts', objectPrefix, 3, 1);
+		var objectName = this.prependFormFieldNames+this.parseObjectId('parts', objectPrefix, 3, 1, true);
 		var formObj = document.getElementsByName(objectName);
 
 		if (this.data.config && this.data.config[objectPrefix] && formObj.length) {
@@ -841,7 +989,7 @@ var inline = {
 
 	setVisibilityOfElementsWithClassName: function(action, selector, parentElement) {
 		var domObjects = Selector.findChildElements($(parentElement), [selector]);
-		if (action == 'hide') { 
+		if (action == 'hide') {
 			$A(domObjects).each(function(domObject) { new Effect.Fade(domObject); });
 		} else if (action == 'show') {
 			$A(domObjects).each(function(domObject) { new Effect.Appear(domObject); });
@@ -908,4 +1056,4 @@ Object.extend(Array.prototype, {
 	}
 });
 
-/*]]>*/
\ No newline at end of file
+/*]]>*/
