@@ -2,7 +2,7 @@
 /***************************************************************
 *  Copyright notice
 *
-*  (c) 1999-2009 Kasper Skaarhoj (kasperYYYY@typo3.com)
+*  (c) 1999-2011 Kasper Skårhøj (kasperYYYY@typo3.com)
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
@@ -27,39 +27,16 @@
 /**
  * Generates a thumbnail and returns an image stream, either GIF/PNG or JPG
  *
- * $Id: thumbs.php 6723 2010-01-05 12:25:20Z benni $
- * Revised for TYPO3 3.6 July/2003 by Kasper Skaarhoj
- *
- * @author		Kasper Skaarhoj	<kasperYYYY@typo3.com>
- */
-/**
- * [CLASS/FUNCTION INDEX of SCRIPT]
- *
- *
- *
- *  113: class SC_t3lib_thumbs
- *  134:     function init()
- *  164:     function main()
- *
- *              SECTION: OTHER FUNCTIONS:
- *  267:     function errorGif($l1,$l2,$l3)
- *  319:     function fontGif($font)
- *  366:     function wrapFileName($inputName)
- *
- * TOTAL FUNCTIONS: 5
- * (This index is automatically created/updated by the extension "extdeveval")
+ * Revised for TYPO3 3.6 July/2003 by Kasper Skårhøj
  *
+ * @author		Kasper Skårhøj	<kasperYYYY@typo3.com>
  */
 
 
 // *******************************
 // Set error reporting
 // *******************************
-if (defined('E_DEPRECATED')) {
-	error_reporting(E_ALL ^ E_NOTICE ^ E_DEPRECATED);
-} else {
-	error_reporting(E_ALL ^ E_NOTICE);
-}
+error_reporting(E_ALL ^ E_NOTICE ^ E_DEPRECATED);
 
 
 
@@ -68,7 +45,15 @@ if (defined('E_DEPRECATED')) {
 // ******************
 define('TYPO3_OS', stristr(PHP_OS,'win')&&!stristr(PHP_OS,'darwin')?'WIN':'');
 define('TYPO3_MODE','BE');
-if(!defined('PATH_thisScript')) define('PATH_thisScript',str_replace('//','/', str_replace('\\','/', (php_sapi_name()=='cgi'||php_sapi_name()=='isapi' ||php_sapi_name()=='cgi-fcgi')&&($_SERVER['ORIG_PATH_TRANSLATED']?$_SERVER['ORIG_PATH_TRANSLATED']:$_SERVER['PATH_TRANSLATED'])? ($_SERVER['ORIG_PATH_TRANSLATED']?$_SERVER['ORIG_PATH_TRANSLATED']:$_SERVER['PATH_TRANSLATED']):($_SERVER['ORIG_SCRIPT_FILENAME']?$_SERVER['ORIG_SCRIPT_FILENAME']:$_SERVER['SCRIPT_FILENAME']))));
+
+if(!defined('PATH_thisScript')) {
+	define('PATH_thisScript', str_replace('//', '/', str_replace('\\', '/',
+		(PHP_SAPI == 'fpm-fcgi' || PHP_SAPI == 'cgi' || PHP_SAPI == 'isapi' || PHP_SAPI == 'cgi-fcgi') &&
+		($_SERVER['ORIG_PATH_TRANSLATED'] ? $_SERVER['ORIG_PATH_TRANSLATED'] : $_SERVER['PATH_TRANSLATED']) ?
+		($_SERVER['ORIG_PATH_TRANSLATED'] ? $_SERVER['ORIG_PATH_TRANSLATED'] : $_SERVER['PATH_TRANSLATED']) :
+		($_SERVER['ORIG_SCRIPT_FILENAME'] ? $_SERVER['ORIG_SCRIPT_FILENAME'] : $_SERVER['SCRIPT_FILENAME']))));
+}
+
 if(!defined('PATH_site'))  		define('PATH_site', preg_replace('/[^\/]*.[^\/]*$/','',PATH_thisScript));		// the path to the website folder (see init.php)
 if(!defined('PATH_t3lib')) 		define('PATH_t3lib', PATH_site.'t3lib/');
 define('PATH_typo3conf', PATH_site.'typo3conf/');
@@ -83,8 +68,12 @@ require_once(PATH_t3lib.'class.t3lib_div.php');
 require_once(PATH_t3lib.'class.t3lib_extmgm.php');
 
 require(PATH_t3lib.'config_default.php');
-if (!defined ('TYPO3_db')) 	die ('The configuration file was not included.');
-if (!$TYPO3_CONF_VARS['GFX']['image_processing'])	die ('ImageProcessing was disabled!');
+if (!defined ('TYPO3_db')) {
+	die ('The configuration file was not included.');
+}
+if (!$GLOBALS['TYPO3_CONF_VARS']['GFX']['image_processing']) {
+	die ('ImageProcessing was disabled!');
+}
 
 
 
@@ -110,7 +99,7 @@ if (!$TYPO3_CONF_VARS['GFX']['image_processing'])	die ('ImageProcessing was disa
  *
  * Relative paths MUST BE the first two characters ONLY: eg: '../dir/file.gif', otherwise it is expect to be absolute
  *
- * @author		Kasper Skaarhoj	<kasperYYYY@typo3.com>
+ * @author		Kasper Skårhøj	<kasperYYYY@typo3.com>
  * @package TYPO3
  * @subpackage t3lib
  */
@@ -119,9 +108,9 @@ class SC_t3lib_thumbs {
 
 	var $outdir = 'typo3temp/';		// The output directory of temporary files in PATH_site
 	var $output = '';
-	var $sizeDefault='56x56';
+	var $sizeDefault='64x64';
 
-	var $imageList;		// Coming from $TYPO3_CONF_VARS['GFX']['imagefile_ext']
+	var $imageList;		// Coming from $GLOBALS['TYPO3_CONF_VARS']['GFX']['imagefile_ext']
 	var $input;		// Contains the absolute path to the file for which to make a thumbnail (after init())
 
 		// Internal, static: GPvar:
@@ -136,45 +125,53 @@ class SC_t3lib_thumbs {
 	 *
 	 * @return	void
 	 */
-	function init()	{
-		global $TYPO3_CONF_VARS;
-
+	function init() {
 			// Setting GPvars:
 		$file = t3lib_div::_GP('file');
 		$size = t3lib_div::_GP('size');
 		$md5sum = t3lib_div::_GP('md5sum');
 
 			// Image extension list is set:
-		$this->imageList = $TYPO3_CONF_VARS['GFX']['imagefile_ext'];			// valid extensions. OBS: No spaces in the list, all lowercase...
+		$this->imageList = $GLOBALS['TYPO3_CONF_VARS']['GFX']['imagefile_ext'];			// valid extensions. OBS: No spaces in the list, all lowercase...
 
 			// If the filereference $this->file is relative, we correct the path
-		if (substr($file,0,3)=='../')	{
+		if (substr($file,0,3)=='../') {
 			$file = PATH_site.substr($file,3);
 		}
 
+		$mtime = 0;
 			// Now the path is absolute.
 			// Checking for backpath and double slashes + the thumbnail can be made from files which are in the PATH_site OR the lockRootPath only!
-		if (t3lib_div::isAllowedAbsPath($file))	{
+		if (t3lib_div::isAllowedAbsPath($file)) {
 			$mtime = filemtime($file);
 		}
 
 			// Do an MD5 check to prevent viewing of images without permission
 		$OK = FALSE;
-		if ($mtime)	{
+		if ($mtime) {
 				// Always use the absolute path for this check!
 			$check = basename($file).':'.$mtime.':'.$GLOBALS['TYPO3_CONF_VARS']['SYS']['encryptionKey'];
-			$md5_real = t3lib_div::shortMD5($check);
-			if (!strcmp($md5_real,$md5sum))	{
+			$md5pre47 = t3lib_div::shortMD5($check);
+			$md5from47 = md5($check);
+			if (!strcmp($md5pre47, $md5sum) || !strcmp($md5from47, $md5sum)) {
 				$OK = TRUE;
 			}
 		}
 
-		if ($OK)	{
+		if ($OK) {
 			$this->input = $file;
 			$this->size = $size;
 			$this->mtime = $mtime;
 		} else {
-			die('Error: Image does not exist and/or MD5 checksum did not match.');
+				// hide the path to the document root;
+			$publicFilename = substr($file, strlen(PATH_site));
+			throw new RuntimeException(
+				'TYPO3 Fatal Error: Image \'' . $publicFilename . '\' does not exist and/or MD5 checksum did not match. ' .
+					'If the target file exists and its file name contains special characters, the setting of ' .
+					'$TYPO3_CONF_VARS[SYS][systemLocale] might be wrong.'
+				,
+				1270853950
+			);
 		}
 	}
 
@@ -184,76 +181,72 @@ class SC_t3lib_thumbs {
 	 *
 	 * @return	void
 	 */
-	function main()	{
-		global $TYPO3_CONF_VARS;
-
+	function main() {
 			// If file exists, we make a thumbsnail of the file.
-		if ($this->input && file_exists($this->input))	{
+		if ($this->input && file_exists($this->input)) {
 
 				// Check file extension:
 			$reg = array();
-			if (preg_match('/(.*)\.([^\.]*$)/',$this->input,$reg))	{
+			if (preg_match('/(.*)\.([^\.]*$)/', $this->input, $reg)) {
 				$ext=strtolower($reg[2]);
-				$ext=($ext=='jpeg')?'jpg':$ext;
-				if ($ext=='ttf')	{
+				$ext=($ext=='jpeg') ? 'jpg' : $ext;
+				if ($ext=='ttf') {
 					$this->fontGif($this->input);	// Make font preview... (will not return)
-				} elseif (!t3lib_div::inList($this->imageList, $ext))	{
-					$this->errorGif('Not imagefile!',$ext,basename($this->input));
+				} elseif (!t3lib_div::inList($this->imageList, $ext)) {
+					$this->errorGif('Not imagefile!', $ext, basename($this->input));
 				}
 			} else {
-				$this->errorGif('Not imagefile!','No ext!',basename($this->input));
+				$this->errorGif('Not imagefile!', 'No ext!', basename($this->input));
 			}
 
 				// ... so we passed the extension test meaning that we are going to make a thumbnail here:
 			if (!$this->size) 	$this->size = $this->sizeDefault;	// default
 
 				// I added extra check, so that the size input option could not be fooled to pass other values. That means the value is exploded, evaluated to an integer and the imploded to [value]x[value]. Furthermore you can specify: size=340 and it'll be translated to 340x340.
-			$sizeParts = explode('x', $this->size.'x'.$this->size);	// explodes the input size (and if no "x" is found this will add size again so it is the same for both dimensions)
-			$sizeParts = array(t3lib_div::intInRange($sizeParts[0],1,1000),t3lib_div::intInRange($sizeParts[1],1,1000));	// Cleaning it up, only two parameters now.
-			$this->size = implode('x',$sizeParts);		// Imploding the cleaned size-value back to the internal variable
+			$sizeParts = explode('x', $this->size . 'x' . $this->size);	// explodes the input size (and if no "x" is found this will add size again so it is the same for both dimensions)
+			$sizeParts = array(t3lib_utility_Math::forceIntegerInRange($sizeParts[0], 1, 1000), t3lib_utility_Math::forceIntegerInRange($sizeParts[1], 1, 1000));	// Cleaning it up, only two parameters now.
+			$this->size = implode('x', $sizeParts);		// Imploding the cleaned size-value back to the internal variable
 			$sizeMax = max($sizeParts);	// Getting max value
 
 				// Init
-			$outpath = PATH_site.$this->outdir;
+			$outpath = PATH_site . $this->outdir;
 
 				// Should be - ? 'png' : 'gif' - , but doesn't work (ImageMagick prob.?)
-				// Ren: png work for me
-			$thmMode = t3lib_div::intInRange($TYPO3_CONF_VARS['GFX']['thumbnails_png'],0);
+				// René: png work for me
+			$thmMode = t3lib_utility_Math::forceIntegerInRange($GLOBALS['TYPO3_CONF_VARS']['GFX']['thumbnails_png'], 0);
 			$outext = ($ext!='jpg' || ($thmMode & 2)) ? ($thmMode & 1 ? 'png' : 'gif') : 'jpg';
 
-			$outfile = 'tmb_'.substr(md5($this->input.$this->mtime.$this->size),0,10).'.'.$outext;
-			$this->output = $outpath.$outfile;
+			$outfile = 'tmb_' . substr(md5($this->input . $this->mtime . $this->size), 0, 10) . '.' . $outext;
+			$this->output = $outpath . $outfile;
 
-			if ($TYPO3_CONF_VARS['GFX']['im'])	{
+			if ($GLOBALS['TYPO3_CONF_VARS']['GFX']['im']) {
 					// If thumbnail does not exist, we generate it
-				if (!file_exists($this->output))	{
-/*					if (strstr($this->input,' ') || strstr($this->output,' '))	{
-						$this->errorGif('Spaces in','filepath',basename($this->input));
-					}
-*/						// 16 colors for small (56) thumbs, 64 for bigger and all for jpegs
-					if ($outext=='jpg')	{
-						$colors = '';
-					} else {
-						$colors = ($sizeMax>56)?'-colors 64':'-colors 16';
-					}
-					$parameters = '-sample '.$this->size.' '.$colors.' '.$this->wrapFileName($this->input).'[0] '.$this->wrapFileName($this->output);
+				if (!file_exists($this->output)) {
+					$parameters = '-sample ' . $this->size . ' ' . $this->wrapFileName($this->input) . '[0] ' . $this->wrapFileName($this->output);
 					$cmd = t3lib_div::imageMagickCommand('convert', $parameters);
-					exec($cmd);
-					if (!file_exists($this->output))	{
-						$this->errorGif('No thumb','generated!',basename($this->input));
+					t3lib_utility_Command::exec($cmd);
+					if (!file_exists($this->output)) {
+						$this->errorGif('No thumb','generated!', basename($this->input));
+					} else {
+						t3lib_div::fixPermissions($this->output);
 					}
 				}
 					// The thumbnail is read and output to the browser
-				if($fd = @fopen($this->output,'rb'))	{
-					header('Content-type: image/'.$outext);
+				if (($fd = @fopen($this->output, 'rb'))) {
+					$fileModificationTime = filemtime($this->output);
+					header('Content-type: image/' . $outext);
+					header('Last-Modified: '. date('r', $fileModificationTime));
+					header('Etag: ' . md5($this->output) . '-' . $fileModificationTime);
+						// Expiration time is choosen arbitrary to 1 month
+					header('Expires: ' . date('r', $fileModificationTime + 30*24*60*60));
 					fpassthru($fd);
 					fclose($fd);
 				} else {
-					$this->errorGif('Read problem!','',$this->output);
+					$this->errorGif('Read problem!', '', $this->output);
 				}
 			} else exit;
 		} else {
-			$this->errorGif('No valid','inputfile!',basename($this->input));
+			$this->errorGif('No valid','inputfile!', basename($this->input));
 		}
 	}
 
@@ -283,41 +276,44 @@ class SC_t3lib_thumbs {
 	 * @param	string		Text line 3
 	 * @return	void
 	 */
-	function errorGif($l1,$l2,$l3)	{
-		global $TYPO3_CONF_VARS;
-
-		if (!$TYPO3_CONF_VARS['GFX']['gdlib'])	die($l1.' '.$l2.' '.$l3);
+	function errorGif($l1,$l2,$l3) {
+		if (!$GLOBALS['TYPO3_CONF_VARS']['GFX']['gdlib']) {
+			throw new RuntimeException(
+				'TYPO3 Fatal Error: No gdlib. ' . $l1 . ' ' . $l2 . ' ' . $l3,
+				1270853952
+			);
+		}
 
 			// Creates the basis for the error image
-		if ($TYPO3_CONF_VARS['GFX']['gdlib_png'])	{
+		if ($GLOBALS['TYPO3_CONF_VARS']['GFX']['gdlib_png']) {
 			header('Content-type: image/png');
-			$im = imagecreatefrompng(PATH_typo3.'gfx/notfound_thumb.png');
+			$im = imagecreatefrompng(PATH_typo3 . 'gfx/notfound_thumb.png');
 		} else {
 			header('Content-type: image/gif');
-			$im = imagecreatefromgif(PATH_typo3.'gfx/notfound_thumb.gif');
+			$im = imagecreatefromgif(PATH_typo3 . 'gfx/notfound_thumb.gif');
 		}
 			// Sets background color and print color.
-		$white = imageColorAllocate($im, 0,0,0);
-		$black = imageColorAllocate($im, 255,255,0);
+		$white = imageColorAllocate($im, 255, 255, 255);
+		$black = imageColorAllocate($im, 0, 0, 0);
 
 			// Prints the text strings with the build-in font functions of GD
 		$x=0;
 		$font=0;
-		if ($l1)	{
-			imagefilledrectangle($im, $x, 9, 56, 16, $black);
-			imageString($im,$font,$x,9,$l1,$white);
+		if ($l1) {
+			imagefilledrectangle($im, $x, 9, 56, 16, $white);
+			imageString($im, $font, $x, 9, $l1, $black);
 		}
-		if ($l2)	{
-			imagefilledrectangle($im, $x, 19, 56, 26, $black);
-			imageString($im,$font,$x,19,$l2,$white);
+		if ($l2) {
+			imagefilledrectangle($im, $x, 19, 56, 26, $white);
+			imageString($im, $font, $x, 19, $l2, $black);
 		}
-		if ($l3)	{
-			imagefilledrectangle($im, $x, 29, 56, 36, $black);
-			imageString($im,$font,$x,29,substr($l3,-14),$white);
+		if ($l3) {
+			imagefilledrectangle($im, $x, 29, 56, 36, $white);
+			imageString($im, $font, $x, 29, substr($l3, -14), $black);
 		}
 
 			// Outputting the image stream and exit
-		if ($TYPO3_CONF_VARS['GFX']['gdlib_png'])	{
+		if ($GLOBALS['TYPO3_CONF_VARS']['GFX']['gdlib_png']) {
 			imagePng($im);
 		} else {
 			imageGif($im);
@@ -335,18 +331,21 @@ class SC_t3lib_thumbs {
 	 * @param	string		The filepath to the font file (absolute, probably)
 	 * @return	void
 	 */
-	function fontGif($font)	{
-		global $TYPO3_CONF_VARS;
-
-		if (!$TYPO3_CONF_VARS['GFX']['gdlib'])	die('');
+	function fontGif($font) {
+		if (!$GLOBALS['TYPO3_CONF_VARS']['GFX']['gdlib']) {
+			throw new RuntimeException(
+				'TYPO3 Fatal Error: No gdlib.',
+				1270853953
+			);
+		}
 
 			// Create image and set background color to white.
-		$im = imageCreate(250,76);
-		$white = imageColorAllocate($im, 255,255,255);
-		$col = imageColorAllocate($im, 0,0,0);
+		$im = imageCreate(250, 76);
+		$white = imageColorAllocate($im, 255, 255, 255);
+		$col = imageColorAllocate($im, 0, 0, 0);
 
 			// The test string and offset in x-axis.
-		$string = 'AaBbCcDdEeFfGgHhIiJjKkLlMmNnOoPpQqRrSsTtUuVvWwXxYyZz';
+		$string = 'AaBbCcDdEeFfGgHhIiJjKkLlMmNnOoPpQqRrSsTtUuVvWwXxYyZzÆæØøÅåÄäÖöÜüß';
 		$x=13;
 
 			// Print (with non-ttf font) the size displayed
@@ -363,8 +362,8 @@ class SC_t3lib_thumbs {
 		imagettftext ($im, t3lib_div::freetypeDpiComp(18), 0, $x, 53, $col, $font, $string);
 		imagettftext ($im, t3lib_div::freetypeDpiComp(24), 0, $x, 74, $col, $font, $string);
 
-			// Output PNG or GIF based on $TYPO3_CONF_VARS['GFX']['gdlib_png']
-		if ($TYPO3_CONF_VARS['GFX']['gdlib_png'])	{
+			// Output PNG or GIF based on $GLOBALS['TYPO3_CONF_VARS']['GFX']['gdlib_png']
+		if ($GLOBALS['TYPO3_CONF_VARS']['GFX']['gdlib_png']) {
 			header('Content-type: image/png');
 			imagePng($im);
 		} else {
@@ -383,12 +382,20 @@ class SC_t3lib_thumbs {
 	 * @return string $inputName escaped as needed
 	 */
 	protected function wrapFileName($inputName) {
-		return escapeshellarg($inputName);
+		if ($GLOBALS['TYPO3_CONF_VARS']['SYS']['UTF8filesystem']) {
+			$currentLocale = setlocale(LC_CTYPE, 0);
+			setlocale(LC_CTYPE, $GLOBALS['TYPO3_CONF_VARS']['SYS']['systemLocale']);
+		}
+		$escapedInputName = escapeshellarg($inputName);
+		if ($GLOBALS['TYPO3_CONF_VARS']['SYS']['UTF8filesystem']) {
+			setlocale(LC_CTYPE, $currentLocale);
+		}
+		return $escapedInputName;
 	}
 }
 
-if (defined('TYPO3_MODE') && $TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['t3lib/thumbs.php'])	{
-	include_once($TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['t3lib/thumbs.php']);
+if (defined('TYPO3_MODE') && isset($GLOBALS['TYPO3_CONF_VARS'][TYPO3_MODE]['XCLASS']['t3lib/thumbs.php'])) {
+	include_once($GLOBALS['TYPO3_CONF_VARS'][TYPO3_MODE]['XCLASS']['t3lib/thumbs.php']);
 }
 
 
