@@ -2,7 +2,7 @@
 /***************************************************************
 *  Copyright notice
 *
-*  (c) 2007-2008 Ingo Renner <ingo@typo3.org>
+*  (c) 2007-2011 Ingo Renner <ingo@typo3.org>
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
@@ -26,12 +26,7 @@
 ***************************************************************/
 
 if(TYPO3_REQUESTTYPE & TYPO3_REQUESTTYPE_AJAX) {
-	require_once('interfaces/interface.backend_toolbaritem.php');
-	require_once(PATH_t3lib.'class.t3lib_loadmodules.php');
-	require_once(PATH_typo3.'sysext/lang/lang.php');
-
-	$GLOBALS['LANG'] = t3lib_div::makeInstance('language');
-	$GLOBALS['LANG']->init($GLOBALS['BE_USER']->uc['lang']);
+	require_once(PATH_typo3 . 'interfaces/interface.backend_toolbaritem.php');
 	$GLOBALS['LANG']->includeLLFile('EXT:lang/locallang_misc.xml');
 
 		// needed to get the correct icons when reloading the menu after saving it
@@ -43,8 +38,6 @@ if(TYPO3_REQUESTTYPE & TYPO3_REQUESTTYPE_AJAX) {
 /**
  * class to render the shortcut menu
  *
- * $Id: class.shortcutmenu.php 3669 2008-05-20 08:34:50Z flyguide $
- *
  * @author	Ingo Renner <ingo@typo3.org>
  * @package TYPO3
  * @subpackage core
@@ -81,7 +74,7 @@ class ShortcutMenu implements backend_toolbarItem {
 	 * @param	TYPO3backend	TYPO3 backend object reference
 	 * @return	void
 	 */
-	public function __construct(TYPO3backend &$backendReference = null) {
+	public function __construct(TYPO3backend &$backendReference = NULL) {
 		$this->backendReference = $backendReference;
 		$this->shortcuts        = array();
 
@@ -101,11 +94,10 @@ class ShortcutMenu implements backend_toolbarItem {
 	/**
 	 * checks whether the user has access to this toolbar item
 	 *
-	 * @return  boolean  true if user has access, false if not
+	 * @return boolean TRUE if user has access, FALSE if not
 	 */
 	public function checkAccess() {
-			// Shortcut module is enabled for everybody
-		return true;
+		return (bool) $GLOBALS['BE_USER']->getTSConfigVal('options.enableBookmarks');
 	}
 
 	/**
@@ -114,16 +106,19 @@ class ShortcutMenu implements backend_toolbarItem {
 	 * @return	string		workspace selector as HTML select
 	 */
 	public function render() {
+		$title = $GLOBALS['LANG']->sL('LLL:EXT:lang/locallang_core.xml:toolbarItems.bookmarks', TRUE);
 		$this->addJavascriptToBackend();
 
 		$shortcutMenu = array();
 
-		$shortcutMenu[] = '<a href="#" class="toolbar-item"><img'.t3lib_iconWorks::skinImg($this->backPath, 'gfx/toolbar_shortcut.png', 'width="16" height="16"').' title="Shortcuts" alt="" /></a>';
+		$shortcutMenu[] = '<a href="#" class="toolbar-item">' .
+			t3lib_iconWorks::getSpriteIcon('apps-toolbar-menu-shortcut', array('title' => $title)) .
+			'</a>';
 		$shortcutMenu[] = '<div class="toolbar-item-menu" style="display: none;">';
 		$shortcutMenu[] = $this->renderMenu();
 		$shortcutMenu[] = '</div>';
 
-		return implode("\n", $shortcutMenu);
+		return implode(LF, $shortcutMenu);
 	}
 
 	/**
@@ -133,9 +128,13 @@ class ShortcutMenu implements backend_toolbarItem {
 	 */
 	public function renderMenu() {
 
-		$groupIcon  = '<img'.t3lib_iconWorks::skinImg($this->backPath, 'gfx/i/sysf.gif', 'width="18" height="16"').' title="Shortcut Group" alt="" />';
-		$editIcon   = '<img'.t3lib_iconWorks::skinImg($this->backPath, 'gfx/edit2.gif', 'width="11" height="12"').' title="Edit Shortcut" alt=""';
-		$deleteIcon = '<img'.t3lib_iconWorks::skinImg($this->backPath, 'gfx/garbage.gif', 'width="11" height="12"').' title="Delete Shortcut" alt="" />';
+		$shortcutGroup  = $GLOBALS['LANG']->sL('LLL:EXT:lang/locallang_core.xml:toolbarItems.bookmarksGroup', TRUE);
+		$shortcutEdit   = $GLOBALS['LANG']->sL('LLL:EXT:lang/locallang_core.xml:toolbarItems.bookmarksEdit', TRUE);
+		$shortcutDelete = $GLOBALS['LANG']->sL('LLL:EXT:lang/locallang_core.xml:toolbarItems.bookmarksDelete', TRUE);
+
+		$groupIcon  = '<img'.t3lib_iconWorks::skinImg($this->backPath, 'gfx/i/sysf.gif', 'width="18" height="16"').' title="'.$shortcutGroup.'" alt="'.$shortcutGroup.'" />';
+		$editIcon   = '<img'.t3lib_iconWorks::skinImg($this->backPath, 'gfx/edit2.gif', 'width="11" height="12"').' title="'.$shortcutEdit.'" alt="'.$shortcutEdit.'"';
+		$deleteIcon = '<img'.t3lib_iconWorks::skinImg($this->backPath, 'gfx/garbage.gif', 'width="11" height="12"').' title="'.$shortcutDelete.'" alt="'.$shortcutDelete.'" />';
 
 		$shortcutMenu[] = '<table border="0" cellspacing="0" cellpadding="0" class="shortcut-list">';
 
@@ -146,7 +145,7 @@ class ShortcutMenu implements backend_toolbarItem {
 			<tr id="shortcut-'.$shortcut['raw']['uid'].'" class="shortcut">
 				<td class="shortcut-icon">'.$shortcut['icon'].'</td>
 				<td class="shortcut-label">
-					<a id="shortcut-label-'.$shortcut['raw']['uid'].'" href="" onclick="'.$shortcut['action'].'">'.$shortcut['label'].'</a>
+					<a id="shortcut-label-' . $shortcut['raw']['uid'] . '" href="#" onclick="' . $shortcut['action'] . '; return false;">' . htmlspecialchars($shortcut['label']) . '</a>
 				</td>
 				<td class="shortcut-edit">'.$editIcon.' id="shortcut-edit-'.$shortcut['raw']['uid'].'" /></td>
 				<td class="shortcut-delete">'.$deleteIcon.'</td>
@@ -179,7 +178,7 @@ class ShortcutMenu implements backend_toolbarItem {
 					<tr id="shortcut-'.$shortcut['raw']['uid'].'" class="shortcut'.$firstRow.'">
 						<td class="shortcut-icon">'.$shortcut['icon'].'</td>
 						<td class="shortcut-label">
-							<a id="shortcut-label-'.$shortcut['raw']['uid'].'" href="" onclick="'.$shortcut['action'].'">'.$shortcut['label'].'</a>
+							<a id="shortcut-label-' . $shortcut['raw']['uid'] . '" href="#" onclick="' . $shortcut['action'] . '; return false;">' . htmlspecialchars($shortcut['label']) . '</a>
 						</td>
 						<td class="shortcut-edit">'.$editIcon.' id="shortcut-edit-'.$shortcut['raw']['uid'].'" /></td>
 						<td class="shortcut-delete">'.$deleteIcon.'</td>
@@ -192,15 +191,18 @@ class ShortcutMenu implements backend_toolbarItem {
 
 		if(count($shortcutMenu) == 1) {
 				//no shortcuts added yet, show a small help message how to add shortcuts
-			$icon  = '<img'.t3lib_iconWorks::skinImg($backPath,'gfx/shortcut.gif','width="14" height="14"').' title="shortcut icon" alt="" />';
-			$label = str_replace('%icon%', $icon, $GLOBALS['LANG']->sL('LLL:EXT:lang/locallang_misc.php:shortcutDescription'));
+			$title = $GLOBALS['LANG']->sL('LLL:EXT:lang/locallang_core.xml:toolbarItems.bookmarks', TRUE);
+			$icon = t3lib_iconWorks::getSpriteIcon('actions-system-shortcut-new', array(
+				'title' => $title
+			));
+			$label = str_replace('%icon%', $icon, $GLOBALS['LANG']->sL('LLL:EXT:lang/locallang_misc.php:bookmarkDescription'));
 
 			$shortcutMenu[] = '<tr><td style="padding:1px 2px; color: #838383;">'.$label.'</td></tr>';
 		}
 
 		$shortcutMenu[] = '</table>';
 
-		$compiledShortcutMenu = implode("\n", $shortcutMenu);
+		$compiledShortcutMenu = implode(LF, $shortcutMenu);
 
 		return $compiledShortcutMenu;
 	}
@@ -212,7 +214,7 @@ class ShortcutMenu implements backend_toolbarItem {
 	 * @param	TYPO3AJAX	object of type TYPO3AJAX
 	 * @return	void
 	 */
-	public function renderAjax($params = array(), TYPO3AJAX &$ajaxObj = null) {
+	public function renderAjax($params = array(), TYPO3AJAX &$ajaxObj = NULL) {
 		$menuContent = $this->renderMenu();
 
 		$ajaxObj->addContent('shortcutMenu', $menuContent);
@@ -284,6 +286,7 @@ class ShortcutMenu implements backend_toolbarItem {
 			}
 
 				// check for module access
+			$pageId = $this->getLinkedPageId($row['url']);
 			if(!$GLOBALS['BE_USER']->isAdmin()) {
 				if(!isset($GLOBALS['LANG']->moduleLabels['tabs_images'][implode('_', $moduleParts).'_tab'])) {
 						// nice hack to check if the user has access to this module
@@ -291,8 +294,7 @@ class ShortcutMenu implements backend_toolbarItem {
 					continue;
 				}
 
-				$pageId = $this->getLinkedPageId($row['url']);
-				if(t3lib_div::testInt($pageId)) {
+				if(t3lib_utility_Math::canBeInterpretedAsInteger($pageId)) {
 						// check for webmount access
 					if(!$GLOBALS['BE_USER']->isInWebMount($pageId)) {
 						continue;
@@ -314,13 +316,13 @@ class ShortcutMenu implements backend_toolbarItem {
 			if($row['description']) {
 				$shortcut['label'] = $row['description'];
 			} else {
-				$shortcut['label'] = t3lib_div::fixed_lgd(rawurldecode($queryParts['query']), 150);
+				$shortcut['label'] = t3lib_div::fixed_lgd_cs(rawurldecode($queryParts['query']), 150);
 			}
 
 			$shortcut['group']     = $shortcutGroup;
 			$shortcut['icon']      = $this->getShortcutIcon($row, $shortcut);
 			$shortcut['iconTitle'] = $this->getShortcutIconTitle($shortcutLabel, $row['module_name'], $row['M_module_name']);
-			$shortcut['action']    = 'jump(unescape(\''.rawurlencode($row['url']).'\'),\''.implode('_',$moduleParts).'\',\''.$moduleParts[0].'\');';
+			$shortcut['action']    = 'jump(unescape(\''.rawurlencode($row['url']).'\'),\''.implode('_',$moduleParts).'\',\''.$moduleParts[0].'\', ' . intval($pageId) . ');';
 
 			$lastGroup   = $row['sc_group'];
 			$shortcuts[] = $shortcut;
@@ -351,10 +353,10 @@ class ShortcutMenu implements backend_toolbarItem {
 	 * gets a shortcut by its uid
 	 *
 	 * @param	integer		shortcut id to get the complete shortcut for
-	 * @return	mixed		an array containing the shortcut's data on success or false on failure
+	 * @return	mixed		an array containing the shortcut's data on success or FALSE on failure
 	 */
 	protected function getShortcutById($shortcutId) {
-		$returnShortcut = false;
+		$returnShortcut = FALSE;
 
 		foreach($this->shortcuts as $shortcut) {
 			if($shortcut['raw']['uid'] == (int) $shortcutId) {
@@ -374,12 +376,12 @@ class ShortcutMenu implements backend_toolbarItem {
 	 * @param	TYPO3AJAX	object of type TYPO3AJAX
 	 * @return	array
 	 */
-	protected function initShortcutGroups($params = array(), TYPO3AJAX &$ajaxObj = null) {
+	protected function initShortcutGroups($params = array(), TYPO3AJAX &$ajaxObj = NULL) {
 			// groups from TSConfig
-		$userShortcutGroups = $GLOBALS['BE_USER']->getTSConfig('options.shortcutGroups');
+		$bookmarkGroups = $GLOBALS['BE_USER']->getTSConfigProp('options.bookmarkGroups');
 
-		if(is_array($userShortcutGroups['properties']) && count($userShortcutGroups['properties'])) {
-			foreach($userShortcutGroups['properties'] as $groupId => $label) {
+		if(is_array($bookmarkGroups) && count($bookmarkGroups)) {
+			foreach($bookmarkGroups as $groupId => $label) {
 				if(strcmp('', $label) && strcmp('0', $label)) {
 					$this->shortcutGroups[$groupId] = (string) $label;
 				} elseif($GLOBALS['BE_USER']->isAdmin()) {
@@ -404,24 +406,24 @@ class ShortcutMenu implements backend_toolbarItem {
 			$label = $groupLabel;
 
 			if($groupLabel == '1') {
-				$label = $GLOBALS['LANG']->getLL('shortcut_group_'.abs($groupId), 1);
+				$label = $GLOBALS['LANG']->getLL('bookmark_group_'.abs($groupId), 1);
 
 				if(empty($label)) {
 						// fallback label
-					$label = $GLOBALS['LANG']->getLL('shortcut_group', 1).' '.abs($groupId);
+					$label = $GLOBALS['LANG']->getLL('bookmark_group', 1).' '.abs($groupId);
 				}
 			}
 
 			if($groupId < 0) {
 					// global group
-				$label = $GLOBALS['LANG']->getLL('shortcut_global', 1).': '.
+				$label = $GLOBALS['LANG']->getLL('bookmark_global', 1).': '.
 					(!empty($label) ?
 						$label :
 						abs($groupId)
 					);
 
 				if($groupId == -100) {
-					$label = $GLOBALS['LANG']->getLL('shortcut_global', 1).': '.$GLOBALS['LANG']->getLL('shortcut_all', 1);
+					$label = $GLOBALS['LANG']->getLL('bookmark_global', 1).': '.$GLOBALS['LANG']->getLL('bookmark_all', 1);
 				}
 			}
 
@@ -438,7 +440,7 @@ class ShortcutMenu implements backend_toolbarItem {
 	 * @param	TYPO3AJAX	object of type TYPO3AJAX
 	 * @return	void
 	 */
-	public function getAjaxShortcutGroups($params = array(), TYPO3AJAX &$ajaxObj = null) {
+	public function getAjaxShortcutGroups($params = array(), TYPO3AJAX &$ajaxObj = NULL) {
 		$shortcutGroups = $this->shortcutGroups;
 
 		if(!$GLOBALS['BE_USER']->isAdmin()) {
@@ -460,7 +462,7 @@ class ShortcutMenu implements backend_toolbarItem {
 	 * @param	TYPO3AJAX	object of type TYPO3AJAX
 	 * @return	void
 	 */
-	public function deleteAjaxShortcut($params = array(), TYPO3AJAX &$ajaxObj = null) {
+	public function deleteAjaxShortcut($params = array(), TYPO3AJAX &$ajaxObj = NULL) {
 		$shortcutId   = (int) t3lib_div::_POST('shortcutId');
 		$fullShortcut = $this->getShortcutById($shortcutId);
 		$ajaxReturn   = 'failed';
@@ -486,14 +488,12 @@ class ShortcutMenu implements backend_toolbarItem {
 	 * @param	TYPO3AJAX	object of type TYPO3AJAX
 	 * @return	void
 	 */
-	public function createAjaxShortcut($params = array(), TYPO3AJAX &$ajaxObj = null) {
-		global $TCA, $LANG;
-
+	public function createAjaxShortcut($params = array(), TYPO3AJAX &$ajaxObj = NULL) {
 		$shortcutCreated     = 'failed';
 		$shortcutName        = 'Shortcut'; // default name
 		$shortcutNamePrepend = '';
 
-		$url             = urldecode(t3lib_div::_POST('url'));
+		$url             = t3lib_div::_POST('url');
 		$module          = t3lib_div::_POST('module');
 		$motherModule    = t3lib_div::_POST('motherModName');
 
@@ -501,60 +501,64 @@ class ShortcutMenu implements backend_toolbarItem {
 		$queryParts      = parse_url($url);
 		$queryParameters = t3lib_div::explodeUrl2Array($queryParts['query'], 1);
 
-		if(is_array($queryParameters['edit'])) {
-			$shortcut['table']    = key($queryParameters['edit']);
-			$shortcut['recordid'] = key($queryParameters['edit'][$shortcut['table']]);
+			// Proceed only if no scheme is defined, as URL is expected to be relative
+		if (empty($queryParts['scheme'])) {
+			if (is_array($queryParameters['edit'])) {
+				$shortcut['table']    = key($queryParameters['edit']);
+				$shortcut['recordid'] = key($queryParameters['edit'][$shortcut['table']]);
 
-			if($queryParameters['edit'][$shortcut['table']][$shortcut['recordid']] == 'edit') {
-				$shortcut['type']    = 'edit';
-				$shortcutNamePrepend = $GLOBALS['LANG']->getLL('shortcut_edit', 1);
-			} elseif($queryParameters['edit'][$shortcut['table']][$shortcut['recordid']] == 'new') {
-				$shortcut['type']    = 'new';
-				$shortcutNamePrepend = $GLOBALS['LANG']->getLL('shortcut_create', 1);
+				if($queryParameters['edit'][$shortcut['table']][$shortcut['recordid']] == 'edit') {
+					$shortcut['type']    = 'edit';
+					$shortcutNamePrepend = $GLOBALS['LANG']->getLL('shortcut_edit', 1);
+				} elseif($queryParameters['edit'][$shortcut['table']][$shortcut['recordid']] == 'new') {
+					$shortcut['type']    = 'new';
+					$shortcutNamePrepend = $GLOBALS['LANG']->getLL('shortcut_create', 1);
+				}
+			} else {
+				$shortcut['type'] = 'other';
 			}
-		} else {
-			$shortcut['type'] = 'other';
-		}
 
-			// Lookup the title of this page and use it as default description
-		$pageId = $this->getLinkedPageId($url);
+				// Lookup the title of this page and use it as default description
+			$pageId = $shortcut['recordid'] ? $shortcut['recordid'] : $this->getLinkedPageId($url);
 
-		if(t3lib_div::testInt($pageId)) {
-			$page = t3lib_BEfunc::getRecord('pages', $pageId);
-			if(count($page)) {
-					// set the name to the title of the page
-				if($shortcut['type'] == 'other') {
-					$shortcutName = $page['title'];
-				} else {
-					$shortcutName = $shortcutNamePrepend.' '.$LANG->sL($TCA[$shortcut['table']]['ctrl']['title']).' ('.$page['title'].')';
+			if(t3lib_utility_Math::canBeInterpretedAsInteger($pageId)) {
+				$page = t3lib_BEfunc::getRecord('pages', $pageId);
+				if(count($page)) {
+						// set the name to the title of the page
+					if($shortcut['type'] == 'other') {
+						$shortcutName = $page['title'];
+					} else {
+						$shortcutName = $shortcutNamePrepend.' '.$GLOBALS['LANG']->sL($GLOBALS['TCA'][$shortcut['table']]['ctrl']['title']).' ('.$page['title'].')';
+					}
+				}
+			} else {
+				$dirName = urldecode($pageId);
+				if (preg_match('/\/$/', $dirName))	{
+						// if $pageId is a string and ends with a slash,
+						// assume it is a fileadmin reference and set
+						// the description to the basename of that path
+					$shortcutName .= ' ' . basename($dirName);
 				}
 			}
-		} else {
-			if (preg_match('/\/$/', $pageId))	{
-					// if $pageId is a string and ends with a slash,
-					// assume it is a fileadmin reference and set
-					// the description to the basename of that path
-				$shortcutName .= basename($pageId);
+
+				// adding the shortcut
+			if($module && $url) {
+				$fieldValues = array(
+					'userid'      => $GLOBALS['BE_USER']->user['uid'],
+					'module_name' => $module.'|'.$motherModule,
+					'url'         => $url,
+					'description' => $shortcutName,
+					'sorting'     => $GLOBALS['EXEC_TIME'],
+				);
+				$GLOBALS['TYPO3_DB']->exec_INSERTquery('sys_be_shortcuts', $fieldValues);
+
+				if($GLOBALS['TYPO3_DB']->sql_affected_rows() == 1) {
+					$shortcutCreated = 'success';
+				}
 			}
+
+			$ajaxObj->addContent('create', $shortcutCreated);
 		}
-
-			// adding the shortcut
-		if($module && $url) {
-			$fieldValues = array(
-				'userid'      => $GLOBALS['BE_USER']->user['uid'],
-				'module_name' => $module.'|'.$motherModule,
-				'url'         => $url,
-				'description' => $shortcutName,
-				'sorting'     => time(),
-			);
-			$GLOBALS['TYPO3_DB']->exec_INSERTquery('sys_be_shortcuts', $fieldValues);
-
-			if($GLOBALS['TYPO3_DB']->sql_affected_rows() == 1) {
-				$shortcutCreated = 'success';
-			}
-		}
-
-		$ajaxObj->addContent('create', $shortcutCreated);
 	}
 
 	/**
@@ -565,7 +569,7 @@ class ShortcutMenu implements backend_toolbarItem {
 	 * @param	TYPO3AJAX	object of type TYPO3AJAX
 	 * @return	void
 	 */
-	public function setAjaxShortcut($params = array(), TYPO3AJAX &$ajaxObj = null) {
+	public function setAjaxShortcut($params = array(), TYPO3AJAX &$ajaxObj = NULL) {
 
 		$shortcutId      = (int) t3lib_div::_POST('shortcutId');
 		$shortcutName    = strip_tags(t3lib_div::_POST('value'));
@@ -659,8 +663,6 @@ class ShortcutMenu implements backend_toolbarItem {
 	 * @return	string		shortcut icon as img tag
 	 */
 	protected function getShortcutIcon($row, $shortcut) {
-		global $TCA;
-
 		switch($row['module_name']) {
 			case 'xMOD_alt_doc.php':
 				$table 				= $shortcut['table'];
@@ -680,19 +682,19 @@ class ShortcutMenu implements backend_toolbarItem {
 						$selectFields[] = 'doktype';
 					}
 
-					if(is_array($TCA[$table]['ctrl']['enablecolumns'])) {
-						$selectFields = array_merge($selectFields,$TCA[$table]['ctrl']['enablecolumns']);
+					if(is_array($GLOBALS['TCA'][$table]['ctrl']['enablecolumns'])) {
+						$selectFields = array_merge($selectFields,$GLOBALS['TCA'][$table]['ctrl']['enablecolumns']);
 					}
 
-					if($TCA[$table]['ctrl']['type']) {
-						$selectFields[] = $TCA[$table]['ctrl']['type'];
+					if($GLOBALS['TCA'][$table]['ctrl']['type']) {
+						$selectFields[] = $GLOBALS['TCA'][$table]['ctrl']['type'];
 					}
 
-					if($TCA[$table]['ctrl']['typeicon_column']) {
-						$selectFields[] = $TCA[$table]['ctrl']['typeicon_column'];
+					if($GLOBALS['TCA'][$table]['ctrl']['typeicon_column']) {
+						$selectFields[] = $GLOBALS['TCA'][$table]['ctrl']['typeicon_column'];
 					}
 
-					if($TCA[$table]['ctrl']['versioningWS']) {
+					if($GLOBALS['TCA'][$table]['ctrl']['versioningWS']) {
 						$selectFields[] = 't3ver_state';
 					}
 
@@ -701,7 +703,7 @@ class ShortcutMenu implements backend_toolbarItem {
 						' AND '.$this->perms_clause :
 						'';
 
-	         		$sqlQueryParts = array(
+					$sqlQueryParts = array(
 						'SELECT' => implode(',', $selectFields),
 						'FROM'   => $table,
 						'WHERE'  => 'uid IN ('.$recordid.') '.$permissionClause.
@@ -739,7 +741,7 @@ class ShortcutMenu implements backend_toolbarItem {
 				}
 		}
 
-		return '<img src="'.$icon.'" alt="shortcut icon" />';
+		return '<img src="' . $icon . '" alt="' . $GLOBALS['LANG']->sL('LLL:EXT:lang/locallang_core.xml:toolbarItems.shortcut', TRUE) . '" title="' . $GLOBALS['LANG']->sL('LLL:EXT:lang/locallang_core.xml:toolbarItems.shortcut', TRUE) . '" />';
 	}
 
 	/**
@@ -786,8 +788,8 @@ class ShortcutMenu implements backend_toolbarItem {
 }
 
 
-if (defined('TYPO3_MODE') && $TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['typo3/classes/class.shortcutmenu.php'])	{
-	include_once($TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['typo3/classes/class.shortcutmenu.php']);
+if (defined('TYPO3_MODE') && isset($GLOBALS['TYPO3_CONF_VARS'][TYPO3_MODE]['XCLASS']['typo3/classes/class.shortcutmenu.php'])) {
+	include_once($GLOBALS['TYPO3_CONF_VARS'][TYPO3_MODE]['XCLASS']['typo3/classes/class.shortcutmenu.php']);
 }
 
-?>
+?>
\ No newline at end of file
