@@ -1,7 +1,7 @@
 /***************************************************************
 *  Copyright notice
 *
-*  (c) 1999-2008 Kasper Skaarhoj (kasperYYYY@typo3.com)
+*  (c) 1999-2010 Kasper Skaarhoj (kasperYYYY@typo3.com)
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
@@ -26,8 +26,6 @@
 /**
  * Contains JavaScript for TYPO3 Core Form generator - AKA "TCEforms"
  *
- * $Id: jsfunc.tbe_editor.js 5480 2009-05-22 18:59:18Z ohader $
- *
  * @author	Kasper Skaarhoj <kasperYYYY@typo3.com>
  * @coauthor	Oliver Hader <oh@inpublica.de>
  */
@@ -36,7 +34,7 @@
 var TBE_EDITOR = {
 	/* Example:
 		elements: {
-			'data[table][uid]': {
+			'data-parentPid-table-uid': {
 				'field': {
 					'range':		[0, 100],
 					'rangeImg':		'',
@@ -73,7 +71,9 @@ var TBE_EDITOR = {
 		cm: new Image(),
 		sel: new Image(),
 		clear: new Image()
-	},	
+	},
+
+	clearBeforeSettingFormValueFromBrowseWin: [],
 
 	// Handling of data structures:
 	addElements: function(elements) {
@@ -196,6 +196,15 @@ var TBE_EDITOR = {
 			if (type == 'required') {
 				form = document[TBE_EDITOR.formname][elementName];
 				if (form) {
+						// Check if we are within a deleted inline element
+					var testNode = $(form.parentNode);
+					while(testNode) {
+						if (testNode.hasClassName && testNode.hasClassName('inlineIsDeletedRecord')) {
+							return result;
+						}
+						testNode = $(testNode.parentNode);
+					}
+
 					var value = form.value;
 					if (!value || elementData.additional && elementData.additional.isPositiveNumber && (isNaN(value) || Number(value) <= 0)) {
 						result = 0;
@@ -206,15 +215,27 @@ var TBE_EDITOR = {
 					}
 				}
 			} else if (type == 'range' && elementData.range) {
+				var numberOfElements = 0;
 				form = document[TBE_EDITOR.formname][elementName+'_list'];
 				if (!form) {
 						// special treatment for IRRE fields:
 					var tempObj = document[TBE_EDITOR.formname][elementName];
-					if (tempObj && Element.hasClassName(tempObj, 'inlineRecord')) {
+					if (tempObj && (Element.hasClassName(tempObj, 'inlineRecord') || Element.hasClassName(tempObj, 'treeRecord'))) {
 						form = tempObj.value ? tempObj.value.split(',') : [];
+						numberOfElements = form.length;
+					}
+
+				} else {
+						// special treatment for file uploads
+					var tempObj = document[TBE_EDITOR.formname][elementName.replace(/^data/, 'data_files')];
+					numberOfElements = form.length;
+
+					if (tempObj && tempObj.type == 'file' && tempObj.value) {
+						numberOfElements++; // Add new uploaded file to the number of elements
 					}
 				}
-				if (!TBE_EDITOR.checkRange(form, elementData.range[0], elementData.range[1])) {
+
+				if (!TBE_EDITOR.checkRange(numberOfElements, elementData.range[0], elementData.range[1])) {
 					result = 0;
 					if (autoNotify) {
 						TBE_EDITOR.setImage('req_'+elementData.rangeImg, TBE_EDITOR.images.req);
@@ -320,10 +341,6 @@ var TBE_EDITOR = {
 			return true;
 		}
 	},
-	setHiddenContent: function(RTEcontent,theField) {
-		document[TBE_EDITOR.formname][theField].value = RTEcontent;
-		alert(document[TBE_EDITOR.formname][theField].value);
-	},
 	fieldChanged_fName: function(fName,el) {
 		var idx=2+TBE_EDITOR.prependFormFieldNamesCnt;
 		var table = TBE_EDITOR.split(fName, "[", idx);
@@ -397,11 +414,6 @@ var TBE_EDITOR = {
 	 */
 	checkSubmit: function(sendAlert) {
 		var funcIndex, funcMax, funcRes;
-		if (TBE_EDITOR.checkLoginTimeout() && confirm(TBE_EDITOR.labels.refresh_login)) {
-			vHWin=window.open(TBE_EDITOR.backPath+'login_frameset.php?','relogin','height=300,width=400,status=0,menubar=0');
-			vHWin.focus();
-			return false;
-		}
 		var OK=1;
 
 		// $this->additionalJS_submit:
@@ -432,8 +444,13 @@ var TBE_EDITOR = {
 			return false;
 		}
 	},
-	checkRange: function(el,lower,upper) {
-		if (el && el.length>=lower && el.length<=upper) {
+	checkRange: function(numberOfElements, lower, upper) {
+			// for backwards compatibility, check if we're dealing with an element as first parameter
+		if(typeof numberOfElements == 'object') {
+			numberOfElements = numberOfElements.length;
+		}
+
+		if (numberOfElements >= lower && numberOfElements <= upper) {
 			return true;
 		} else {
 			return false;
@@ -463,7 +480,7 @@ var TBE_EDITOR = {
 	},
 	submitForm: function() {
 		if (TBE_EDITOR.doSaveFieldName) {
-			document[TBE_EDITOR.formname][TBE_EDITOR.doSaveFieldName].value=1;			
+			document[TBE_EDITOR.formname][TBE_EDITOR.doSaveFieldName].value=1;
 		}
 		document[TBE_EDITOR.formname].submit();
 	},
@@ -480,22 +497,6 @@ var TBE_EDITOR = {
 		if(ePos == -1) { ePos = theStr.length; }
 		return (theStr.substring(sPos+lengthOfDelim,ePos));
 	},
-	palUrl: function(inData,fieldList,fieldNum,table,uid,isOnFocus) {
-		var url = TBE_EDITOR.backPath+'alt_palette.php?inData='+inData+'&formName='+TBE_EDITOR.formnameUENC+'&prependFormFieldNames='+TBE_EDITOR.prependFormFieldNamesUENC;
-		var field = "";
-		var theField="";
-		for (var a=0; a<fieldNum;a++)	{
-			field = TBE_EDITOR.split(fieldList, ",", a+1);
-			theField = TBE_EDITOR.prependFormFieldNames+'['+table+']['+uid+']['+field+']';
-			if (document[TBE_EDITOR.formname][theField]) url+="&rec["+field+"]="+TBE_EDITOR.rawurlencode(document[TBE_EDITOR.formname][theField].value);
-		}
-		if (top.topmenuFrame)	{
-			top.topmenuFrame.location.href = url+"&backRef="+(top.content.list_frame ? (top.content.list_frame.view_frame ? "top.content.list_frame.view_frame" : "top.content.list_frame") : "top.content");
-		} else if (!isOnFocus) {
-			var vHWin=window.open(url,"palette","height=300,width=200,status=0,menubar=0,scrollbars=1");
-			vHWin.focus();
-		}
-	},
 	curSelected: function(theField)	{
 		var fObjSel = document[TBE_EDITOR.formname][theField];
 		var retVal="";
@@ -514,11 +515,7 @@ var TBE_EDITOR = {
 	rawurlencode: function(str,maxlen) {
 		var output = str;
 		if (maxlen)	output = output.substr(0,200);
-		output = escape(output);
-		output = TBE_EDITOR.str_replace("*","%2A", output);
-		output = TBE_EDITOR.str_replace("+","%2B", output);
-		output = TBE_EDITOR.str_replace("/","%2F", output);
-		output = TBE_EDITOR.str_replace("@","%40", output);
+		output = encodeURIComponent(output);
 		return output;
 	},
 	str_replace: function(match,replace,string) {
@@ -538,18 +535,34 @@ var TBE_EDITOR = {
 	},
 	toggle_display_states: function(id, state_1, state_2) {
 		var node = document.getElementById(id);
-		if (node) {	
+		if (node) {
 			switch (node.style.display) {
 				case state_1:
 					node.style.display = state_2;
 					break;
 				case state_2:
-					node.style.display = state_1; 
+					node.style.display = state_1;
 					break;
 			}
 		}
 		return false;
-	}	
+	},
+
+	/**
+	 * Determines backend path to be used for e.g. ajax.php
+	 * @return string
+	 */
+	getBackendPath: function() {
+		var backendPath = '';
+		if (TYPO3) {
+			if (TYPO3.configuration && TYPO3.configuration.PATH_typo3) {
+				backendPath = TYPO3.configuration.PATH_typo3;
+			} else if (TYPO3.settings && TYPO3.settings.PATH_typo3) {
+				backendPath = TYPO3.settings.PATH_typo3;
+			}
+		}
+		return backendPath;
+	}
 };
 
 function typoSetup	() {
@@ -575,7 +588,6 @@ var TBE_EDITOR_initRequired = TBE_EDITOR.initRequired;
 var TBE_EDITOR_setImage = TBE_EDITOR.setImage;
 var TBE_EDITOR_submitForm = TBE_EDITOR.submitForm;
 var TBE_EDITOR_split = TBE_EDITOR.split;
-var TBE_EDITOR_palUrl = TBE_EDITOR.palUrl;
 var TBE_EDITOR_curSelected = TBE_EDITOR.curSelected;
 var TBE_EDITOR_rawurlencode = TBE_EDITOR.rawurlencode;
 var TBE_EDITOR_str_replace = TBE_EDITOR.str_replace;
