@@ -2,7 +2,7 @@
 /***************************************************************
 *  Copyright notice
 *
-*  (c) 1999-2008 Kasper Skaarhoj (kasperYYYY@typo3.com)
+*  (c) 1999-2011 Kasper Skårhøj (kasperYYYY@typo3.com)
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
@@ -27,75 +27,10 @@
 /**
  * This script contains the parent class, 'pibase', providing an API with the most basic methods for frontend plugins
  *
- * $Id: class.tslib_pibase.php 5650 2009-06-28 11:19:39Z benni $
- * Revised for TYPO3 3.6 June/2003 by Kasper Skaarhoj
+ * Revised for TYPO3 3.6 June/2003 by Kasper Skårhøj
  * XHTML compliant
  *
- * @author	Kasper Skaarhoj <kasperYYYY@typo3.com>
- */
-/**
- * [CLASS/FUNCTION INDEX of SCRIPT]
- *
- *
- *
- *  132: class tslib_pibase
- *
- *              SECTION: Init functions
- *  214:     function tslib_pibase()
- *  240:     function pi_setPiVarDefaults()
- *
- *              SECTION: Link functions
- *  277:     function pi_getPageLink($id,$target='',$urlParameters=array())
- *  293:     function pi_linkToPage($str,$id,$target='',$urlParameters=array())
- *  308:     function pi_linkTP($str,$urlParameters=array(),$cache=0,$altPageId=0)
- *  331:     function pi_linkTP_keepPIvars($str,$overrulePIvars=array(),$cache=0,$clearAnyway=0,$altPageId=0)
- *  355:     function pi_linkTP_keepPIvars_url($overrulePIvars=array(),$cache=0,$clearAnyway=0,$altPageId=0)
- *  373:     function pi_list_linkSingle($str,$uid,$cache=FALSE,$mergeArr=array(),$urlOnly=FALSE,$altPageId=0)
- *  401:     function pi_openAtagHrefInJSwindow($str,$winName='',$winParams='width=670,height=500,status=0,menubar=0,scrollbars=1,resizable=1')
- *
- *              SECTION: Functions for listing, browsing, searching etc.
- *  456:     function pi_list_browseresults($showResultCount=1,$tableParams='',$wrapArr=array(), $pointerName = 'pointer', $hscText = TRUE)
- *  618:     function pi_list_searchBox($tableParams='')
- *  649:     function pi_list_modeSelector($items=array(),$tableParams='')
- *  687:     function pi_list_makelist($res,$tableParams='')
- *  722:     function pi_list_row($c)
- *  734:     function pi_list_header()
- *
- *              SECTION: Stylesheet, CSS
- *  765:     function pi_getClassName($class)
- *  777:     function pi_classParam($class)
- *  791:     function pi_setClassStyle($class,$data,$selector='')
- *  802:     function pi_wrapInBaseClass($str)
- *
- *              SECTION: Frontend editing: Edit panel, edit icons
- *  858:     function pi_getEditPanel($row='',$tablename='',$label='',$conf=Array())
- *  900:     function pi_getEditIcon($content,$fields,$title='',$row='',$tablename='',$oConf=array())
- *
- *              SECTION: Localization, locallang functions
- *  947:     function pi_getLL($key,$alt='',$hsc=FALSE)
- *  970:     function pi_loadLL()
- *
- *              SECTION: Database, queries
- * 1048:     function pi_list_query($table,$count=0,$addWhere='',$mm_cat='',$groupBy='',$orderBy='',$query='',$returnQueryArray=FALSE)
- * 1140:     function pi_exec_query($table,$count=0,$addWhere='',$mm_cat='',$groupBy='',$orderBy='',$query='')
- * 1155:     function pi_getRecord($table,$uid,$checkPage=0)
- * 1166:     function pi_getPidList($pid_list,$recursive=0)
- * 1191:     function pi_prependFieldsWithTable($table,$fieldList)
- * 1211:     function pi_getCategoryTableContents($table,$pid,$whereClause='',$groupBy='',$orderBy='',$limit='')
- *
- *              SECTION: Various
- * 1255:     function pi_isOnlyFields($fList,$lowerThan=-1)
- * 1275:     function pi_autoCache($inArray)
- * 1306:     function pi_RTEcssText($str)
- *
- *              SECTION: FlexForms related functions
- * 1328:     function pi_initPIflexForm($field='pi_flexform')
- * 1346:     function pi_getFFvalue($T3FlexForm_array,$fieldName,$sheet='sDEF',$lang='lDEF',$value='vDEF')
- * 1363:     function pi_getFFvalueFromSheetArray($sheetArray,$fieldNameArr,$value)
- *
- * TOTAL FUNCTIONS: 35
- * (This index is automatically created/updated by the extension "extdeveval")
- *
+ * @author	Kasper Skårhøj <kasperYYYY@typo3.com>
  */
 
 
@@ -114,7 +49,7 @@
  * This class contains functions which assists these plugins in creating lists, searching, displaying menus, page-browsing (next/previous/1/2/3) and handling links.
  * Functions are all prefixed "pi_" which is reserved for this class. Those functions can of course be overridden in the extension classes (that is the point...)
  *
- * @author	Kasper Skaarhoj <kasperYYYY@typo3.com>
+ * @author	Kasper Skårhøj <kasperYYYY@typo3.com>
  * @package TYPO3
  * @subpackage tslib
  */
@@ -205,11 +140,11 @@ class tslib_pibase {
 	 *
 	 * @return	void
 	 */
-	function tslib_pibase()	{
+	function __construct()	{
 
 			// Setting piVars:
 		if ($this->prefixId)	{
-			$this->piVars = t3lib_div::GParrayMerged($this->prefixId);
+			$this->piVars = t3lib_div::_GPmerged($this->prefixId);
 
 				// cHash mode check
 				// IMPORTANT FOR CACHED PLUGINS (USER cObject): As soon as you generate cached plugin output which depends on parameters (eg. seeing the details of a news item) you MUST check if a cHash value is set.
@@ -218,14 +153,27 @@ class tslib_pibase {
 				$GLOBALS['TSFE']->reqCHash();
 			}
 		}
-		if ($GLOBALS['TSFE']->config['config']['language'])	{
+		if (!empty($GLOBALS['TSFE']->config['config']['language'])) {
 			$this->LLkey = $GLOBALS['TSFE']->config['config']['language'];
-			if ($GLOBALS['TSFE']->config['config']['language_alt'])	{
+			if (!empty($GLOBALS['TSFE']->config['config']['language_alt'])) {
 				$this->altLLkey = $GLOBALS['TSFE']->config['config']['language_alt'];
 			}
 		}
 	}
 
+	/**
+	 * Compatibility constructor.
+	 *
+	 * @deprecated since TYPO3 4.6 and will be removed in TYPO3 4.8. Use __construct() instead.
+	 */
+	public function tslib_pibase() {
+		t3lib_div::logDeprecatedFunction();
+			// Note: we cannot call $this->__construct() here because it would call the derived class constructor and cause recursion
+			// This code uses official PHP behavior (http://www.php.net/manual/en/language.oop5.basic.php) when $this in the
+			// statically called non-static method inherits $this from the caller's scope.
+		tslib_pibase::__construct();
+	}
+
 	/**
 	 * If internal TypoScript property "_DEFAULT_PI_VARS." is set then it will merge the current $this->piVars array onto these default values.
 	 *
@@ -304,7 +252,7 @@ class tslib_pibase {
 		$conf['useCacheHash'] = $this->pi_USER_INT_obj ? 0 : $cache;
 		$conf['no_cache'] = $this->pi_USER_INT_obj ? 0 : !$cache;
 		$conf['parameter'] = $altPageId ? $altPageId : ($this->pi_tmpPageId ? $this->pi_tmpPageId : $GLOBALS['TSFE']->id);
-		$conf['additionalParams'] = $this->conf['parent.']['addParams'].t3lib_div::implodeArrayForUrl('',$urlParameters,'',1).$this->pi_moreParams;
+		$conf['additionalParams'] = $this->conf['parent.']['addParams'].t3lib_div::implodeArrayForUrl('', $urlParameters, '', TRUE).$this->pi_moreParams;
 
 		return $this->cObj->typoLink($str, $conf);
 	}
@@ -359,7 +307,7 @@ class tslib_pibase {
 	 * @param	integer		UID of the record for which to display details (basically this will become the value of [showUid]
 	 * @param	boolean		See pi_linkTP_keepPIvars
 	 * @param	array		Array of values to override in the current piVars. Same as $overrulePIvars in pi_linkTP_keepPIvars
-	 * @param	boolean		If true, only the URL is returned, not a full link
+	 * @param	boolean		If TRUE, only the URL is returned, not a full link
 	 * @param	integer		Alternative page ID for the link. (By default this function links to the SAME page!)
 	 * @return	string		The input string wrapped in <a> tags
 	 * @see pi_linkTP(), pi_linkTP_keepPIvars()
@@ -393,7 +341,7 @@ class tslib_pibase {
 	 * @return	string		The processed input string, modified IF a <a> tag was found
 	 */
 	function pi_openAtagHrefInJSwindow($str,$winName='',$winParams='width=670,height=500,status=0,menubar=0,scrollbars=1,resizable=1')	{
-		if (eregi('(.*)(<a[^>]*>)(.*)',$str,$match))	{
+		if (preg_match('/(.*)(<a[^>]*>)(.*)/i',$str,$match))	{
 			$aTagContent = t3lib_div::get_tag_attributes($match[2]);
 			$match[2]='<a href="#" onclick="'.
 				htmlspecialchars('vHWin=window.open(\''.$GLOBALS['TSFE']->baseUrlWrap($aTagContent['href']).'\',\''.($winName?$winName:md5($aTagContent['href'])).'\',\''.$winParams.'\');vHWin.focus();return false;').
@@ -443,9 +391,10 @@ class tslib_pibase {
 	 * @param	array		Array with elements to overwrite the default $wrapper-array.
 	 * @param	string		varname for the pointer.
 	 * @param	boolean		enable htmlspecialchars() for the pi_getLL function (set this to FALSE if you want f.e use images instead of text for links like 'previous' and 'next').
-	 * @return	string		Output HTML-Table, wrapped in <div>-tags with a class attribute (if $wrapArr is not passed,
+	 * @param   boolean     forces the output of the page browser if you set this option to "TRUE" (otherwise it's only drawn if enough entries are available)
+ 	 * @return	string		Output HTML-Table, wrapped in <div>-tags with a class attribute (if $wrapArr is not passed,
 	 */
-	function pi_list_browseresults($showResultCount=1, $tableParams='', $wrapArr=array(), $pointerName='pointer', $hscText=TRUE)	{
+	function pi_list_browseresults($showResultCount=1, $tableParams='', $wrapArr=array(), $pointerName='pointer', $hscText=TRUE, $forceOutput=FALSE) {
 
 		// example $wrapArr-array how it could be traversed from an extension
 		/* $wrapArr = array(
@@ -461,11 +410,15 @@ class tslib_pibase {
 			// Initializing variables:
 		$pointer = intval($this->piVars[$pointerName]);
 		$count = intval($this->internal['res_count']);
-		$results_at_a_time = t3lib_div::intInRange($this->internal['results_at_a_time'],1,1000);
+		$results_at_a_time = t3lib_utility_Math::forceIntegerInRange($this->internal['results_at_a_time'],1,1000);
 		$totalPages = ceil($count/$results_at_a_time);
-		$maxPages = t3lib_div::intInRange($this->internal['maxPages'],1,100);
+		$maxPages = t3lib_utility_Math::forceIntegerInRange($this->internal['maxPages'],1,100);
 		$pi_isOnlyFields = $this->pi_isOnlyFields($this->pi_isOnlyFields);
 
+		if (!$forceOutput && $count <= $results_at_a_time) {
+			return '';
+		}
+
 			// $showResultCount determines how the results of the pagerowser will be shown.
 			// If set to 0: only the result-browser will be shown
 			//	 		 1: (default) the text "Displaying results..." and the result-browser will be shown.
@@ -483,7 +436,7 @@ class tslib_pibase {
 				$pagefloat = ceil(($maxPages - 1)/2);
 			} else {
 				// pagefloat set as integer. 0 = left, value >= $this->internal['maxPages'] = right
-				$pagefloat = t3lib_div::intInRange($this->internal['pagefloat'],-1,$maxPages-1);
+				$pagefloat = t3lib_utility_Math::forceIntegerInRange($this->internal['pagefloat'],-1,$maxPages-1);
 			}
 		} else {
 			$pagefloat = -1; // pagefloat disabled
@@ -512,14 +465,14 @@ class tslib_pibase {
 				$firstPage = max(0,$lastPage-$maxPages);
 			} else {
 				$firstPage = 0;
-				$lastPage = t3lib_div::intInRange($totalPages,1,$maxPages);
+				$lastPage = t3lib_utility_Math::forceIntegerInRange($totalPages,1,$maxPages);
 			}
 			$links=array();
 
 				// Make browse-table/links:
 			if ($showFirstLast) { // Link to first page
 				if ($pointer>0)	{
-					$links[]=$this->cObj->wrap($this->pi_linkTP_keepPIvars($this->pi_getLL('pi_list_browseresults_first','<< First',$hscText),array($pointerName => null),$pi_isOnlyFields),$wrapper['inactiveLinkWrap']);
+					$links[]=$this->cObj->wrap($this->pi_linkTP_keepPIvars($this->pi_getLL('pi_list_browseresults_first','<< First',$hscText),array($pointerName => NULL),$pi_isOnlyFields),$wrapper['inactiveLinkWrap']);
 				} else {
 					$links[]=$this->cObj->wrap($this->pi_getLL('pi_list_browseresults_first','<< First',$hscText),$wrapper['disabledLinkWrap']);
 				}
@@ -561,7 +514,7 @@ class tslib_pibase {
 					$links[]=$this->cObj->wrap($this->pi_getLL('pi_list_browseresults_last','Last >>',$hscText),$wrapper['disabledLinkWrap']);
 				}
 			}
-			$theLinks = $this->cObj->wrap(implode(chr(10),$links),$wrapper['browseLinksWrap']);
+			$theLinks = $this->cObj->wrap(implode(LF,$links),$wrapper['browseLinksWrap']);
 		} else {
 			$theLinks = '';
 		}
@@ -640,8 +593,7 @@ class tslib_pibase {
 	 */
 	function pi_list_modeSelector($items=array(),$tableParams='')	{
 		$cells=array();
-		reset($items);
-		while(list($k,$v)=each($items))	{
+		foreach ($items as $k => $v) {
 			$cells[]='
 					<td'.($this->piVars['mode']==$k?$this->pi_classParam('modeSelector-SCell'):'').'><p>'.
 				$this->pi_linkTP_keepPIvars(htmlspecialchars($v),array('mode'=>$k),$this->pi_isOnlyFields($this->pi_isOnlyFields)).
@@ -778,20 +730,6 @@ class tslib_pibase {
 		return ' class="'.trim($output).'"';
 	}
 
-	/**
-	 * Sets CSS style-data for the $class-suffix (prefixed by pi_getClassName())
-	 *
-	 * @param	string		$class: Class suffix, see pi_getClassName
-	 * @param	string		$data: CSS data
-	 * @param	string		If $selector is set to any CSS selector, eg 'P' or 'H1' or 'TABLE' then the style $data will regard those HTML-elements only
-	 * @return	void
-	 * @deprecated		I think this function should not be used (and probably isn't used anywhere). It was a part of a concept which was left behind quite quickly.
-	 * @private
-	 */
-	function pi_setClassStyle($class,$data,$selector='')	{
-		$GLOBALS['TSFE']->setCSS($this->pi_getClassName($class).($selector?' '.$selector:''),'.'.$this->pi_getClassName($class).($selector?' '.$selector:'').' {'.$data.'}');
-	}
-
 	/**
 	 * Wraps the input string in a <div> tag with the class attribute set to the prefixId.
 	 * All content returned from your plugins should be returned through this function so all content from your plugin is encapsulated in a <div>-tag nicely identifying the content of your plugin.
@@ -852,7 +790,7 @@ class tslib_pibase {
 	 * @param	string		Table name
 	 * @param	string		A label to show with the panel.
 	 * @param	array		TypoScript parameters to pass along to the EDITPANEL content Object that gets rendered. The property "allow" WILL get overridden/set though.
-	 * @return	string		Returns false/blank if no BE User login and of course if the panel is not shown for other reasons. Otherwise the HTML for the panel (a table).
+	 * @return	string		Returns FALSE/blank if no BE User login and of course if the panel is not shown for other reasons. Otherwise the HTML for the panel (a table).
 	 * @see tslib_cObj::EDITPANEL()
 	 */
 	function pi_getEditPanel($row='',$tablename='',$label='',$conf=Array())	{
@@ -941,55 +879,82 @@ class tslib_pibase {
 	 *
 	 * @param	string		The key from the LOCAL_LANG array for which to return the value.
 	 * @param	string		Alternative string to return IF no value is found set for the key, neither for the local language nor the default.
-	 * @param	boolean		If true, the output label is passed through htmlspecialchars()
+	 * @param	boolean		If TRUE, the output label is passed through htmlspecialchars()
 	 * @return	string		The value from LOCAL_LANG.
 	 */
-	function pi_getLL($key,$alt='',$hsc=FALSE)	{
-			// The "from" charset of csConv() is only set for strings from TypoScript via _LOCAL_LANG
-		if (isset($this->LOCAL_LANG[$this->LLkey][$key]))	{
-			$word = $GLOBALS['TSFE']->csConv($this->LOCAL_LANG[$this->LLkey][$key], $this->LOCAL_LANG_charset[$this->LLkey][$key]);
-		} elseif ($this->altLLkey && isset($this->LOCAL_LANG[$this->altLLkey][$key]))	{
-			$word = $GLOBALS['TSFE']->csConv($this->LOCAL_LANG[$this->altLLkey][$key], $this->LOCAL_LANG_charset[$this->altLLkey][$key]);
-		} elseif (isset($this->LOCAL_LANG['default'][$key]))	{
-			$word = $this->LOCAL_LANG['default'][$key];	// No charset conversion because default is english and thereby ASCII
+	public function pi_getLL($key, $alternativeLabel = '', $hsc = FALSE) {
+		if (isset($this->LOCAL_LANG[$this->LLkey][$key][0]['target'])) {
+
+				// The "from" charset of csConv() is only set for strings from TypoScript via _LOCAL_LANG
+			if (isset($this->LOCAL_LANG_charset[$this->LLkey][$key])) {
+				$word = $GLOBALS['TSFE']->csConv(
+					$this->LOCAL_LANG[$this->LLkey][$key][0]['target'],
+					$this->LOCAL_LANG_charset[$this->LLkey][$key]
+				);
+			} else {
+				$word = $this->LOCAL_LANG[$this->LLkey][$key][0]['target'];
+			}
+		} elseif ($this->altLLkey && isset($this->LOCAL_LANG[$this->altLLkey][$key][0]['target'])) {
+
+				// The "from" charset of csConv() is only set for strings from TypoScript via _LOCAL_LANG
+			if (isset($this->LOCAL_LANG_charset[$this->altLLkey][$key])) {
+				$word = $GLOBALS['TSFE']->csConv(
+					$this->LOCAL_LANG[$this->altLLkey][$key][0]['target'],
+					$this->LOCAL_LANG_charset[$this->altLLkey][$key]
+				);
+			} else {
+				$word = $this->LOCAL_LANG[$this->altLLkey][$key][0]['target'];
+			}
+		} elseif (isset($this->LOCAL_LANG['default'][$key][0]['target'])) {
+
+				// Get default translation (without charset conversion, english)
+			$word = $this->LOCAL_LANG['default'][$key][0]['target'];
 		} else {
-			$word = $this->LLtestPrefixAlt.$alt;
+
+				// Return alternative string or empty
+			$word = (isset($this->LLtestPrefixAlt)) ? $this->LLtestPrefixAlt . $alternativeLabel : $alternativeLabel;
 		}
 
-		$output = $this->LLtestPrefix.$word;
-		if ($hsc)	$output = htmlspecialchars($output);
+		$output = (isset($this->LLtestPrefix)) ? $this->LLtestPrefix . $word : $word;
+
+		if ($hsc) {
+			$output = htmlspecialchars($output);
+		}
 
 		return $output;
 	}
 
 	/**
-	 * Loads local-language values by looking for a "locallang.php" file in the plugin class directory ($this->scriptRelPath) and if found includes it.
-	 * Also locallang values set in the TypoScript property "_LOCAL_LANG" are merged onto the values found in the "locallang.php" file.
+	 * Loads local-language values by looking for a "locallang" file in the
+	 * plugin class directory ($this->scriptRelPath) and if found includes it.
+	 * Also locallang values set in the TypoScript property "_LOCAL_LANG" are
+	 * merged onto the values found in the "locallang" file.
+	 * Supported file extensions xlf, xml, php
 	 *
-	 * @return	void
+	 * @return void
 	 */
-	function pi_loadLL()	{
-		if (!$this->LOCAL_LANG_loaded && $this->scriptRelPath)	{
-			$basePath = t3lib_extMgm::extPath($this->extKey).dirname($this->scriptRelPath).'/locallang.php';
+	public function pi_loadLL() {
+		if (!$this->LOCAL_LANG_loaded && $this->scriptRelPath) {
+			$basePath = 'EXT:' . $this->extKey . '/' . dirname($this->scriptRelPath) . '/locallang.xml';
 
 				// Read the strings in the required charset (since TYPO3 4.2)
-			$this->LOCAL_LANG = t3lib_div::readLLfile($basePath,$this->LLkey,$GLOBALS['TSFE']->renderCharset);
-			if ($this->altLLkey)	{
-				$tempLOCAL_LANG = t3lib_div::readLLfile($basePath,$this->altLLkey);
-				$this->LOCAL_LANG = array_merge(is_array($this->LOCAL_LANG) ? $this->LOCAL_LANG : array(),$tempLOCAL_LANG);
+			$this->LOCAL_LANG = t3lib_div::readLLfile($basePath,$this->LLkey, $GLOBALS['TSFE']->renderCharset);
+			if ($this->altLLkey) {
+				$this->LOCAL_LANG = t3lib_div::readLLfile($basePath,$this->altLLkey);
 			}
 
 				// Overlaying labels from TypoScript (including fictitious language keys for non-system languages!):
-			if (is_array($this->conf['_LOCAL_LANG.']))	{
-				reset($this->conf['_LOCAL_LANG.']);
-				while(list($k,$lA)=each($this->conf['_LOCAL_LANG.']))	{
-					if (is_array($lA))	{
-						$k = substr($k,0,-1);
-						foreach($lA as $llK => $llV)	{
-							if (!is_array($llV))	{
-								$this->LOCAL_LANG[$k][$llK] = $llV;
-									// For labels coming from the TypoScript (database) the charset is assumed to be "forceCharset" and if that is not set, assumed to be that of the individual system languages
-								$this->LOCAL_LANG_charset[$k][$llK] = $GLOBALS['TYPO3_CONF_VARS']['BE']['forceCharset'] ? $GLOBALS['TYPO3_CONF_VARS']['BE']['forceCharset'] : $GLOBALS['TSFE']->csConvObj->charSetArray[$k];
+			$confLL = $this->conf['_LOCAL_LANG.'];
+			if (is_array($confLL)) {
+				foreach ($confLL as $languageKey => $languageArray) {
+						// Don't process label if the langue is not loaded
+					$languageKey = substr($languageKey,0,-1);
+					if (is_array($languageArray) && is_array($this->LOCAL_LANG[$languageKey])) {
+							// Remove the dot after the language key
+						foreach ($languageArray as $labelKey => $labelValue) {
+							if (!is_array($labelValue))	{
+								$this->LOCAL_LANG[$languageKey][$labelKey][0]['target'] = $labelValue;
+								$this->LOCAL_LANG_charset[$languageKey][$labelKey] = 'utf-8';
 							}
 						}
 					}
@@ -1027,101 +992,6 @@ class tslib_pibase {
 	 *
 	 **************************/
 
-	/**
-	 * Makes a standard query for listing of records based on standard input vars from the 'browser' ($this->internal['results_at_a_time'] and $this->piVars['pointer']) and 'searchbox' ($this->piVars['sword'] and $this->internal['searchFieldList'])
-	 * Set $count to 1 if you wish to get a count(*) query for selecting the number of results.
-	 * Notice that the query will use $this->conf['pidList'] and $this->conf['recursive'] to generate a PID list within which to search for records.
-	 *
-	 * @param	string		See pi_exec_query()
-	 * @param	boolean		See pi_exec_query()
-	 * @param	string		See pi_exec_query()
-	 * @param	mixed		See pi_exec_query()
-	 * @param	string		See pi_exec_query()
-	 * @param	string		See pi_exec_query()
-	 * @param	string		See pi_exec_query()
-	 * @param	boolean		If set, the function will return the query not as a string but array with the various parts.
-	 * @return	mixed		The query build.
-	 * @access private
-	 * @deprecated		Use pi_exec_query() instead!
-	 */
-	function pi_list_query($table,$count=0,$addWhere='',$mm_cat='',$groupBy='',$orderBy='',$query='',$returnQueryArray=FALSE)	{
-
-			// Begin Query:
-		if (!$query)	{
-				// Fetches the list of PIDs to select from.
-				// TypoScript property .pidList is a comma list of pids. If blank, current page id is used.
-				// TypoScript property .recursive is a int+ which determines how many levels down from the pids in the pid-list subpages should be included in the select.
-			$pidList = $this->pi_getPidList($this->conf['pidList'],$this->conf['recursive']);
-			if (is_array($mm_cat))	{
-				$query='FROM '.$table.','.$mm_cat['table'].','.$mm_cat['mmtable'].chr(10).
-						' WHERE '.$table.'.uid='.$mm_cat['mmtable'].'.uid_local AND '.$mm_cat['table'].'.uid='.$mm_cat['mmtable'].'.uid_foreign '.chr(10).
-						(strcmp($mm_cat['catUidList'],'')?' AND '.$mm_cat['table'].'.uid IN ('.$mm_cat['catUidList'].')':'').chr(10).
-						' AND '.$table.'.pid IN ('.$pidList.')'.chr(10).
-						$this->cObj->enableFields($table).chr(10);	// This adds WHERE-clauses that ensures deleted, hidden, starttime/endtime/access records are NOT selected, if they should not! Almost ALWAYS add this to your queries!
-			} else {
-				$query='FROM '.$table.' WHERE pid IN ('.$pidList.')'.chr(10).
-						$this->cObj->enableFields($table).chr(10);	// This adds WHERE-clauses that ensures deleted, hidden, starttime/endtime/access records are NOT selected, if they should not! Almost ALWAYS add this to your queries!
-			}
-		}
-
-			// Split the "FROM ... WHERE" string so we get the WHERE part and TABLE names separated...:
-		list($TABLENAMES,$WHERE) = spliti('WHERE', trim($query), 2);
-		$TABLENAMES = trim(substr(trim($TABLENAMES),5));
-		$WHERE = trim($WHERE);
-
-			// Add '$addWhere'
-		if ($addWhere)	{$WHERE.=' '.$addWhere.chr(10);}
-
-			// Search word:
-		if ($this->piVars['sword'] && $this->internal['searchFieldList'])	{
-			$WHERE.=$this->cObj->searchWhere($this->piVars['sword'],$this->internal['searchFieldList'],$table).chr(10);
-		}
-
-		if ($count) {
-			$queryParts = array(
-				'SELECT' => 'count(*)',
-				'FROM' => $TABLENAMES,
-				'WHERE' => $WHERE,
-				'GROUPBY' => '',
-				'ORDERBY' => '',
-				'LIMIT' => ''
-			);
-		} else {
-				// Order by data:
-			if (!$orderBy && $this->internal['orderBy'])	{
-				if (t3lib_div::inList($this->internal['orderByList'],$this->internal['orderBy']))	{
-					$orderBy = 'ORDER BY '.$table.'.'.$this->internal['orderBy'].($this->internal['descFlag']?' DESC':'');
-				}
-			}
-
-				// Limit data:
-			$pointer = $this->piVars['pointer'];
-			$pointer = intval($pointer);
-			$results_at_a_time = t3lib_div::intInRange($this->internal['results_at_a_time'],1,1000);
-			$LIMIT = ($pointer*$results_at_a_time).','.$results_at_a_time;
-
-				// Add 'SELECT'
-			$queryParts = array(
-				'SELECT' => $this->pi_prependFieldsWithTable($table,$this->pi_listFields),
-				'FROM' => $TABLENAMES,
-				'WHERE' => $WHERE,
-				'GROUPBY' => $GLOBALS['TYPO3_DB']->stripGroupBy($groupBy),
-				'ORDERBY' => $GLOBALS['TYPO3_DB']->stripOrderBy($orderBy),
-				'LIMIT' => $LIMIT
-			);
-		}
-
-		$query = $GLOBALS['TYPO3_DB']->SELECTquery (
-					$queryParts['SELECT'],
-					$queryParts['FROM'],
-					$queryParts['WHERE'],
-					$queryParts['GROUPBY'],
-					$queryParts['ORDERBY'],
-					$queryParts['LIMIT']
-				);
-		return $returnQueryArray ? $queryParts : $query;
-	}
-
 	/**
 	 * Executes a standard SELECT query for listing of records based on standard input vars from the 'browser' ($this->internal['results_at_a_time'] and $this->piVars['pointer']) and 'searchbox' ($this->piVars['sword'] and $this->internal['searchFieldList'])
 	 * Set $count to 1 if you wish to get a count(*) query for selecting the number of results.
@@ -1136,9 +1006,73 @@ class tslib_pibase {
 	 * @param	string		If set, this is taken as the first part of the query instead of what is created internally. Basically this should be a query starting with "FROM [table] WHERE ... AND ...". The $addWhere clauses and all the other stuff is still added. Only the tables and PID selecting clauses are bypassed. May be deprecated in the future!
 	 * @return	pointer		SQL result pointer
 	 */
-	function pi_exec_query($table,$count=0,$addWhere='',$mm_cat='',$groupBy='',$orderBy='',$query='')	{
-		$queryParts = $this->pi_list_query($table,$count,$addWhere,$mm_cat,$groupBy,$orderBy,$query, TRUE);
+	function pi_exec_query($table, $count=0 ,$addWhere='' ,$mm_cat='' ,$groupBy='' ,$orderBy='', $query='') {
+        		// Begin Query:
+		if (!$query) {
+				// Fetches the list of PIDs to select from.
+				// TypoScript property .pidList is a comma list of pids. If blank, current page id is used.
+				// TypoScript property .recursive is a int+ which determines how many levels down from the pids in the pid-list subpages should be included in the select.
+			$pidList = $this->pi_getPidList($this->conf['pidList'], $this->conf['recursive']);
+			if (is_array($mm_cat)) {
+				$query = 'FROM ' . $table . ',' . $mm_cat['table'] . ',' . $mm_cat['mmtable'] . LF .
+						' WHERE ' . $table . '.uid=' . $mm_cat['mmtable'] . '.uid_local AND ' . $mm_cat['table'] . '.uid=' . $mm_cat['mmtable'] . '.uid_foreign ' . LF .
+						(strcmp($mm_cat['catUidList'],'') ? ' AND ' . $mm_cat['table'] . '.uid IN (' . $mm_cat['catUidList'] . ')' : '') . LF .
+						' AND ' . $table . '.pid IN (' . $pidList . ')' . LF .
+						$this->cObj->enableFields($table) . LF;	// This adds WHERE-clauses that ensures deleted, hidden, starttime/endtime/access records are NOT selected, if they should not! Almost ALWAYS add this to your queries!
+			} else {
+				$query='FROM ' . $table . ' WHERE pid IN (' . $pidList . ')' . LF .
+						$this->cObj->enableFields($table) . LF;	// This adds WHERE-clauses that ensures deleted, hidden, starttime/endtime/access records are NOT selected, if they should not! Almost ALWAYS add this to your queries!
+			}
+		}
 
+			// Split the "FROM ... WHERE" string so we get the WHERE part and TABLE names separated...:
+		list($TABLENAMES, $WHERE) = preg_split('/WHERE/i', trim($query), 2);
+		$TABLENAMES = trim(substr(trim($TABLENAMES), 5));
+		$WHERE = trim($WHERE);
+
+			// Add '$addWhere'
+		if ($addWhere) {
+			$WHERE .= ' ' . $addWhere . LF;
+		}
+
+			// Search word:
+		if ($this->piVars['sword'] && $this->internal['searchFieldList']) {
+			$WHERE .= $this->cObj->searchWhere($this->piVars['sword'], $this->internal['searchFieldList'], $table) . LF;
+		}
+
+		if ($count) {
+			$queryParts = array(
+				'SELECT' => 'count(*)',
+				'FROM' => $TABLENAMES,
+				'WHERE' => $WHERE,
+				'GROUPBY' => '',
+				'ORDERBY' => '',
+				'LIMIT' => ''
+			);
+		} else {
+				// Order by data:
+			if (!$orderBy && $this->internal['orderBy']) {
+				if (t3lib_div::inList($this->internal['orderByList'], $this->internal['orderBy'])) {
+					$orderBy = 'ORDER BY ' . $table . '.' . $this->internal['orderBy'] . ($this->internal['descFlag'] ? ' DESC' : '');
+				}
+			}
+
+				// Limit data:
+			$pointer = $this->piVars['pointer'];
+			$pointer = intval($pointer);
+			$results_at_a_time = t3lib_utility_Math::forceIntegerInRange($this->internal['results_at_a_time'], 1, 1000);
+			$LIMIT = ($pointer * $results_at_a_time) . ',' . $results_at_a_time;
+
+				// Add 'SELECT'
+			$queryParts = array(
+				'SELECT' => $this->pi_prependFieldsWithTable($table, $this->pi_listFields),
+				'FROM' => $TABLENAMES,
+				'WHERE' => $WHERE,
+				'GROUPBY' => $GLOBALS['TYPO3_DB']->stripGroupBy($groupBy),
+				'ORDERBY' => $GLOBALS['TYPO3_DB']->stripOrderBy($orderBy),
+				'LIMIT' => $LIMIT
+			);
+		}
 		return $GLOBALS['TYPO3_DB']->exec_SELECT_queryArray($queryParts);
 	}
 
@@ -1149,7 +1083,7 @@ class tslib_pibase {
 	 * @param	string		The table name
 	 * @param	integer		The uid of the record from the table
 	 * @param	boolean		If $checkPage is set, it's required that the page on which the record resides is accessible
-	 * @return	array		If record is found, an array. Otherwise false.
+	 * @return	array		If record is found, an array. Otherwise FALSE.
 	 */
 	function pi_getRecord($table,$uid,$checkPage=0)	{
 		return $GLOBALS['TSFE']->sys_page->checkRecord($table,$uid,$checkPage);
@@ -1167,13 +1101,13 @@ class tslib_pibase {
 			$pid_list = $GLOBALS['TSFE']->id;
 		}
 
-		$recursive = t3lib_div::intInRange($recursive, 0);
+		$recursive = t3lib_utility_Math::forceIntegerInRange($recursive, 0);
 
 		$pid_list_arr = array_unique(t3lib_div::trimExplode(',', $pid_list, 1));
 		$pid_list     = array();
 
 		foreach($pid_list_arr as $val) {
-			$val = t3lib_div::intInRange($val, 0);
+			$val = t3lib_utility_Math::forceIntegerInRange($val, 0);
 			if ($val) {
 				$_list = $this->cObj->getTreeList(-1 * $val, $recursive);
 				if ($_list) {
@@ -1195,7 +1129,7 @@ class tslib_pibase {
 	function pi_prependFieldsWithTable($table,$fieldList)	{
 		$list=t3lib_div::trimExplode(',',$fieldList,1);
 		$return=array();
-		while(list(,$listItem)=each($list))	{
+		foreach ($list as $listItem) {
 			$return[]=$table.'.'.$listItem;
 		}
 		return implode(',',$return);
@@ -1249,37 +1183,36 @@ class tslib_pibase {
 	 **************************/
 
 	/**
-	 * Returns true if the piVars array has ONLY those fields entered that is set in the $fList (commalist) AND if none of those fields value is greater than $lowerThan field if they are integers.
+	 * Returns TRUE if the piVars array has ONLY those fields entered that is set in the $fList (commalist) AND if none of those fields value is greater than $lowerThan field if they are integers.
 	 * Notice that this function will only work as long as values are integers.
 	 *
 	 * @param	string		List of fields (keys from piVars) to evaluate on
 	 * @param	integer		Limit for the values.
-	 * @return	boolean		Returns true (1) if conditions are met.
+	 * @return	boolean		Returns TRUE (1) if conditions are met.
 	 */
 	function pi_isOnlyFields($fList,$lowerThan=-1)	{
 		$lowerThan = $lowerThan==-1 ? $this->pi_lowerThan : $lowerThan;
 
 		$fList = t3lib_div::trimExplode(',',$fList,1);
 		$tempPiVars = $this->piVars;
-		while(list(,$k)=each($fList))	{
-			if (!t3lib_div::testInt($tempPiVars[$k]) || $tempPiVars[$k]<$lowerThan)		unset($tempPiVars[$k]);
+		foreach ($fList as $k) {
+			if (!t3lib_utility_Math::canBeInterpretedAsInteger($tempPiVars[$k]) || $tempPiVars[$k]<$lowerThan)		unset($tempPiVars[$k]);
 		}
 		if (!count($tempPiVars))	return 1;
 	}
 
 	/**
-	 * Returns true if the array $inArray contains only values allowed to be cached based on the configuration in $this->pi_autoCacheFields
+	 * Returns TRUE if the array $inArray contains only values allowed to be cached based on the configuration in $this->pi_autoCacheFields
 	 * Used by ->pi_linkTP_keepPIvars
 	 * This is an advanced form of evaluation of whether a URL should be cached or not.
 	 *
 	 * @param	array		An array with piVars values to evaluate
-	 * @return	boolean		Returns true (1) if conditions are met.
+	 * @return	boolean		Returns TRUE (1) if conditions are met.
 	 * @see pi_linkTP_keepPIvars()
 	 */
 	function pi_autoCache($inArray)	{
 		if (is_array($inArray))	{
-			reset($inArray);
-			while(list($fN,$fV)=each($inArray))	{
+			foreach ($inArray as $fN => $fV) {
 				if (!strcmp($inArray[$fN],''))	{
 					unset($inArray[$fN]);
 				} elseif (is_array($this->pi_autoCacheFields[$fN]))	{
@@ -1368,7 +1301,7 @@ class tslib_pibase {
 
 		$tempArr=$sheetArray;
 		foreach($fieldNameArr as $k => $v)	{
-			if (t3lib_div::testInt($v))	{
+			if (t3lib_utility_Math::canBeInterpretedAsInteger($v))	{
 				if (is_array($tempArr))	{
 					$c=0;
 					foreach($tempArr as $values)	{
@@ -1389,4 +1322,5 @@ class tslib_pibase {
 }
 
 // NO extension of class - does not make sense here.
+
 ?>
