@@ -2,7 +2,7 @@
 /***************************************************************
 *  Copyright notice
 *
-*  (c) 1999-2009 Kasper Skaarhoj (kasperYYYY@typo3.com)
+*  (c) 1999-2011 Kasper Skårhøj (kasperYYYY@typo3.com)
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
@@ -27,30 +27,10 @@
 /**
  * Contains the TMENU_LAYERS extension class, tslib_tmenu_layers
  *
- * $Id: tmenu_layers.php 5165 2009-03-09 18:28:59Z ohader $
- * Revised for TYPO3 3.6 June/2003 by Kasper Skaarhoj
+ * Revised for TYPO3 3.6 June/2003 by Kasper Skårhøj
  * XHTML compliant
  *
- * @author	Kasper Skaarhoj <kasperYYYY@typo3.com>
- */
-/**
- * [CLASS/FUNCTION INDEX of SCRIPT]
- *
- *
- *
- *   84: class tslib_tmenu_layers extends tslib_tmenu
- *  116:     function extProc_init()
- *  134:     function extProc_RO($key)
- *  150:     function extProc_beforeLinking($key)
- *  205:     function extProc_afterLinking($key)
- *  240:     function extProc_beforeAllWrap($item,$key)
- *  253:     function isSetIntval($in)
- *  262:     function extProc_finish ()
- *  444:     function extCalcBorderWithin($kind,$integer)
- *
- * TOTAL FUNCTIONS: 8
- * (This index is automatically created/updated by the extension "extdeveval")
- *
+ * @author	Kasper Skårhøj <kasperYYYY@typo3.com>
  */
 
 
@@ -75,10 +55,9 @@
  * Class extending tslib_tmenu for the creation of text based DHTML menus
  * NOTICE: The contents of this class is copied EXACTLY AS IS from gmenu_layers class! See notes in class (for BEGIN/END) and also 'diff.xmenu_layers.txt'
  *
- * @author	Kasper Skaarhoj <kasperYYYY@typo3.com>
+ * @author	Kasper Skårhøj <kasperYYYY@typo3.com>
  * @package TYPO3
  * @subpackage tslib
- * @link http://typo3.org/doc.0.html?&tx_extrepmgm_pi1[extUid]=270&tx_extrepmgm_pi1[tocEl]=385&cHash=648519dd66
  * @see diff.xmenu_layers.txt
  */
 class tslib_tmenu_layers extends tslib_tmenu {
@@ -114,7 +93,7 @@ class tslib_tmenu_layers extends tslib_tmenu {
 	 * @return	void
 	 */
 	function extProc_init()	{
-		$this->WMid = trim($this->mconf['layer_menu_id'])?trim($this->mconf['layer_menu_id']).'x':substr(md5(microtime()),0,6);	// NO '_' (underscore) in the ID!!! NN4 breaks!
+		$this->WMid = trim($this->mconf['layer_menu_id']) ? trim($this->mconf['layer_menu_id']) . 'x' : substr(md5('gl' . serialize($this->mconf)), 0, 6);
 
 		$GLOBALS['TSFE']->applicationData['GMENU_LAYERS']['WMid'][]=$this->WMid;
 		$this->WMtempStore = $GLOBALS['TSFE']->applicationData['GMENU_LAYERS']['WMid'];
@@ -180,7 +159,7 @@ GLV_restoreMenu["'.$this->WMid.'"] = "'.$this->WMactiveKey.'";
 				if ($this->mconf['ieSelectFix']) $this->I['linkHREF']['onMouseover']=$this->I['linkHREF']['onMouseover'].'GL_iframer(\''.$this->WMid.'\',\'Menu'.$this->WMid.$key.'\',true);';
 					// Added 120802; This means that everytime leaving a menuitem the layer should be shut down (and if the layer is hit in the meantime it is not though).
 					// This should happen only for items that are auto-hidden when not over and possibly only when a hide-timer is set. Problem is if the hide-timer is not set and we leave the main element, then the layer will be hidden unless we reach the layer before the timeout will happen and the menu hidden.
-				if (t3lib_div::intInRange($this->mconf['hideMenuWhenNotOver'],0,600) && $this->mconf['hideMenuTimer'])	{
+				if (t3lib_utility_Math::forceIntegerInRange($this->mconf['hideMenuWhenNotOver'],0,600) && $this->mconf['hideMenuTimer'])	{
 					$event.='GL_resetAll("'.$this->WMid.'");';
 				}
 				$this->I['linkHREF']['onMouseout'].=$event;
@@ -245,10 +224,10 @@ GLV_restoreMenu["'.$this->WMid.'"] = "'.$this->WMactiveKey.'";
 	}
 
 	/**
-	 * Returns true if different from ''  OR if intval()!=0
+	 * Returns TRUE if different from ''  OR if intval()!=0
 	 *
 	 * @param	string		Value to evaluate
-	 * @return	boolean		true if $in is different from ''  OR if intval()!=0
+	 * @return	boolean		TRUE if $in is different from ''  OR if intval()!=0
 	 */
 	function isSetIntval($in)	{
 		return $this->mconf['blankStrEqFalse'] ? strcmp($in,'') : intval($in);
@@ -337,8 +316,7 @@ GL'.$this->WMid.'_out("");';
 
 		$TEST='';
 		if (count($GLOBALS['TSFE']->applicationData['GMENU_LAYERS']['WMid']))	{
-			reset($GLOBALS['TSFE']->applicationData['GMENU_LAYERS']['WMid']);
-			while(list(,$mIdStr)=each($GLOBALS['TSFE']->applicationData['GMENU_LAYERS']['WMid']))	{
+			foreach ($GLOBALS['TSFE']->applicationData['GMENU_LAYERS']['WMid'] as $mIdStr) {
 				$this->WMhideCode.='
 GL_hideAll("'.$mIdStr.'");';
 				$this->WMrestoreScript.='
@@ -362,7 +340,7 @@ GLV_curLayerHeight["'.$this->WMid.'"]=0;
 GLV_curLayerX["'.$this->WMid.'"]=0;
 GLV_curLayerY["'.$this->WMid.'"]=0;
 GLV_menuOn["'.$this->WMid.'"] = null;
-GLV_gap["'.$this->WMid.'"]='.t3lib_div::intInRange($this->mconf['hideMenuWhenNotOver'],0,600).';
+GLV_gap["'.$this->WMid.'"]='.t3lib_utility_Math::forceIntegerInRange($this->mconf['hideMenuWhenNotOver'],0,600).';
 GLV_currentLayer["'.$this->WMid.'"] = null;
 GLV_currentROitem["'.$this->WMid.'"] = null;
 GLV_hasBeenOver["'.$this->WMid.'"]=0;
@@ -373,9 +351,9 @@ GLV_dontHideOnMouseUp["'.$this->WMid.'"] = '.($this->mconf['dontHideOnMouseUp']?
 GLV_dontFollowMouse["'.$this->WMid.'"] = '.($this->mconf['dontFollowMouse']?1:0).';
 GLV_date = new Date();
 GLV_timeout["'.$this->WMid.'"] = GLV_date.getTime();
-GLV_timeoutRef["'.$this->WMid.'"] = '.t3lib_div::intInRange($this->mconf['hideMenuTimer'],0,20000).';
+GLV_timeoutRef["'.$this->WMid.'"] = '.t3lib_utility_Math::forceIntegerInRange($this->mconf['hideMenuTimer'],0,20000).';
 GLV_menuXY["'.$this->WMid.'"] = new Array();
-'.implode(chr(10),$this->WMxyArray).'
+'.implode(LF,$this->WMxyArray).'
 '.$this->WMrestoreVars;
 
 		if ($this->mconf['freezeMouseover'])	{
@@ -384,14 +362,14 @@ GLV_menuXY["'.$this->WMid.'"] = new Array();
 function GL'.$this->WMid.'_over(mitm_id)	{
 	GL'.$this->WMid.'_out("");	// removes any old roll over state of an item. Needed for alwaysKeep and Opera browsers.
 	switch(mitm_id)	{
-'.implode(chr(10),$this->VMmouseoverActions).'
+'.implode(LF,$this->VMmouseoverActions).'
 	}
 	GLV_currentROitem["'.$this->WMid.'"]=mitm_id;
 }
 function GL'.$this->WMid.'_out(mitm_id)	{
 	if (!mitm_id)	mitm_id=GLV_currentROitem["'.$this->WMid.'"];
 	switch(mitm_id)	{
-'.implode(chr(10),$this->VMmouseoutActions).'
+'.implode(LF,$this->VMmouseoutActions).'
 	}
 }
 ';
@@ -399,7 +377,7 @@ function GL'.$this->WMid.'_out(mitm_id)	{
 		$GLOBALS["TSFE"]->JSCode.= '
 function GL'.$this->WMid.'_getMouse(e) {
 	if (GLV_menuOn["'.$this->WMid.'"]!=null && !GLV_dontFollowMouse["'.$this->WMid.'"]){
-'.implode(chr(10),$GLV_menuOn).'
+'.implode(LF,$GLV_menuOn).'
 	}
 	GL_mouseMoveEvaluate("'.$this->WMid.'");
 }
@@ -407,7 +385,7 @@ function GL'.$this->WMid.'_hideCode() {
 '.$this->WMhideCode.'
 }
 function GL'.$this->WMid.'_doTop(WMid,id) {
-'.trim(implode(chr(10),$DoTop)).'
+'.trim(implode(LF,$DoTop)).'
 }
 function GL'.$this->WMid.'_restoreMenu() {
 '.$this->WMrestoreScript.'
@@ -424,11 +402,13 @@ GLV_timeout_count++;
 ';
 		$GLOBALS['TSFE']->JSeventFuncCalls['onload']['GL_initLayers()']= 'GL_initLayers();';
 		$GLOBALS['TSFE']->JSeventFuncCalls['onload'][$this->WMid]=	'GL_restoreMenu("'.$this->WMid.'");';
-		$GLOBALS['TSFE']->JSeventFuncCalls['onmousemove']['GL_getMouse(e)']= 'GL_getMouse(e);';	// Should be called BEFORE any of the 'local' getMouse functions!
-		$GLOBALS['TSFE']->JSeventFuncCalls['onmousemove'][$this->WMid]= 'GL'.$this->WMid.'_getMouse(e);';
+		// Should be called BEFORE any of the 'local' getMouse functions!
+		// is put inside in a try catch block to avoid JS errors in IE
+		$GLOBALS['TSFE']->JSeventFuncCalls['onmousemove']['GL_getMouse(e)']= 'try{GL_getMouse(e);}catch(ex){};';
+		$GLOBALS['TSFE']->JSeventFuncCalls['onmousemove'][$this->WMid]= 'try{GL'.$this->WMid.'_getMouse(e);}catch(ex){};';
 		$GLOBALS['TSFE']->JSeventFuncCalls['onmouseup'][$this->WMid]= 'GL_mouseUp(\''.$this->WMid.'\',e);';
 
-		$GLOBALS['TSFE']->divSection.=implode($this->divLayers,chr(10)).chr(10);
+		$GLOBALS['TSFE']->divSection.=implode($this->divLayers,LF).LF;
 
 		return parent::extProc_finish();
 	}
@@ -438,7 +418,7 @@ GLV_timeout_count++;
 	 *
 	 * @param	string		Direction to test.
 	 * @param	integer		The boundary limit in the direction set by $kind. If set then a value is returned, otherwise blank.
-	 * @return	string		JavaScript string for correction of the layer position (if $integer is true)
+	 * @return	string		JavaScript string for correction of the layer position (if $integer is TRUE)
 	 * @see extProc_finish(), extProc_init()
 	 */
 	function extCalcBorderWithin($kind,$integer)	{
@@ -447,8 +427,14 @@ GLV_timeout_count++;
 				case 'right':
 				case 'bottom':
 					$add='';
-					if ($kind=='right')		{$add='GL_getObj(id).width'; $key = 'left';}
-					if ($kind=='bottom')	{$add='GL_getObj(id).height'; $key = 'top';}
+					if ($kind == 'right') {
+						$add = 'GL_getObj(id).width';
+						$key = 'left';
+					}
+					if ($kind == 'bottom') {
+						$add = 'GL_getObj(id).height';
+						$key = 'top';
+					}
 					$str = 'if (parseInt(GLV_menuOn["'.$this->WMid.'"].'.$key.')+'.$add.'>'.$integer.') GLV_menuOn["'.$this->WMid.'"].'.$key.'='.$integer.'-'.$add.';';
 				break;
 				default:
@@ -465,8 +451,8 @@ GLV_timeout_count++;
 
 $GLOBALS['TSFE']->tmpl->menuclasses.=',tmenu_layers';
 
-if (defined('TYPO3_MODE') && $TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['media/scripts/tmenu_layers.php'])	{
-	include_once($TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['media/scripts/tmenu_layers.php']);
+if (defined('TYPO3_MODE') && isset($GLOBALS['TYPO3_CONF_VARS'][TYPO3_MODE]['XCLASS']['media/scripts/tmenu_layers.php'])) {
+	include_once($GLOBALS['TYPO3_CONF_VARS'][TYPO3_MODE]['XCLASS']['media/scripts/tmenu_layers.php']);
 }
 
 ?>
\ No newline at end of file
