@@ -1,13 +1,13 @@
 <?php
 
 ########################################################################
-# Extension Manager/Repository config file for ext: "extra_page_cm_options"
+# Extension Manager/Repository config file for ext "extra_page_cm_options".
 #
-# Auto generated 23-04-2008 10:22
+# Auto generated 22-05-2012 11:27
 #
 # Manual updates:
-# Only the data in the array - anything else is removed by next write.
-# "version" and "dependencies" must not be touched!
+# Only the data in the array - everything else is removed by next
+# writing. "version" and "dependencies" must not be touched!
 ########################################################################
 
 $EM_CONF[$_EXTKEY] = array(
@@ -20,6 +20,7 @@ $EM_CONF[$_EXTKEY] = array(
 	'priority' => '',
 	'loadOrder' => '',
 	'module' => '',
+	'doNotLoadInFE' => 1,
 	'state' => 'stable',
 	'internal' => 0,
 	'uploadfolder' => 0,
@@ -32,18 +33,20 @@ $EM_CONF[$_EXTKEY] = array(
 	'author_company' => 'Curby Soft Multimedia',
 	'CGLcompliance' => '',
 	'CGLcompliance_note' => '',
-	'version' => '0.1.0',
-	'_md5_values_when_last_written' => 'a:4:{s:31:"class.tx_extrapagecmoptions.php";s:4:"e243";s:12:"ext_icon.gif";s:4:"b28d";s:14:"ext_tables.php";s:4:"ac39";s:13:"locallang.xml";s:4:"1351";}',
+	'version' => '4.7.1',
+	'_md5_values_when_last_written' => 'a:4:{s:31:"class.tx_extrapagecmoptions.php";s:4:"acf5";s:12:"ext_icon.gif";s:4:"955b";s:14:"ext_tables.php";s:4:"ac39";s:13:"locallang.xlf";s:4:"db7f";}',
 	'constraints' => array(
 		'depends' => array(
-			'php' => '5.1.0-0.0.0',
-			'typo3' => '4.2.0-4.2.99',
+			'php' => '5.3.0-0.0.0',
+			'typo3' => '4.7.0-0.0.0',
 		),
 		'conflicts' => array(
 		),
 		'suggests' => array(
 		),
 	),
+	'suggests' => array(
+	),
 );
 
 ?>
\ No newline at end of file
