@@ -2,7 +2,7 @@
 /***************************************************************
 *  Copyright notice
 *
-*  (c) 2001-2009 Kasper Skaarhoj (kasperYYYY@typo3.com)
+*  (c) 2001-2011 Kasper Skårhøj (kasperYYYY@typo3.com)
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
@@ -24,60 +24,7 @@
 /**
  * Module extension (addition to function menu) 'Indexed search' for the 'indexed_search' extension.
  *
- * @author    Kasper Skrhj <kasperYYYY@typo3.com>
- */
-/**
- * [CLASS/FUNCTION INDEX of SCRIPT]
- *
- *
- *
- *  106: class tx_indexedsearch_modfunc1 extends t3lib_extobjbase
- *  120:     function modMenu()
- *  144:     function main()
- *
- *              SECTION: Drawing table of indexed pages
- *  248:     function drawTableOfIndexedPages()
- *  299:     function indexed_info($data, $firstColContent)
- *  386:     function printPhashRow($row,$grouping=0,$extraGrListRows)
- *  527:     function printPhashRowHeader()
- *  582:     function returnNumberOfColumns()
- *
- *              SECTION: Details display, phash row
- *  618:     function showDetailsForPhash($phash)
- *  737:     function listWords($ftrows,$header, $stopWordBoxes=FALSE, $page='')
- *  787:     function listMetaphoneStat($ftrows,$header)
- *  824:     function linkWordDetails($string,$wid)
- *  836:     function linkMetaPhoneDetails($string,$metaphone)
- *  846:     function flagsMsg($flags)
- *
- *              SECTION: Details display, words / metaphone
- *  877:     function showDetailsForWord($wid)
- *  936:     function showDetailsForMetaphone($metaphone)
- *
- *              SECTION: Helper functions
- * 1007:     function printRemoveIndexed($phash,$alt)
- * 1020:     function printReindex($resultRow,$alt)
- * 1035:     function linkDetails($string,$phash)
- * 1044:     function linkList()
- * 1055:     function showPageDetails($string,$id)
- * 1065:     function printExtraGrListRows($extraGrListRows)
- * 1082:     function printRootlineInfo($row)
- * 1116:     function makeItemTypeIcon($it,$alt='')
- * 1141:     function utf8_to_currentCharset($string)
- *
- *              SECTION: Reindexing
- * 1173:     function reindexPhash($phash, $pageId)
- * 1227:     function getUidRootLineForClosestTemplate($id)
- *
- *              SECTION: SQL functions
- * 1270:     function removeIndexedPhashRow($phashList,$clearPageCache=1)
- * 1314:     function getGrListEntriesForPhash($phash,$gr_list)
- * 1334:     function processStopWords($stopWords)
- * 1354:     function processPageKeywords($pageKeywords, $pageUid)
- *
- * TOTAL FUNCTIONS: 30
- * (This index is automatically created/updated by the extension "extdeveval")
- *
+ * @author    Kasper Skårhøj <kasperYYYY@typo3.com>
  */
 
 
@@ -87,7 +34,7 @@ require_once(t3lib_extMgm::extPath('indexed_search').'class.indexer.php');
 /**
  * Indexing class for TYPO3 frontend
  *
- * @author	Kasper Skaarhoj <kasperYYYY@typo3.com>
+ * @author	Kasper Skårhøj <kasperYYYY@typo3.com>
  * @package TYPO3
  * @subpackage tx_indexedsearch
  */
@@ -97,6 +44,8 @@ class tx_indexedsearch_modfunc1 extends t3lib_extobjbase {
 	var $allPhashListed = array();		// phash values accumulations for link to clear all
 	var $external_parsers = array();	// External content parsers - objects set here with file extensions as keys.
 	var $iconFileNameCache = array();	// File extensions - icon map/cache.
+	var $indexerConfig = array();	// Indexer configuration, coming from $GLOBALS['TYPO3_CONF_VARS']['EXT']['extConf']['indexed_search']
+	var $enableMetaphoneSearch = FALSE;
 
 	/**
 	 * Indexer object
@@ -142,6 +91,12 @@ class tx_indexedsearch_modfunc1 extends t3lib_extobjbase {
 			// Return if no page id:
 		if ($this->pObj->id<=0)		return;
 
+			// Indexer configuration from Extension Manager interface:
+		$this->indexerConfig = unserialize($GLOBALS['TYPO3_CONF_VARS']['EXT']['extConf']['indexed_search']);
+
+			// Workaround: If the extension configuration was not updated yet, the value is not existing
+		$this->enableMetaphoneSearch = isset($this->indexerConfig['enableMetaphoneSearch']) ? ($this->indexerConfig['enableMetaphoneSearch'] ? TRUE : FALSE) : TRUE;
+
 			// Initialize max-list items
 		$this->maxListPerPage = t3lib_div::_GP('listALL') ? 100000 : 100;
 
@@ -166,7 +121,7 @@ class tx_indexedsearch_modfunc1 extends t3lib_extobjbase {
 			foreach($TYPO3_CONF_VARS['EXTCONF']['indexed_search']['external_parsers'] as $extension => $_objRef)	{
 				$this->external_parsers[$extension] = t3lib_div::getUserObj($_objRef);
 
-					// Init parser and if it returns false, unset its entry again:
+					// Init parser and if it returns FALSE, unset its entry again:
 				if (!$this->external_parsers[$extension]->softInit($extension))	{
 					unset($this->external_parsers[$extension]);
 				}
@@ -194,7 +149,7 @@ class tx_indexedsearch_modfunc1 extends t3lib_extobjbase {
 			$theOutput.=$this->pObj->doc->spacer(5);
 			$theOutput.=$this->pObj->doc->section('Details for a word:',$this->showDetailsForWord(t3lib_div::_GET('wid')),0,1);
 
-		} elseif (t3lib_div::_GET('metaphone'))	{
+		} elseif ($this->enableMetaphoneSearch && t3lib_div::_GET('metaphone')) {
 				// Show title / function menu:
 			$theOutput.=$this->pObj->doc->spacer(5);
 			$theOutput.=$this->pObj->doc->section('Details for metaphone value:',$this->showDetailsForMetaphone(t3lib_div::_GET('metaphone')),0,1);
@@ -206,14 +161,14 @@ class tx_indexedsearch_modfunc1 extends t3lib_extobjbase {
 
 		} else {	// Detail listings:
 				// Depth function menu:
-			$h_func = t3lib_BEfunc::getFuncMenu($this->pObj->id,'SET[type]',$this->pObj->MOD_SETTINGS['type'],$this->pObj->MOD_MENU['type'],'index.php');
-			$h_func.= t3lib_BEfunc::getFuncMenu($this->pObj->id,'SET[depth]',$this->pObj->MOD_SETTINGS['depth'],$this->pObj->MOD_MENU['depth'],'index.php');
+			$h_func = t3lib_BEfunc::getFuncMenu($this->pObj->id, 'SET[type]', $this->pObj->MOD_SETTINGS['type'], $this->pObj->MOD_MENU['type'], 'index.php');
+			$h_func .= t3lib_BEfunc::getFuncMenu($this->pObj->id, 'SET[depth]', $this->pObj->MOD_SETTINGS['depth'], $this->pObj->MOD_MENU['depth'], 'index.php');
 
 				// Show title / function menu:
-			$theOutput.=$this->pObj->doc->spacer(5);
-			$theOutput.=$this->pObj->doc->section($LANG->getLL('title'),$h_func,0,1);
+			$theOutput .= $this->pObj->doc->header($LANG->getLL('title'));
+			$theOutput .= $this->pObj->doc->section('', $h_func, 0, 1);
 
-			$theOutput.=$this->drawTableOfIndexedPages();
+			$theOutput .= $this->drawTableOfIndexedPages();
 		}
 
         return $theOutput;
@@ -264,7 +219,7 @@ class tx_indexedsearch_modfunc1 extends t3lib_extobjbase {
 			$code.= $this->indexed_info(
 						$data['row'],
 						$data['HTML'].
-							$this->showPageDetails(t3lib_div::fixed_lgd_cs($data['row']['title'], 20),$data['row']['uid'])
+							$this->showPageDetails(t3lib_BEfunc::getRecordTitlePrep($data['row']['title']), $data['row']['uid'])
 					);
 		}
 
@@ -295,7 +250,12 @@ class tx_indexedsearch_modfunc1 extends t3lib_extobjbase {
 
 			// Query:
 		$res = $GLOBALS['TYPO3_DB']->exec_SELECTquery(
-					'ISEC.*, IP.*, count(*) AS count_val',
+					'ISEC.phash_t3, ISEC.rl0, ISEC.rl1, ISEC.rl2, ISEC.page_id, ISEC.uniqid, ' .
+					'IP.phash, IP.phash_grouping, IP.cHashParams, IP.data_filename, IP.data_page_id, ' .
+					'IP.data_page_reg1, IP.data_page_type, IP.data_page_mp, IP.gr_list, IP.item_type, ' .
+					'IP.item_title, IP.item_description, IP.item_mtime, IP.tstamp, IP.item_size, ' .
+					'IP.contentHash, IP.crdate, IP.parsetime, IP.sys_language_uid, IP.item_crdate, ' .
+					'IP.externalUrl, IP.recordUid, IP.freeIndexUid, IP.freeIndexSetId, count(*) AS count_val',
 					'index_phash IP, index_section ISEC',
 					'IP.phash = ISEC.phash AND ISEC.page_id = '.intval($data['uid']),
 					'IP.phash,IP.phash_grouping,IP.cHashParams,IP.data_filename,IP.data_page_id,IP.data_page_reg1,IP.data_page_type,IP.data_page_mp,IP.gr_list,IP.item_type,IP.item_title,IP.item_description,IP.item_mtime,IP.tstamp,IP.item_size,IP.contentHash,IP.crdate,IP.parsetime,IP.sys_language_uid,IP.item_crdate,ISEC.phash,ISEC.phash_t3,ISEC.rl0,ISEC.rl1,ISEC.rl2,ISEC.page_id,ISEC.uniqid,IP.externalUrl,IP.recordUid,IP.freeIndexUid,IP.freeIndexSetId',
@@ -361,7 +321,7 @@ class tx_indexedsearch_modfunc1 extends t3lib_extobjbase {
 		while($row = $GLOBALS['TYPO3_DB']->sql_fetch_assoc($res))	{
 			$out.='
 				<tr class="typo3-red">
-					<td colspan="'.$this->returnNumberOfColumns().'"><b>Warning:</b> phash-row "'.$row['phash'].'" didn\'t have a representation in the index_section table!</td>
+					<td colspan="'.$this->returnNumberOfColumns().'"><strong>Warning:</strong> phash-row "'.$row['phash'].'" didn\'t have a representation in the index_section table!</td>
 				</tr>';
 			$this->allPhashListed[] = $row['phash'];
 		}
@@ -429,10 +389,13 @@ class tx_indexedsearch_modfunc1 extends t3lib_extobjbase {
 
 					// cHash parameters:
 				$arr = unserialize($row['cHashParams']);
-				if (is_array($arr))		{
-					$theCHash = $arr['cHash'];
-					unset($arr['cHash']);
+				if (!is_array($arr)) {
+					$arr = array(
+						'cHash' => $GLOBALS['LANG']->sL('LLL:EXT:lang/locallang_general.xml:LGL.error', TRUE)
+					);
 				}
+				$theCHash = $arr['cHash'];
+				unset($arr['cHash']);
 
 				if ($row['item_type'])	{	// pdf...
 					$lines[] = '<td>'.($arr['key'] ? 'Page '.$arr['key'] : '').'&nbsp;</td>';
@@ -459,14 +422,14 @@ class tx_indexedsearch_modfunc1 extends t3lib_extobjbase {
 				$lines[] = '<td>'.$cmdLinks.'</td>';
 
 					// Query:
-				$ftrows = $GLOBALS['TYPO3_DB']->exec_SELECTgetRows(
+				$ftrow = $GLOBALS['TYPO3_DB']->exec_SELECTgetSingleRow(
 							'*',
 							'index_fulltext',
 							'phash = '.intval($row['phash'])
 						);
 				$lines[] = '<td style="white-space: normal;">'.
-							htmlspecialchars(t3lib_div::fixed_lgd_cs($this->utf8_to_currentCharset($ftrows[0]['fulltextdata']),3000)).
-							'<hr/><em>Size: '.strlen($ftrows[0]['fulltextdata']).'</em>'.
+							htmlspecialchars(t3lib_div::fixed_lgd_cs($this->utf8_to_currentCharset($ftrow['fulltextdata']), 3000)) .
+							'<hr/><em>Size: ' . strlen($ftrow['fulltextdata']) . '</em>' .
 							'</td>';
 
 					// Query:
@@ -615,17 +578,16 @@ class tx_indexedsearch_modfunc1 extends t3lib_extobjbase {
 		$content = '';
 
 			// Selects the result row:
-		$ftrows = $GLOBALS['TYPO3_DB']->exec_SELECTgetRows(
+		$phashRecord = $GLOBALS['TYPO3_DB']->exec_SELECTgetSingleRow(
 					'*',
 					'index_phash',
 					'phash = '.intval($phash)
 				);
-		$phashRecord = $ftrows[0];
 
 			// If found, display:
 		if (is_array($phashRecord))	{
 			$content.= '<h4>phash row content:</h4>'.
-						$this->utf8_to_currentCharset(t3lib_div::view_array($phashRecord));
+						$this->utf8_to_currentCharset(t3lib_utility_Debug::viewArray($phashRecord));
 
 				// Getting debug information if any:
 			$ftrows = $GLOBALS['TYPO3_DB']->exec_SELECTgetRows(
@@ -639,12 +601,12 @@ class tx_indexedsearch_modfunc1 extends t3lib_extobjbase {
 				unset($debugInfo['lexer']);
 
 				$content.= '<h3>Debug information:</h3>'.
-						$this->utf8_to_currentCharset(t3lib_div::view_array($debugInfo));
+						$this->utf8_to_currentCharset(t3lib_utility_Debug::viewArray($debugInfo));
 
 				$content.= '<h4>Debug information / lexer splitting:</h4>'.
-						'<hr/><b>'.
+						'<hr/><strong>'.
 						$this->utf8_to_currentCharset($lexer).
-						'</b><hr/>';
+						'</strong><hr/>';
 			}
 
 
@@ -665,12 +627,14 @@ class tx_indexedsearch_modfunc1 extends t3lib_extobjbase {
 			$showStopWordCheckBox = $GLOBALS['BE_USER']->isAdmin();
 			$content.= $this->listWords($ftrows, 'All words found on page ('.count($ftrows).'):', $showStopWordCheckBox, $pageRec);
 
-				// Group metaphone hash:
-			$metaphone = array();
-			foreach($ftrows as $row)	{
-				$metaphone[$row['metaphone']][] = $row['baseword'];
+			if ($this->enableMetaphoneSearch) {
+					// Group metaphone hash:
+				$metaphone = array();
+				foreach ($ftrows as $row) {
+					$metaphone[$row['metaphone']][] = $row['baseword'];
+				}
+				$content .= $this->listMetaphoneStat($metaphone, 'Metaphone stats:');
 			}
-			$content.= $this->listMetaphoneStat($metaphone, 'Metaphone stats:');
 
 				// Finding top-20 on frequency for this phash:
 			$ftrows = $GLOBALS['TYPO3_DB']->exec_SELECTgetRows(
@@ -710,7 +674,7 @@ class tx_indexedsearch_modfunc1 extends t3lib_extobjbase {
 						'',
 						''
 					);
-			$content.= t3lib_div::view_array($ftrows);
+			$content .= t3lib_utility_Debug::viewArray($ftrows);
 
 				// Add go-back link:
 			$content = $this->linkList().$content.$this->linkList();
@@ -1000,9 +964,9 @@ class tx_indexedsearch_modfunc1 extends t3lib_extobjbase {
 	 * @return	string		HTML img-tag with link around.
 	 */
 	function printRemoveIndexed($phash,$alt)	{
-		return '<a href="'.htmlspecialchars(t3lib_div::linkThisScript(array('deletePhash'=>$phash))).'">'.
-				'<img src="'.$GLOBALS['BACK_PATH'].'gfx/garbage.gif" width="11" hspace="1" vspace="2" height="12" border="0" title="'.htmlspecialchars($alt).'" alt="" />'.
-				'</a>';
+		return '<a href="'.htmlspecialchars(t3lib_div::linkThisScript(array('deletePhash'=>$phash))).'" title="' . htmlspecialchars($alt) . '">' .
+				t3lib_iconWorks::getSpriteIcon('actions-edit-delete') .
+			'</a>';
 	}
 
 	/**
@@ -1015,7 +979,7 @@ class tx_indexedsearch_modfunc1 extends t3lib_extobjbase {
 	function printReindex($resultRow,$alt)	{
 		if ($resultRow['item_type'] && $resultRow['item_type']!=='0')	{
 			return '<a href="'.htmlspecialchars(t3lib_div::linkThisScript(array('reindex'=>$resultRow['phash'],'reindex_id'=>$resultRow['page_id']))).'">'.
-					'<img src="'.$GLOBALS['BACK_PATH'].'gfx/refresh_n.gif" width="14" hspace="1" vspace="2" height="14" border="0" title="'.htmlspecialchars($alt).'" alt="" />'.
+					'<img '.t3lib_iconWorks::skinImg($GLOBALS['BACK_PATH'], 'gfx/refresh_n.gif', 'width="14" height="14"') . ' hspace="1" vspace="2" border="0" title="'.htmlspecialchars($alt).'" alt="" />'.
 					'</a>';
 		}
 	}
@@ -1059,9 +1023,8 @@ class tx_indexedsearch_modfunc1 extends t3lib_extobjbase {
 	 */
 	function printExtraGrListRows($extraGrListRows)	{
 		if (count($extraGrListRows))	{
-			reset($extraGrListRows);
 			$lines=array();
-			while(list(,$r)=each($extraGrListRows))	{
+			foreach ($extraGrListRows as $r) {
 				$lines[] = $r['gr_list'];
 			}
 			return '<br />' . $GLOBALS['TBE_TEMPLATE']->dfw(implode('<br />', $lines));
@@ -1132,12 +1095,11 @@ class tx_indexedsearch_modfunc1 extends t3lib_extobjbase {
 	 *
 	 * @param	string		String to convert (utf-8)
 	 * @return	string		Converted string (backend charset if different from utf-8)
+	 * @deprecated since 4.7, will be removed in 4.9
 	 */
-	function utf8_to_currentCharset($string)	{
-		global $LANG;
-		if ($LANG->charSet != 'utf-8')	{
-			$string = $LANG->csConvObj->utf8_decode($string, $LANG->charSet, TRUE);
-		}
+	function utf8_to_currentCharset($string) {
+		t3lib_div::logDeprecatedFunction();
+
 		return $string;
 	}
 
@@ -1168,7 +1130,7 @@ class tx_indexedsearch_modfunc1 extends t3lib_extobjbase {
 	function reindexPhash($phash, $pageId)	{
 
 			// Query:
-		list($resultRow) = $GLOBALS['TYPO3_DB']->exec_SELECTgetRows(
+		$resultRow = $GLOBALS['TYPO3_DB']->exec_SELECTgetSingleRow(
 					'ISEC.*, IP.*',
 					'index_phash IP, index_section ISEC',
 					'IP.phash = ISEC.phash
@@ -1196,13 +1158,13 @@ class tx_indexedsearch_modfunc1 extends t3lib_extobjbase {
 				}
 
 				$content.='<h4>Log for re-indexing of "'.htmlspecialchars($resultRow['data_filename']).'":</h4>';
-				$content.=t3lib_div::view_array($indexerObj->internal_log);
+				$content.=t3lib_utility_Debug::viewArray($indexerObj->internal_log);
 
 				$content.='<h4>Hash-array, page:</h4>';
-				$content.=t3lib_div::view_array($indexerObj->hash);
+				$content.=t3lib_utility_Debug::viewArray($indexerObj->hash);
 
 				$content.='<h4>Hash-array, file:</h4>';
-				$content.=t3lib_div::view_array($indexerObj->file_phash_arr);
+				$content.=t3lib_utility_Debug::viewArray($indexerObj->file_phash_arr);
 			}
 		}
 
@@ -1285,13 +1247,9 @@ class tx_indexedsearch_modfunc1 extends t3lib_extobjbase {
 							$idList[] = (int)$row['page_id'];
 						}
 
-						if (TYPO3_UseCachingFramework) {
-							$pageCache = $GLOBALS['typo3CacheManager']->getCache('cache_pages');
-							foreach ($idList as $pageId) {
-								$pageCache->flushByTag('pageId_' . $pageId);
-							}
-						} else {
-							$GLOBALS['TYPO3_DB']->exec_DELETEquery('cache_pages', 'page_id IN (' . implode(',', $idList) . ')');
+						$pageCache = $GLOBALS['typo3CacheManager']->getCache('cache_pages');
+						foreach ($idList as $pageId) {
+							$pageCache->flushByTag('pageId_' . $pageId);
 						}
 					}
 				}
@@ -1382,8 +1340,8 @@ class tx_indexedsearch_modfunc1 extends t3lib_extobjbase {
 
 
 
-if (defined('TYPO3_MODE') && $TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/indexed_search/modfunc1/class.tx_indexedsearch_modfunc1.php'])    {
-    include_once($TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/indexed_search/modfunc1/class.tx_indexedsearch_modfunc1.php']);
+if (defined('TYPO3_MODE') && isset($GLOBALS['TYPO3_CONF_VARS'][TYPO3_MODE]['XCLASS']['ext/indexed_search/modfunc1/class.tx_indexedsearch_modfunc1.php'])) {
+	include_once($GLOBALS['TYPO3_CONF_VARS'][TYPO3_MODE]['XCLASS']['ext/indexed_search/modfunc1/class.tx_indexedsearch_modfunc1.php']);
 }
 
 ?>
\ No newline at end of file
