@@ -2,7 +2,7 @@
 /***************************************************************
 *  Copyright notice
 *
-*  (c) 2008-2009 Benjamin Mack <mack@xnos.org>
+*  (c) 2008-2011 Benjamin Mack <mack@xnos.org>
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
@@ -58,7 +58,7 @@ class tx_opendocs implements backend_toolbarItem {
 	 *
 	 * @param	TYPO3backend	TYPO3 backend object reference
 	 */
-	public function __construct(TYPO3backend &$backendReference = null) {
+	public function __construct(TYPO3backend &$backendReference = NULL) {
 		$this->backendReference = $backendReference;
 		$this->loadDocsFromUserSession();
 	}
@@ -66,11 +66,11 @@ class tx_opendocs implements backend_toolbarItem {
 	/**
 	 * checks whether the user has access to this toolbar item
 	 *
-	 * @return  boolean  true if user has access, false if not
+	 * @return  boolean  TRUE if user has access, FALSE if not
 	 */
 	public function checkAccess() {
 		$conf = $GLOBALS['BE_USER']->getTSConfig('backendToolbarItem.tx_opendocs.disabled');
-		return ($conf['value'] == 1 ? false : true);
+		return ($conf['value'] == 1 ? FALSE : TRUE);
 	}
 
 	/**
@@ -93,19 +93,19 @@ class tx_opendocs implements backend_toolbarItem {
 		$this->addCssToBackend();
 		$numDocs      = count($this->openDocs);
 		$opendocsMenu = array();
-		$title        = $GLOBALS['LANG']->getLL('toolbaritem', true);
+		$title        = $GLOBALS['LANG']->getLL('toolbaritem', TRUE);
 
 			// toolbar item icon
 		$opendocsMenu[] = '<a href="#" class="toolbar-item">';
 		$opendocsMenu[] = '<input type="text" id="tx-opendocs-counter" disabled="disabled" value="' . $numDocs . '" />';
-		$opendocsMenu[] = '<img' . t3lib_iconWorks::skinImg($GLOBALS['BACK_PATH'], t3lib_extMgm::extRelPath($this->EXTKEY) . 'opendocs.png', 'width="23" height="16"') . '  alt="' . $title . '" title="' . $title . '" /></a>';
+		$opendocsMenu[] = t3lib_iconWorks::getSpriteIcon('apps-toolbar-menu-opendocs', array('title' => $title)) . '</a>';
 
 			// toolbar item menu and initial content
 		$opendocsMenu[] = '<div class="toolbar-item-menu" style="display: none;">';
 		$opendocsMenu[] = $this->renderMenu();
 		$opendocsMenu[] = '</div>';
 
-		return implode("\n", $opendocsMenu);
+		return implode(LF, $opendocsMenu);
 	}
 
 	/**
@@ -120,30 +120,30 @@ class tx_opendocs implements backend_toolbarItem {
 		$content         = '';
 
 		if (count($openDocuments)) {
-			$entries[] = '<tr><th colspan="3">' . $GLOBALS['LANG']->getLL('open_docs', true) . '</th></tr>';
+			$entries[] = '<tr><th colspan="3">' . $GLOBALS['LANG']->getLL('open_docs', TRUE) . '</th></tr>';
 
 			$i = 0;
 			foreach ($openDocuments as $md5sum => $openDocument) {
 				$i++;
-				$entries[] = $this->renderMenuEntry($openDocument, $md5sum, false, ($i == 1));
+				$entries[] = $this->renderMenuEntry($openDocument, $md5sum, FALSE, ($i == 1));
 			}
 		}
 
 			// if there are "recent documents" in the list, add them
 		if (count($recentDocuments)) {
-			$entries[] = '<tr><th colspan="3">' . $GLOBALS['LANG']->getLL('recent_docs', true) . '</th></tr>';
+			$entries[] = '<tr><th colspan="3">' . $GLOBALS['LANG']->getLL('recent_docs', TRUE) . '</th></tr>';
 
 			$i = 0;
 			foreach ($recentDocuments as $md5sum => $recentDocument) {
 				$i++;
-				$entries[] = $this->renderMenuEntry($recentDocument, $md5sum, true, ($i == 1));
+				$entries[] = $this->renderMenuEntry($recentDocument, $md5sum, TRUE, ($i == 1));
 			}
 		}
 
 		if (count($entries)) {
 			$content = '<table class="list" cellspacing="0" cellpadding="0" border="0">' . implode('', $entries) . '</table>';
 		} else {
-			$content = '<div class="no-docs">' . $GLOBALS['LANG']->getLL('no_docs', true) . '</div>';
+			$content = '<div class="no-docs">' . $GLOBALS['LANG']->getLL('no_docs', TRUE) . '</div>';
 		}
 
 		return $content;
@@ -154,37 +154,46 @@ class tx_opendocs implements backend_toolbarItem {
 	 *
 	 * @return	array	all recent documents as list-items
 	 */
-	public function renderMenuEntry($document, $md5sum, $isRecentDoc = false, $isFirstDoc = false) {
+	public function renderMenuEntry($document, $md5sum, $isRecentDoc = FALSE, $isFirstDoc = FALSE) {
 		$table  = $document[3]['table'];
 		$uid    = $document[3]['uid'];
 		$record = t3lib_BEfunc::getRecordWSOL($table, $uid);
+		if (!is_array($record)) {
+				// record seems to be deleted
+			return '';
+		}
 		$label  = htmlspecialchars(strip_tags(t3lib_div::htmlspecialchars_decode($document[0])));
-		$icon   = t3lib_iconWorks::getIconImage($table, $record, $GLOBALS['BACK_PATH']);
+		$icon   = t3lib_iconWorks::getSpriteIconForRecord($table, $record);
 		$link   = $GLOBALS['BACK_PATH'] . 'alt_doc.php?' . $document[2];
 
+		$pageId = intval($document[3]['uid']);
+		if ($document[3]['table'] !== 'pages') {
+			$pageId = intval($document[3]['pid']);
+		}
+
 		$firstRow = '';
 		if ($isFirstDoc) {
 			$firstRow = ' first-row';
 		}
 
 		if (!$isRecentDoc) {
-			$title = $GLOBALS['LANG']->sL('LLL:EXT:lang/locallang_core.xml:rm.closeDoc', true);
+			$title = $GLOBALS['LANG']->sL('LLL:EXT:lang/locallang_core.xml:rm.closeDoc', TRUE);
 
 				// open document
-			$closeIcon = '<img' . t3lib_iconWorks::skinImg($GLOBALS['BACK_PATH'], 'gfx/closedok.gif', 'width="16" height="16"') . ' title="' . $title . '" alt="' . $title . '" />';
+			$closeIcon = t3lib_iconWorks::getSpriteIcon('actions-document-close');
 
 			$entry = '
-				<tr id="opendocs-open-' . $table . '-' . $uid . '" class="opendoc' . $firstRow . '">
+				<tr class="opendoc' . $firstRow . '">
 					<td class="icon">' . $icon . '</td>
-					<td class="label"><a href="' . htmlspecialchars($link) . '" target="content" onclick="TYPO3BackendOpenDocs.toggleMenu();">' . $label . '</a></td>
+					<td class="label"><a href="#" onclick="jump(unescape(\'' . htmlspecialchars($link) . '\'), \'web_list\', \'web\', ' . $pageId . '); TYPO3BackendOpenDocs.toggleMenu(); return false;" target="content">' . $label . '</a></td>
 					<td class="close" onclick="return TYPO3BackendOpenDocs.closeDocument(\'' . $md5sum . '\');">' . $closeIcon . '</td>
 				</tr>';
 		} else {
 				// recently used document
 			$entry = '
-				<tr id="opendocs-recent-' . $table . '-' . $uid . '" class="recentdoc' . $firstRow . '">
+				<tr class="recentdoc' . $firstRow . '">
 					<td class="icon">' . $icon . '</td>
-					<td class="label" colspan="2"><a href="' . htmlspecialchars($link) . '" target="content" onclick="TYPO3BackendOpenDocs.toggleMenu();">' . $label . '</a></td>
+					<td class="label" colspan="2"><a href="#" onclick="jump(unescape(\'' . htmlspecialchars($link) . '\'), \'web_list\', \'web\', ' . $pageId . '); TYPO3BackendOpenDocs.toggleMenu(); return false;" target="content">' . $label . '</a></td>
 				</tr>';
 		}
 
@@ -251,7 +260,7 @@ class tx_opendocs implements backend_toolbarItem {
 	 * @param	TYPO3AJAX	object of type TYPO3AJAX
 	 * @return	string		list item HTML attibutes
 	 */
-	public function closeDocument($params = array(), TYPO3AJAX &$ajaxObj = null) {
+	public function closeDocument($params = array(), TYPO3AJAX &$ajaxObj = NULL) {
 		$md5sum = t3lib_div::_GP('md5sum');
 
 		if ($md5sum && isset($this->openDocs[$md5sum])) {
@@ -284,7 +293,7 @@ class tx_opendocs implements backend_toolbarItem {
 	 * @param	TYPO3AJAX	object of type TYPO3AJAX
 	 * @return	void
 	 */
-	public function renderAjax($params = array(), TYPO3AJAX &$ajaxObj = null) {
+	public function renderAjax($params = array(), TYPO3AJAX &$ajaxObj = NULL) {
 		$menuContent = $this->renderMenu();
 
 		$ajaxObj->addContent('opendocsMenu', $menuContent);
@@ -293,7 +302,7 @@ class tx_opendocs implements backend_toolbarItem {
 }
 
 
-if (defined('TYPO3_MODE') && $TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/opendocs/class.tx_opendocs.php']) {
-	include_once($TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/opendocs/class.tx_opendocs.php']);
+if (defined('TYPO3_MODE') && isset($GLOBALS['TYPO3_CONF_VARS'][TYPO3_MODE]['XCLASS']['ext/opendocs/class.tx_opendocs.php'])) {
+	include_once($GLOBALS['TYPO3_CONF_VARS'][TYPO3_MODE]['XCLASS']['ext/opendocs/class.tx_opendocs.php']);
 }
 ?>
\ No newline at end of file
