@@ -2,7 +2,7 @@
 /***************************************************************
 *  Copyright notice
 *
-*  (c) 2003-2008 Stanislas Rolland <stanislas.rolland(arobas)fructifor.ca>
+*  (c) 2003-2011 Stanislas Rolland <typo3(arobas)sjbr.ca>
 *  All rights reserved
 *
 *  This script is part of the Typo3 project. The Typo3 project is
@@ -24,25 +24,14 @@
 /**
  * Spell checking plugin 'tx_rtehtmlarea_pi1' for the htmlArea RTE extension.
  *
- * @author Stanislas Rolland <stanislas.rolland(arobas)fructifor.ca>
- *
- * TYPO3 SVN ID: $Id: class.tx_rtehtmlarea_pi1.php 3439 2008-03-16 19:16:51Z flyguide $
+ * @author Stanislas Rolland <typo3(arobas)sjbr.ca>
  *
  */
-require_once(PATH_tslib.'class.tslib_pibase.php');
 
-class tx_rtehtmlarea_pi1 extends tslib_pibase {
+class tx_rtehtmlarea_pi1 {
 
-	/**
-	 * back reference to the mother cObj object set at call time
-	 *
-	 * @var tslib_cObj
-	 */
-	var $cObj;
-	var $prefixId = 'tx_rtehtmlarea_pi1';  // Same as class name
-	var $scriptRelPath = 'pi1/class.tx_rtehtmlarea_pi1.php';  // Path to this script relative to the extension dir.
+	protected $csConvObj;
 	var $extKey = 'rtehtmlarea'; // The extension key.
-	var $conf = array();
 	var $siteUrl;
 	var $charset = 'utf-8';
 	var $parserCharset = 'utf-8';
@@ -70,84 +59,46 @@ class tx_rtehtmlarea_pi1 extends tslib_pibase {
 	/**
 	 * Main class of Spell Checker plugin for Typo3 CMS
 	 *
-	 * @param	string		$content: content to be displayed
-	 * @param	array		$conf: TS setup for the plugin
 	 * @return	string		content produced by the plugin
 	 */
-	function main($conf) {
-		global $TYPO3_CONF_VARS, $TYPO3_DB;
+	function main() {
+
+		$this->csConvObj = t3lib_div::makeInstance('t3lib_cs');
 
-		$this->conf = $conf;
-		$this->tslib_pibase();
-		$this->pi_setPiVarDefaults();
-		$this->pi_loadLL();
-		$this->pi_USER_INT_obj = 1;  // Disable caching
 			// Setting start time
-		$time_start = microtime(true);
+		$time_start = microtime(TRUE);
 		$this->pspell_is_available = in_array('pspell', get_loaded_extensions());
-		$this->AspellDirectory = trim($TYPO3_CONF_VARS['EXTCONF'][$this->extKey]['AspellDirectory'])? trim($TYPO3_CONF_VARS['EXTCONF'][$this->extKey]['AspellDirectory']) : '/usr/bin/aspell';
-		$this->forceCommandMode = (trim($TYPO3_CONF_VARS['EXTCONF'][$this->extKey]['forceCommandMode']))? trim($TYPO3_CONF_VARS['EXTCONF'][$this->extKey]['forceCommandMode']) : 0;
-		$safe_mode_is_enabled = ini_get('safe_mode');
-		if($safe_mode_is_enabled && !$this->pspell_is_available ) echo('Configuration problem: Spell checking cannot be performed');
-		if($safe_mode_is_enabled && $this->forceCommandMode) echo('Configuration problem: Spell checking cannot be performed in command mode');
-		if(!$safe_mode_is_enabled && (!$this->pspell_is_available || $this->forceCommandMode)) {
+		$this->AspellDirectory = trim($GLOBALS['TYPO3_CONF_VARS']['EXTCONF'][$this->extKey]['plugins']['SpellChecker']['AspellDirectory'])? trim($GLOBALS['TYPO3_CONF_VARS']['EXTCONF'][$this->extKey]['plugins']['SpellChecker']['AspellDirectory']) : '/usr/bin/aspell';
+			// Setting command mode if requested and available
+		$this->forceCommandMode = (trim($GLOBALS['TYPO3_CONF_VARS']['EXTCONF'][$this->extKey]['plugins']['SpellChecker']['forceCommandMode']))? trim($GLOBALS['TYPO3_CONF_VARS']['EXTCONF'][$this->extKey]['plugins']['SpellChecker']['forceCommandMode']) : 0;
+		if (!$this->pspell_is_available || $this->forceCommandMode) {
 			$AspellVersionString = explode('Aspell', shell_exec( $this->AspellDirectory.' -v'));
 			$AspellVersion = substr( $AspellVersionString[1], 0, 4);
-			if( doubleval($AspellVersion) < doubleval('0.5') && (!$this->pspell_is_available || $this->forceCommandMode)) echo('Configuration problem: Aspell version ' . $AspellVersion . ' too old. Spell checking cannot be performed in command mode');
+			if( doubleval($AspellVersion) < doubleval('0.5') && (!$this->pspell_is_available || $this->forceCommandMode)) echo('Configuration problem: Aspell version ' . $AspellVersion . ' too old. Spell checking cannot be performed in command mode.');
 			$this->defaultAspellEncoding = trim(shell_exec($this->AspellDirectory.' config encoding'));
 		}
-
 			// Setting the list of dictionaries
-		if(!$safe_mode_is_enabled && (!$this->pspell_is_available || $this->forceCommandMode)) {
-			$dictionaryList = shell_exec( $this->AspellDirectory.' dump dicts');
-			$dictionaryList = implode(',', t3lib_div::trimExplode(chr(10), $dictionaryList, 1));
-		}
-		if( empty($dictionaryList) ) {
-			$dictionaryList = trim($TYPO3_CONF_VARS['EXTCONF'][$this->extKey]['dictionaryList']);
-		}
-		if( empty($dictionaryList) ) {
-			$dictionaryList = 'en';
-		}
+		$dictionaryList = shell_exec( $this->AspellDirectory . ' dump dicts');
+		$dictionaryList = implode(',', t3lib_div::trimExplode(LF, $dictionaryList, 1));
 		$dictionaryArray = t3lib_div::trimExplode(',', $dictionaryList, 1);
-
-		$defaultDictionary = trim($TYPO3_CONF_VARS['EXTCONF'][$this->extKey]['defaultDictionary']);
-		if(!$defaultDictionary || !in_array($defaultDictionary, $dictionaryArray)) {
+		$restrictToDictionaries = t3lib_div::_POST('restrictToDictionaries');
+		if ($restrictToDictionaries) {
+			$dictionaryArray = array_intersect($dictionaryArray, t3lib_div::trimExplode(',', $restrictToDictionaries, 1));
+		}
+		if (!count($dictionaryArray)) {
+			$dictionaryArray[] = 'en';
+		}
+		$this->dictionary = t3lib_div::_POST('dictionary');
+		$defaultDictionary = $this->dictionary;
+		if (!$defaultDictionary || !in_array($defaultDictionary, $dictionaryArray)) {
 			$defaultDictionary = 'en';
 		}
-
-			// Get the defined sys_language codes
-		$languageArray = array();
-		$tableA = 'sys_language';
-		$tableB = 'static_languages';
-		$selectFields = $tableA . '.uid,' . $tableB . '.lg_iso_2,' . $tableB . '.lg_country_iso_2';
-		$table = $tableA . ' LEFT JOIN ' . $tableB . ' ON ' . $tableA . '.static_lang_isocode=' . $tableB . '.uid';
-		$whereClause = '1=1 ';
-		$whereClause .= ' AND ' . $tableA . '.hidden != 1';
-		$res = $TYPO3_DB->exec_SELECTquery($selectFields, $table, $whereClause);
-		while($row = $TYPO3_DB->sql_fetch_assoc($res))    {
-			$languageArray[] = strtolower($row['lg_iso_2']).($row['lg_country_iso_2']?'_'.$row['lg_country_iso_2']:'');
-		}
-		if(!in_array($defaultDictionary, $languageArray)) {
-			$languageArray[] = $defaultDictionary;
-		}
-		foreach ($dictionaryArray as $key => $dict) {
-			$lang = explode('-', $dict);
-			if( !in_array(substr($dict, 0, 2), $languageArray) || !empty($lang[1])) {
-				unset($dictionaryArray[$key]);
-			} else {
-				$dictionaryArray[$key] = $lang[0];
-			}
-		}
 		uasort($dictionaryArray, 'strcoll');
 		$dictionaryList = implode(',', $dictionaryArray);
-
 			// Setting the dictionary
-		$this->dictionary = t3lib_div::_POST('dictionary');
-		if( empty($this->dictionary) || !in_array($this->dictionary, $dictionaryArray)) {
-			$this->dictionary = $defaultDictionary;
+		if (empty($this->dictionary) || !in_array($this->dictionary, $dictionaryArray)) {
+			$this->dictionary = 'en';
 		}
-		$dictionaries = substr_replace($dictionaryList, '@'.$this->dictionary, strpos($dictionaryList, $this->dictionary), strlen($this->dictionary));
-
 			// Setting the pspell suggestion mode
 		$this->pspellMode = t3lib_div::_POST('pspell_mode')?t3lib_div::_POST('pspell_mode'): $this->pspellMode;
 			// Now sanitize $this->pspellMode
@@ -173,8 +124,6 @@ class tx_rtehtmlarea_pi1 extends tslib_pibase {
 		if (strtolower($this->charset) == 'iso-8859-1') {
 			$this->parserCharset = strtolower($this->charset);
 		}
-		$internal_encoding = mb_internal_encoding(strtoupper($this->parserCharset));
-		//$regex_encoding = mb_regex_encoding(strtoupper($this->parserCharset));
 
 			// In some configurations, Aspell uses 'iso8859-1' instead of 'iso-8859-1'
 		$this->aspellEncoding = $this->parserCharset;
@@ -188,7 +137,7 @@ class tx_rtehtmlarea_pi1 extends tslib_pibase {
 		}
 
 			// Setting the path to user personal dicts, if any
-		if (t3lib_div::_POST('enablePersonalDicts') == 'true' && $GLOBALS['TSFE']->beUserLogin)	{
+		if (t3lib_div::_POST('enablePersonalDicts') == 'true' && TYPO3_MODE == 'BE' && is_object($GLOBALS['BE_USER'])) {
 			$this->userUid = 'BE_' . $GLOBALS['BE_USER']->user['uid'];
 			if ($this->userUid) {
 				$this->personalDictPath = t3lib_div::getFileAbsFileName($this->uploadFolder . $this->userUid);
@@ -201,9 +150,9 @@ class tx_rtehtmlarea_pi1 extends tslib_pibase {
 		}
 
 		$cmd = t3lib_div::_POST('cmd');
-		if ($cmd == 'learn' && !$safe_mode_is_enabled) {
+		if ($cmd == 'learn') {
 				// Only availble for BE_USERS, die silently if someone has gotten here by accident
-			if(!$GLOBALS['TSFE']->beUserLogin) die('');
+			if (TYPO3_MODE !='BE' || !is_object($GLOBALS['BE_USER'])) die('');
 				// Updating the personal word list
 			$to_p_dict = t3lib_div::_POST('to_p_dict');
 			$to_p_dict = $to_p_dict ? $to_p_dict : array();
@@ -211,17 +160,16 @@ class tx_rtehtmlarea_pi1 extends tslib_pibase {
 			$to_r_list = $to_r_list ? $to_r_list : array();
 			header('Content-Type: text/plain; charset=' . strtoupper($this->parserCharset));
 			header('Pragma: no-cache');
-			//print_r($to_r_list);
 			if($to_p_dict || $to_r_list) {
 				$tmpFileName = t3lib_div::tempnam($this->filePrefix);
 				if($filehandle = fopen($tmpFileName,'wb')) {
 					foreach ($to_p_dict as $personal_word) {
-						$cmd = '&' . $personal_word . "\n";
+						$cmd = '&' . $personal_word . LF;
 						echo $cmd;
 						fwrite($filehandle, $cmd, strlen($cmd));
 					}
 					foreach ($to_r_list as $replace_pair) {
-						$cmd = '$$ra ' . $replace_pair[0] . ' , ' . $replace_pair[1] . "\n";
+						$cmd = '$$ra ' . $replace_pair[0] . ' , ' . $replace_pair[1] . LF;
 						echo $cmd;
 						fwrite($filehandle, $cmd, strlen($cmd));
 					}
@@ -231,7 +179,7 @@ class tx_rtehtmlarea_pi1 extends tslib_pibase {
 					fclose($filehandle);
 						// $this->personalDictsArg has already been escapeshellarg()'ed above, it is an optional paramter and might be empty here
 					$AspellCommand = 'cat ' . escapeshellarg($tmpFileName) . ' | ' . $this->AspellDirectory . ' -a --mode=none' . $this->personalDictsArg . ' --lang=' . escapeshellarg($this->dictionary) . ' --encoding=' . escapeshellarg($this->aspellEncoding) . ' 2>&1';
-					print $AspellCommand . "\n";
+					print $AspellCommand . LF;
 					print shell_exec($AspellCommand);
 					t3lib_div::unlink_tempfile($tmpFileName);
 					echo('Personal word list was updated.');
@@ -251,10 +199,9 @@ class tx_rtehtmlarea_pi1 extends tslib_pibase {
      PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN"
      "http://www.w3.org/TR/xhtml1/DTD/xhtml1-transitional.dtd">
 <html xmlns="http://www.w3.org/1999/xhtml" xml:lang="' . substr($this->dictionary, 0, 2) . '" lang="' . substr($this->dictionary, 0, 2) . '">
-<html>
 <head>
 <meta http-equiv="Content-Type" content="text/html; charset=' . $this->parserCharset . '" />
-<link rel="stylesheet" type="text/css" media="all" href="spell-check-style.css" />
+<link rel="stylesheet" type="text/css" media="all" href="' . (TYPO3_MODE == 'BE' ? '../' : '') . t3lib_extMgm::siteRelPath($this->extKey) . '/htmlarea/plugins/SpellChecker/spell-check-style.css" />
 <script type="text/javascript">
 /*<![CDATA[*/
 <!--
@@ -266,35 +213,36 @@ class tx_rtehtmlarea_pi1 extends tslib_pibase {
 				// Parsing the input HTML
 			$parser = xml_parser_create(strtoupper($this->parserCharset));
 			xml_parser_set_option($parser, XML_OPTION_CASE_FOLDING, 0);
-			xml_set_object($parser, &$this);
+			xml_set_object($parser, $this);
 			if (!xml_set_element_handler($parser, 'startHandler', 'endHandler')) echo('Bad xml handler setting');
 			if (!xml_set_character_data_handler($parser, 'collectDataHandler')) echo('Bad xml handler setting');
 			if (!xml_set_default_handler($parser, 'defaultHandler')) echo('Bad xml handler setting');
-			if (!xml_parse($parser,'<?xml version="1.0" encoding="' . $this->parserCharset . '"?><spellchecker> ' . mb_ereg_replace('&nbsp;', ' ', $content) . ' </spellchecker>')) echo('Bad parsing');
+			if (!xml_parse($parser,'<?xml version="1.0" encoding="' . $this->parserCharset . '"?><spellchecker> ' . preg_replace('/&nbsp;/'.(($this->parserCharset == 'utf-8')?'u':''), ' ', $content) . ' </spellchecker>')) echo('Bad parsing');
 			if (xml_get_error_code($parser)) {
-				die('Line '.xml_get_current_line_number($parser).': '.xml_error_string(xml_get_error_code($parser)));
+				throw new UnexpectedException('Line ' . xml_get_current_line_number($parser) . ': ' . xml_error_string(xml_get_error_code($parser)), 1294585788);
 			}
 			xml_parser_free($parser);
 			if ($this->pspell_is_available && !$this->forceCommandMode) {
 				pspell_clear_session ($this->pspell_link);
 			}
-			$this->result .= 'var suggested_words = {' . $this->suggestedWords . '};
+			$this->result .= 'var suggestedWords = {' . $this->suggestedWords . '};
+var dictionaries = "' . $dictionaryList . '";
+var selectedDictionary = "' . $this->dictionary . '";
 ';
 
 				// Calculating parsing and spell checkting time
-			$time = number_format(microtime(true) - $time_start, 2, ',', ' ');
+			$time = number_format(microtime(TRUE) - $time_start, 2, ',', ' ');
 
 				// Insert spellcheck info
-			$this->result .= 'var spellcheck_info = { "Total words":"'.$this->wordCount.'","Misspelled words":"'.sizeof($this->misspelled).'","Total suggestions":"'.$this->suggestionCount.'","Total words suggested":"'.$this->suggestedWordCount.'","Spelling checked in":"'.$time.'" };
+			$this->result .= 'var spellcheckInfo = { "Total words":"'.$this->wordCount.'","Misspelled words":"'.sizeof($this->misspelled).'","Total suggestions":"'.$this->suggestionCount.'","Total words suggested":"'.$this->suggestedWordCount.'","Spelling checked in":"'.$time.'" };
 // -->
 /*]]>*/
 </script>
 </head>
 ';
-			$this->result .= '<body onload="window.parent.finishedSpellChecking();">';
-			$this->result .= preg_replace('/'.preg_quote('<?xml').'.*'.preg_quote('?>').'['.preg_quote(chr(10).chr(13).chr(32)).']*/', '', $this->text);
-			$this->result .= '<div id="HA-spellcheck-dictionaries">'.$dictionaries.'</div>';
-
+			$this->result .= '<body onload="window.parent.RTEarea[\'' . t3lib_div::_POST('editorId') . '\'].editor.getPlugin(\'SpellChecker\').spellCheckComplete();">';
+			$this->result .= preg_replace('/'.preg_quote('<?xml').'.*'.preg_quote('?>').'['.preg_quote(LF.CR.chr(32)).']*/'.(($this->parserCharset == 'utf-8')?'u':''), '', $this->text);
+			$this->result .= '<div style="display: none;">'.$dictionaries.'</div>';
 				// Closing
 			$this->result .= '
 </body></html>';
@@ -307,6 +255,7 @@ class tx_rtehtmlarea_pi1 extends tslib_pibase {
 	}  // end of function main
 
 	function startHandler($xml_parser, $tag, $attributes) {
+
 		if (strlen($this->xmlCharacterData)) {
 			$this->spellCheckHandler($xml_parser, $this->xmlCharacterData);
 			$this->xmlCharacterData = '';
@@ -323,14 +272,14 @@ class tx_rtehtmlarea_pi1 extends tslib_pibase {
 			case 'HR':
 			case 'area':
 			case 'AREA':
-				$this->text .= '<'. mb_strtolower($tag) . ' ';
+				$this->text .= '<'. $this->csConvObj->conv_case($this->parserCharset, $tag, 'toLower') . ' ';
 				foreach( $attributes as $key => $val) {
 					$this->text .= $key . '="' . $val . '" ';
 				}
 				$this->text .= ' />';
 				break;
 			default:
-				$this->text .= '<'. mb_strtolower($tag) . ' ';
+				$this->text .= '<'. $this->csConvObj->conv_case($this->parserCharset, $tag, 'toLower') . ' ';
 				foreach( $attributes as $key => $val) {
 					$this->text .= $key . '="' . $val . '" ';
 				}
@@ -370,9 +319,9 @@ class tx_rtehtmlarea_pi1 extends tslib_pibase {
 	function spellCheckHandler($xml_parser, $string) {
 		$incurrent=array();
 		$stringText = $string;
-		$words = mb_split('\W+', $stringText);
+		$words = preg_split((($this->parserCharset == 'utf-8')?'/\P{L}+/u':'/\W+/'), $stringText);
 		while( list(,$word) = each($words) ) {
-			$word = mb_ereg_replace(' ', '', $word);
+			$word = preg_replace('/ /'.(($this->parserCharset == 'utf-8')?'u':''), '', $word);
 			if( $word && !is_numeric($word)) {
 				if($this->pspell_is_available && !$this->forceCommandMode) {
 					if (!pspell_check($this->pspell_link, $word)) {
@@ -391,7 +340,7 @@ class tx_rtehtmlarea_pi1 extends tslib_pibase {
 							unset($suggest);
 						}
 						if( !in_array($word, $incurrent) ) {
-							$stringText = mb_ereg_replace('\b'.$word.'\b', '<span class="HA-spellcheck-error">'.$word.'</span>', $stringText);
+							$stringText = preg_replace('/\b'.$word.'\b/'.(($this->parserCharset == 'utf-8')?'u':''), '<span class="htmlarea-spellcheck-error">'.$word.'</span>', $stringText);
 							$incurrent[] = $word;
 						}
 					}
@@ -403,7 +352,7 @@ class tx_rtehtmlarea_pi1 extends tslib_pibase {
 					$AspellCommand = 'cat ' . escapeshellarg($tmpFileName) . ' | ' . $this->AspellDirectory . ' -a check --mode=none --sug-mode=' . escapeshellarg($this->pspellMode) . $this->personalDictsArg . ' --lang=' . escapeshellarg($this->dictionary) . ' --encoding=' . escapeshellarg($this->aspellEncoding) . ' 2>&1';
 					$AspellAnswer = shell_exec($AspellCommand);
 					$AspellResultLines = array();
-					$AspellResultLines = t3lib_div::trimExplode(chr(10), $AspellAnswer, 1);
+					$AspellResultLines = t3lib_div::trimExplode(LF, $AspellAnswer, 1);
 					if(substr($AspellResultLines[0],0,6) == 'Error:') echo("{$AspellAnswer}");
 					t3lib_div::unlink_tempfile($tmpFileName);
 					if(substr($AspellResultLines['1'],0,1) != '*') {
@@ -427,7 +376,7 @@ class tx_rtehtmlarea_pi1 extends tslib_pibase {
 							unset($suggestions);
 						}
 						if (!in_array($word, $incurrent)) {
-							$stringText = mb_ereg_replace('\b'.$word.'\b', '<span class="HA-spellcheck-error">'.$word.'</span>', $stringText);
+							$stringText = preg_replace('/\b'.$word.'\b/'.(($this->parserCharset == 'utf-8')?'u':''), '<span class="htmlarea-spellcheck-error">'.$word.'</span>', $stringText);
 							$incurrent[] = $word;
 						}
 					}
@@ -450,10 +399,16 @@ class tx_rtehtmlarea_pi1 extends tslib_pibase {
 		return;
 	}
 
-} // end of class
+}
 
-if (defined('TYPO3_MODE') && $TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/rtehtmlarea/pi1/class.tx_rtehtmlarea_pi1.php']) {
-	include_once($TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/rtehtmlarea/pi1/class.tx_rtehtmlarea_pi1.php']);
+if (defined('TYPO3_MODE') && isset($GLOBALS['TYPO3_CONF_VARS'][TYPO3_MODE]['XCLASS']['ext/rtehtmlarea/pi1/class.tx_rtehtmlarea_pi1.php'])) {
+	include_once($GLOBALS['TYPO3_CONF_VARS'][TYPO3_MODE]['XCLASS']['ext/rtehtmlarea/pi1/class.tx_rtehtmlarea_pi1.php']);
+}
+
+if (TYPO3_MODE=='FE') {
+	tslib_eidtools::connectDB();
+	$spellChecker = t3lib_div::makeInstance('tx_rtehtmlarea_pi1');
+	$spellChecker->main();
 }
 
 ?>
\ No newline at end of file
