@@ -2,7 +2,7 @@
 /***************************************************************
 *  Copyright notice
 *
-*  (c) 1999-2009 Kasper Skaarhoj (kasperYYYY@typo3.com)
+*  (c) 1999-2011 Kasper Skårhøj (kasperYYYY@typo3.com)
 *  All rights reserved
 *
 *  This script is part of the TYPO3 project. The TYPO3 project is
@@ -31,7 +31,7 @@
  * 	$TYPO3_CONF_VARS["MODS"]["web_ts"]["onlineResourceDir"]  = Directory of default resources. Eg. "fileadmin/res/" or so.
  *
  *
- * @author	Kasper Skaarhoj <kasperYYYY@typo3.com>
+ * @author	Kasper Skårhøj <kasperYYYY@typo3.com>
  */
 
 
@@ -42,7 +42,7 @@ require($BACK_PATH . 'init.php');
 require($BACK_PATH . 'template.php');
 $GLOBALS['LANG']->includeLLFile('EXT:tstemplate/ts/locallang.xml');
 
-$BE_USER->modAccess($MCONF, true);
+$BE_USER->modAccess($MCONF, TRUE);
 
 
 // ***************************
@@ -132,18 +132,21 @@ class SC_mod_web_ts_index extends t3lib_SCbase {
 		';
 
 			$this->doc->inDocStylesArray[] = '
+				TABLE#typo3-objectBrowser { width: 100%; }
 				TABLE#typo3-objectBrowser A { text-decoration: none; }
 				TABLE#typo3-objectBrowser .comment { color: maroon; font-weight: bold; }
-				TABLE#ts-analyzer tr.c-headLineTable {background-color: #A2AAB8;}
-				TABLE#ts-analyzer tr td {padding: 0 2px;}
-				TABLE#ts-analyzer tr.c-headLineTable td {padding: 2px 4px; font-weight:bold; color: #fff;}
-				.tsob-menu label, .tsob-menu-row2 label, .tsob-conditions label {padding: 0 5px; vertical-align: text-top;}
+				TABLE#ts-analyzer { width: 100% }
+				TABLE#ts-analyzer tr.t3-row-header { background-color: #A2AAB8; }
+				TABLE#ts-analyzer tr td {padding: 0 4px;}
+				TABLE#ts-analyzer tr.t3-row-header td { padding: 2px 4px; font-weight:bold; color: #fff; }
+				.ts-typoscript { width: 100%; }
+				.tsob-menu label, .tsob-menu-row2 label, .tsob-conditions label { padding: 0 5px 0 0; vertical-align: text-top;}
 				.tsob-menu-row2 {margin-top: 10px;}
 				.tsob-conditions {padding: 1px 2px;}
 				.tsob-search-submit {margin-left: 3px; margin-right: 3px;}
 				.tst-analyzer-options { margin:5px 0; }
 				.tst-analyzer-options label {padding-left:5px; vertical-align:text-top; }
-				.bgColor0 {background-color:#fff;}
+				.bgColor0 {background-color:#fff; color: #000; }
 			';
 
 
@@ -153,7 +156,6 @@ class SC_mod_web_ts_index extends t3lib_SCbase {
 				// Build the modulle content
 			$this->content = $this->doc->header($GLOBALS['LANG']->getLL('moduleTitle'));
 			$this->extObjContent();
-			$this->content .= $this->doc->spacer(10);
 
 				// Setting up the buttons and markers for docheader
 			$docHeaderButtons = $this->getButtons();
@@ -164,9 +166,9 @@ class SC_mod_web_ts_index extends t3lib_SCbase {
 				// If no access or if ID == zero
 
 			$this->doc->inDocStylesArray[] = '
-				TABLE#ts-overview tr.c-headLineTable {background-color: #A2AAB8;}
+				TABLE#ts-overview tr.t3-row-header { background-color: #A2AAB8; }
 				TABLE#ts-overview tr td {padding: 2px;}
-				TABLE#ts-overview tr.c-headLineTable td {padding: 2px 4px; font-weight:bold; color: #fff;}
+				TABLE#ts-overview tr.t3-row-header td { padding: 2px 4px; font-weight:bold; color: #fff; }
 			';
 				// Template pages:
 			$res = $GLOBALS['TYPO3_DB']->exec_SELECTquery(
@@ -191,7 +193,7 @@ class SC_mod_web_ts_index extends t3lib_SCbase {
 			}
 
 			$lines = array();
-			$lines[] = '<tr class="c-headLineTable">
+			$lines[] = '<tr class="t3-row-header">
 				<td nowrap>' . $GLOBALS['LANG']->getLL('pageName') . '</td>
 				<td nowrap>' . $GLOBALS['LANG']->getLL('templates') . '</td>
 				<td nowrap>' . $GLOBALS['LANG']->getLL('isRoot') . '</td>
@@ -200,7 +202,9 @@ class SC_mod_web_ts_index extends t3lib_SCbase {
 			$lines = array_merge($lines, $this->renderList($pArray));
 
 			$table = '<table border="0" cellpadding="0" cellspacing="1" id="ts-overview">' . implode('', $lines) . '</table>';
-			$this->content = $this->doc->section($GLOBALS['LANG']->getLL('moduleTitle'), '
+
+			$this->content = $this->doc->header($GLOBALS['LANG']->getLL('moduleTitle'));
+			$this->content .= $this->doc->section('', '
 			<br />
 			' . $GLOBALS['LANG']->getLL('overview') . '
 			<br /><br />' . $table);
@@ -209,8 +213,6 @@ class SC_mod_web_ts_index extends t3lib_SCbase {
 			// RENDER LIST of pages with templates, END
 			// ********************************************
 
-			$this->content .= $this->doc->spacer(10);
-
 				// Setting up the buttons and markers for docheader
 			$docHeaderButtons = $this->getButtons();
 			// $markers['CSH'] = $docHeaderButtons['csh'];
@@ -218,10 +220,12 @@ class SC_mod_web_ts_index extends t3lib_SCbase {
 		}
 
 			// Build the <body> for the module
-		$this->content = $this->doc->startPage('Template Tools');
-		$this->content .= $this->doc->moduleBody($this->pageinfo, $docHeaderButtons, $markers);
-		$this->content .= $this->doc->endPage();
-		$this->content = $this->doc->insertStylesAndJS($this->content);
+		$this->content = $this->doc->moduleBody($this->pageinfo, $docHeaderButtons, $markers);
+			// Renders the module page
+		$this->content = $this->doc->render(
+			'Template Tools',
+			$this->content
+		);
 	}
 
 	function printContent() {
@@ -248,45 +252,68 @@ class SC_mod_web_ts_index extends t3lib_SCbase {
 
 		if ($this->id && $this->access) {
 				// View page
-			$buttons['view'] = '<a href="#" onclick="' . htmlspecialchars(t3lib_BEfunc::viewOnClick($this->pageinfo['uid'], $GLOBALS['BACK_PATH'], t3lib_BEfunc::BEgetRootLine($this->pageinfo['uid']))) . '">' .
-					'<img' . t3lib_iconWorks::skinImg($GLOBALS['BACK_PATH'], 'gfx/zoom.gif') . ' title="' . $GLOBALS['LANG']->sL('LLL:EXT:lang/locallang_core.php:labels.showPage', true) . '" hspace="3" alt="" />' .
+			$buttons['view'] = '<a href="#" onclick="' . htmlspecialchars(t3lib_BEfunc::viewOnClick($this->pageinfo['uid'], $GLOBALS['BACK_PATH'], t3lib_BEfunc::BEgetRootLine($this->pageinfo['uid']))) . '" title="' . $GLOBALS['LANG']->sL('LLL:EXT:lang/locallang_core.php:labels.showPage', TRUE) . '">' .
+						t3lib_iconWorks::getSpriteIcon('actions-document-view') .
 					'</a>';
 
 				// If access to Web>List for user, then link to that module.
-			if ($GLOBALS['BE_USER']->check('modules', 'web_list')) {
-				$href = $GLOBALS['BACK_PATH'] . 'db_list.php?id=' . $this->pageinfo['uid'] . '&returnUrl=' . rawurlencode(t3lib_div::getIndpEnv('REQUEST_URI'));
-				$buttons['record_list'] = '<a href="' . htmlspecialchars($href) . '">' .
-						'<img' . t3lib_iconWorks::skinImg($GLOBALS['BACK_PATH'], 'gfx/list.gif') . ' title="' . $GLOBALS['LANG']->sL('LLL:EXT:lang/locallang_core.php:labels.showList', true) . '" alt="" />' .
-						'</a>';
-			}
+			$buttons['record_list'] = t3lib_BEfunc::getListViewLink(
+				array(
+					'id' => $this->pageinfo['uid'],
+					'returnUrl' => t3lib_div::getIndpEnv('REQUEST_URI'),
+				),
+				$GLOBALS['LANG']->sL('LLL:EXT:lang/locallang_core.php:labels.showList')
+			);
 
 			if ($this->extClassConf['name'] == 'tx_tstemplateinfo') {
 					// NEW button
-				$buttons['new'] = '<input type="image" class="c-inputButton" name="createExtension" value="New"' . t3lib_iconWorks::skinImg($GLOBALS['BACK_PATH'], 'gfx/new_el.gif', '') . ' title="' . $GLOBALS['LANG']->sL('LLL:EXT:lang/locallang_core.php:db_new.php.pagetitle', true) . '" />';
+				$buttons['new'] = '<input type="image" class="c-inputButton" name="createExtension" value="New"' . t3lib_iconWorks::skinImg($GLOBALS['BACK_PATH'], 'gfx/new_el.gif', '') . ' title="' . $GLOBALS['LANG']->sL('LLL:EXT:lang/locallang_core.php:db_new.php.pagetitle', TRUE) . '" />';
 
 				if (!empty($this->e) && !t3lib_div::_POST('abort') && !t3lib_div::_POST('saveclose')) {
 						// no NEW-button while edit
 					$buttons['new'] = '';
 
 						// SAVE button
-					$buttons['save'] = '<input type="image" class="c-inputButton" name="submit" value="Update"' . t3lib_iconWorks::skinImg($GLOBALS['BACK_PATH'], 'gfx/savedok.gif', '') . ' title="' . $GLOBALS['LANG']->sL('LLL:EXT:lang/locallang_core.php:rm.saveDoc', true) . '" />';
+					$buttons['save'] = t3lib_iconWorks::getSpriteIcon('actions-document-save',
+						array(
+							'html' => '<input type="image" class="c-inputButton" name="submit" src="clear.gif" ' .
+								'title="'. $GLOBALS['LANG']->sL('LLL:EXT:lang/locallang_core.php:rm.saveDoc', TRUE) .'" ' .
+								'value="'. $GLOBALS['LANG']->sL('LLL:EXT:lang/locallang_core.php:rm.saveDoc', TRUE) .'" ' .
+								'/>'
+						));
 
 						// SAVE AND CLOSE button
-					$buttons['save_close'] = '<input type="image" class="c-inputButton" name="saveclose" value="Save and close"' . t3lib_iconWorks::skinImg($GLOBALS['BACK_PATH'], 'gfx/saveandclosedok.gif', '') . ' title="' . $GLOBALS['LANG']->sL('LLL:EXT:lang/locallang_core.php:rm.saveCloseDoc', true) . '" />';
+					$buttons['save_close'] = t3lib_iconWorks::getSpriteIcon('actions-document-save-close',
+						array(
+							'html' => '<input type="image" class="c-inputButton" name="saveclose" src="clear.gif" '.
+								'title="' . $GLOBALS['LANG']->sL('LLL:EXT:lang/locallang_core.php:rm.saveCloseDoc', TRUE) . '" ' .
+								'value="' . $GLOBALS['LANG']->sL('LLL:EXT:lang/locallang_core.php:rm.saveCloseDoc', TRUE) . '" ' .
+								'/>'
+						));
 
 						// CLOSE button
-					$buttons['close'] = '<input type="image" class="c-inputButton" name="abort" value="Abort"' . t3lib_iconWorks::skinImg($GLOBALS['BACK_PATH'], 'gfx/closedok.gif', '') . ' title="' . $GLOBALS['LANG']->sL('LLL:EXT:lang/locallang_core.php:rm.closeDoc', true) . '" />';
+					$buttons['close'] = t3lib_iconWorks::getSpriteIcon('actions-document-close',
+						array(
+							'html' => '<input type="image" class="c-inputButton" name="abort" src="clear.gif" ' .
+								'title="' . $GLOBALS['LANG']->sL('LLL:EXT:lang/locallang_core.php:rm.closeDoc', TRUE) . '" ' .
+								'value="' . $GLOBALS['LANG']->sL('LLL:EXT:lang/locallang_core.php:rm.closeDoc', TRUE) . '" ' .
+								'/>'
+						));
 
 				}
 			} elseif($this->extClassConf['name'] == 'tx_tstemplateceditor' && count($this->MOD_MENU['constant_editor_cat'])) {
 					// SAVE button
-				$buttons['save'] = '<input type="image" class="c-inputButton" name="submit" value="Update"' . t3lib_iconWorks::skinImg($GLOBALS['BACK_PATH'], 'gfx/savedok.gif', '') . ' title="' . $GLOBALS['LANG']->sL('LLL:EXT:lang/locallang_core.php:rm.saveDoc', true) . '" />';
+				$buttons['save'] = t3lib_iconWorks::getSpriteIcon('actions-document-save',
+					array('html' => '<input type="image" class="c-inputButton" name="submit" src="clear.gif" '.
+						'title="' . $GLOBALS['LANG']->sL('LLL:EXT:lang/locallang_core.php:rm.saveDoc', TRUE) . '" ' .
+						'value="' . $GLOBALS['LANG']->sL('LLL:EXT:lang/locallang_core.php:rm.saveDoc', TRUE) . '" ' .
+						'/>'));
 			} elseif($this->extClassConf['name'] == 'tx_tstemplateobjbrowser') {
 				if(!empty($this->sObj)) {
 						// BACK
-					$buttons['back'] = '<a href="index.php?id=' . $this->id . '" class="typo3-goBack">' .
-									'<img' . t3lib_iconWorks::skinImg($GLOBALS['BACK_PATH'], 'gfx/goback.gif') . ' title="' . $GLOBALS['LANG']->sL('LLL:EXT:lang/locallang_core.php:labels.goBack', true) . '" alt="" />' .
-									'</a>';
+					$buttons['back'] = '<a href="index.php?id=' . $this->id . '" class="typo3-goBack" title="' . $GLOBALS['LANG']->sL('LLL:EXT:lang/locallang_core.php:labels.goBack', TRUE) . '">' .
+									t3lib_iconWorks::getSpriteIcon('actions-view-go-back') .
+								'</a>';
 				}
 			}
 
@@ -308,35 +335,11 @@ class SC_mod_web_ts_index extends t3lib_SCbase {
 	// OTHER FUNCTIONS:
 	// ***************************
 
-	/**
-	* Counts the records in the system cache_* tables and returns these values.
-	*
-	* @param boolean $humanReadable: Returns human readable string instead of an array
-	* @return mixed The number of records in cache_* tables as array or string
-	* @deprecated since TYPO3 4.2.0
-	*/
-	function getCountCacheTables($humanReadable) {
-		$out = array();
-
-		$out['cache_pages'] = $GLOBALS['TYPO3_DB']->exec_SELECTcountRows('id', 'cache_pages');
-		$out['cache_pagesection'] = $GLOBALS['TYPO3_DB']->exec_SELECTcountRows('id', 'cache_pagesection');
-		$out['cache_hash'] = $GLOBALS['TYPO3_DB']->exec_SELECTcountRows('id', 'cache_hash');
-
-		if ($humanReadable) {
-			$newOut = array();
-			foreach ($out as $k => $v) {
-				$newOut[] = $k . ":" . $v;
-			}
-			$out = implode(', ', $newOut);
-		}
-		return $out;
-	}
-
 	function linkWrapTemplateTitle($title, $onlyKey = '') {
 		if ($onlyKey) {
-			$title = '<a href="index.php?id=' . $GLOBALS['SOBE']->id . '&e[' . $onlyKey . ']=1&SET[function]=tx_tstemplateinfo">' . htmlspecialchars($title) . '</a>';
+			$title = '<a href="index.php?id=' . htmlspecialchars($GLOBALS['SOBE']->id . '&e[' . $onlyKey . ']=1&SET[function]=tx_tstemplateinfo') . '">' . htmlspecialchars($title) . '</a>';
 		} else {
-			$title = '<a href="index.php?id=' . $GLOBALS['SOBE']->id . '&e[constants]=1&e[config]=1&SET[function]=tx_tstemplateinfo">' . htmlspecialchars($title) . '</a>';
+			$title = '<a href="index.php?id=' . htmlspecialchars($GLOBALS['SOBE']->id . '&e[constants]=1&e[config]=1&SET[function]=tx_tstemplateinfo') . '">' . htmlspecialchars($title) . '</a>';
 		}
 		return $title;
 	}
@@ -345,46 +348,51 @@ class SC_mod_web_ts_index extends t3lib_SCbase {
 
 		$tmpl = t3lib_div::makeInstance('t3lib_tsparser_ext');	// Defined global here!
 		/* @var $tmpl t3lib_tsparser_ext */
-		$tmpl->tt_track = false;	// Do not log time-performance information
+		$tmpl->tt_track = FALSE;	// Do not log time-performance information
 		$tmpl->init();
 
-		$areYouSure = $GLOBALS['LANG']->getLL('areYouSure');
-		$confirm = ' onClick="return confirm(\'' . $areYouSure . '\');"';
+		$flashMessage = t3lib_div::makeInstance(
+			't3lib_FlashMessage',
+			$GLOBALS['LANG']->getLL('noTemplateDescription') . '<br />' . $GLOBALS['LANG']->getLL('createTemplateToEditConfiguration'),
+			$GLOBALS['LANG']->getLL('noTemplate'),
+			t3lib_FlashMessage::INFO
+		);
+		$theOutput .= $flashMessage->render();
 
-			// No template
-		$theOutput .= $this->doc->spacer(10);
-		$theOutput .= $this->doc->section('<span class="typo3-red">' . $GLOBALS['LANG']->getLL('noTemplate') . '</span>', $GLOBALS['LANG']->getLL('noTemplateDescription') . '<br />
-			' . $GLOBALS['LANG']->getLL('createTemplate'), 0, 0, 0, 1);
 
 			// New standard?
 		if ($newStandardTemplate) {
-			$res = $GLOBALS['TYPO3_DB']->exec_SELECTquery('title,uid', 'static_template', '', '', 'title');
-			$opt = '';
-			while ($row = $GLOBALS['TYPO3_DB']->sql_fetch_assoc($res)) {
-				if (substr(trim($row['title']), 0, 8) == 'template') {
-					$opt .= '<option value="' . $row['uid'] . '">' . htmlspecialchars($row['title']) . '</option>';
-				}
-			}
-			$selector = '<select name="createStandard"><option></option>' . $opt . '</select>';
+			if (t3lib_extMgm::isLoaded('statictemplates')) { // check wether statictemplates are supported
+				$res = $GLOBALS['TYPO3_DB']->exec_SELECTquery('title,uid', 'static_template', '', '', 'title');
+				$opt = '';
+				while ($row = $GLOBALS['TYPO3_DB']->sql_fetch_assoc($res)) {
+					if (substr(trim($row['title']), 0, 8) == 'template') {
+						$opt .= '<option value="' . $row['uid'] . '">' . htmlspecialchars($row['title']) . '</option>';
+					}
+ 				}
+				$selector = '<select name="createStandard"><option></option>' . $opt . '</select><br />';
+				$staticsText = ', optionally based on one of the standard templates';
+			} else {
+				$selector = '<input type="hidden" name="createStandard" value="" />';
+				$staticsText = '';
+ 			}
 
 				// Extension?
-			$theOutput .= $this->doc->spacer(10);
-			$theOutput .= $this->doc->section($GLOBALS['LANG']->getLL('newWebsite'), $GLOBALS['LANG']->getLL('newWebsiteDescription') . '<br />
-			<br />' .
-			$selector . '<br />
-			<img' . t3lib_iconWorks::skinImg($GLOBALS['BACK_PATH'], 'gfx/icon_warning.gif', 'width="18" height="16"') . ' hspace="5" align="top">
-			<input type="Submit" name="newWebsite" value="' . $GLOBALS['LANG']->getLL('newWebsiteAction') . '"' . $confirm . '>', 0, 1);
+			$theOutput .= $this->doc->section($GLOBALS['LANG']->getLL('newWebsite') . $staticsText, $GLOBALS['LANG']->getLL('newWebsiteDescription') . '<br /><br />' .
+			$selector .
+			'<input type="Submit" name="newWebsite" value="' . $GLOBALS['LANG']->getLL('newWebsiteAction') . '" />', 0, 1);
 		}
 			// Extension?
 		$theOutput .= $this->doc->spacer(10);
-		$theOutput .= $this->doc->section($GLOBALS['LANG']->getLL('extTemplate'), $GLOBALS['LANG']->getLL('extTemplateDescription') . '<BR><BR><img' . t3lib_iconWorks::skinImg($GLOBALS['BACK_PATH'], 'gfx/icon_warning.gif', 'width="18" height="16"') . ' hspace="5" align="top"><input type="submit" name="createExtension" value="' . $GLOBALS['LANG']->getLL('extTemplateAction') . '"' . $confirm . '>', 0, 1);
+		$theOutput .= $this->doc->section($GLOBALS['LANG']->getLL('extTemplate'), $GLOBALS['LANG']->getLL('extTemplateDescription') . '<br /><br />' .
+			'<input type="submit" name="createExtension" value="' . $GLOBALS['LANG']->getLL('extTemplateAction') . '" />', 0, 1);
 
 			// Go to first appearing...
 		$first = $tmpl->ext_prevPageWithTemplate($this->id, $this->perms_clause);
 		if ($first) {
 			$theOutput .= $this->doc->spacer(10);
 			$theOutput .= $this->doc->section($GLOBALS['LANG']->getLL('goToClosest'),
-					sprintf($GLOBALS['LANG']->getLL('goToClosestDescription') . '<br /><br />%s<strong>' . $GLOBALS['LANG']->getLL('goToClosestAction') . '</strong>%s', $first['title'], $first['uid'],
+					sprintf($GLOBALS['LANG']->getLL('goToClosestDescription') . '<br /><br />%s<strong>' . $GLOBALS['LANG']->getLL('goToClosestAction') . '</strong>%s', htmlspecialchars($first['title']), $first['uid'],
 					'<a href="index.php?id=' . $first['uid'] . '">', '</a>'), 0, 1);
 		}
 		return $theOutput;
@@ -393,7 +401,7 @@ class SC_mod_web_ts_index extends t3lib_SCbase {
 	function templateMenu() {
 		$tmpl = t3lib_div::makeInstance('t3lib_tsparser_ext');	// Defined global here!
 		/* @var $tmpl t3lib_tsparser_ext */
-		$tmpl->tt_track = false;	// Do not log time-performance information
+		$tmpl->tt_track = FALSE;	// Do not log time-performance information
 		$tmpl->init();
 		$all = $tmpl->ext_getAllTemplates($this->id, $this->perms_clause);
 		$menu = '';
@@ -412,7 +420,7 @@ class SC_mod_web_ts_index extends t3lib_SCbase {
 	}
 
 	function createTemplate($id, $actTemplateId = 0) {
-		if (t3lib_div::_GP('createExtension')) {
+		if (t3lib_div::_GP('createExtension') || t3lib_div::_GP('createExtension_x')) {
 			$tce = t3lib_div::makeInstance('t3lib_TCEmain');
 			/* @var $tce t3lib_TCEmain */
 			$tce->stripslashes_values = 0;
@@ -473,7 +481,7 @@ page.10.value = HELLO WORLD!
 		}
 
 		$cEl = current($rlArr);
-		$pArray[$cEl['uid']] = $cEl['title'];
+		$pArray[$cEl['uid']] = htmlspecialchars($cEl['title']);
 		array_shift($rlArr);
 		if (count($rlArr)) {
 			if (!isset($pArray[$cEl['uid'] . '.'])) {
@@ -490,25 +498,23 @@ page.10.value = HELLO WORLD!
 			reset($pArray);
 			static $i;
 			foreach ($pArray as $k => $v) {
-				if (t3lib_div::testInt($k)) {
+				if (t3lib_utility_Math::canBeInterpretedAsInteger($k)) {
 					if (isset($pArray[$k . "_"])) {
 						$lines[] = '<tr class="' . ($i++ % 2 == 0 ? 'bgColor4' : 'bgColor6') . '">
 							<td nowrap><img src="clear.gif" width="1" height="1" hspace=' . ($c * 10) . ' align="top">' .
 							'<a href="' . t3lib_div::linkThisScript(array('id' => $k)) . '">' .
-							t3lib_iconWorks::getIconImage('pages', t3lib_BEfunc::getRecordWSOL('pages', $k), $GLOBALS['BACK_PATH'], ' align="top" title="ID: ' . $k . '"') .
+							t3lib_iconWorks::getSpriteIconForRecord('pages', t3lib_BEfunc::getRecordWSOL('pages', $k), array("title"=>'ID: ' . $k )) .
 							t3lib_div::fixed_lgd_cs($pArray[$k], 30) . '</a></td>
 							<td align="center">' . $pArray[$k . '_']['count'] . '</td>
-							<td align="center" class="bgColor5">' . ($pArray[$k . '_']['root_max_val'] > 0 ? '<img' .
-							t3lib_iconWorks::skinImg($GLOBALS['BACK_PATH'], 'gfx/perm-allowed.gif', 'width="10" height="9"') . ' align="top" alt="" />' : "&nbsp;") .
+							<td align="center" class="bgColor5">' . ($pArray[$k . '_']['root_max_val'] > 0 ? t3lib_iconWorks::getSpriteIcon('status-status-checked') : "&nbsp;") .
 							'</td>
-							<td align="center">' . ($pArray[$k . '_']['root_min_val'] == 0 ? '<img' .
-							t3lib_iconWorks::skinImg($GLOBALS['BACK_PATH'], 'gfx/perm-allowed.gif', 'width="10" height="9"') . ' align="top" alt="" />' : "&nbsp;") .
+							<td align="center">' . ($pArray[$k . '_']['root_min_val'] == 0 ? t3lib_iconWorks::getSpriteIcon('status-status-checked') : "&nbsp;") .
 							'</td>
 							</tr>';
-					} else {
-						$lines[] = '<tr class="' . ($i++ % 2 == 0 ? 'bgColor4' : 'bgColor6') . '">
+						} else {
+							$lines[] = '<tr class="' . ($i++ % 2 == 0 ? 'bgColor4' : 'bgColor6') . '">
 							<td nowrap ><img src="clear.gif" width="1" height="1" hspace=' . ($c * 10) . ' align=top>' .
-							t3lib_iconWorks::getIconImage('pages', t3lib_BEfunc::getRecordWSOL('pages', $k), $GLOBALS['BACK_PATH'], ' align="top"') .
+							t3lib_iconWorks::getSpriteIconForRecord('pages', t3lib_BEfunc::getRecordWSOL('pages', $k)) .
 							t3lib_div::fixed_lgd_cs($pArray[$k], 30) . '</td>
 							<td align="center"></td>
 							<td align="center" class="bgColor5"></td>
@@ -524,8 +530,8 @@ page.10.value = HELLO WORLD!
 }
 
 
-if (defined('TYPO3_MODE') && $TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/tstemplate/ts/index.php']) {
-	include_once($TYPO3_CONF_VARS[TYPO3_MODE]['XCLASS']['ext/tstemplate/ts/index.php']);
+if (defined('TYPO3_MODE') && isset($GLOBALS['TYPO3_CONF_VARS'][TYPO3_MODE]['XCLASS']['ext/tstemplate/ts/index.php'])) {
+	include_once($GLOBALS['TYPO3_CONF_VARS'][TYPO3_MODE]['XCLASS']['ext/tstemplate/ts/index.php']);
 }
 
 
@@ -545,4 +551,4 @@ $SOBE->clearCache();
 $SOBE->main();
 $SOBE->printContent();
 
-?>
\ No newline at end of file
+?>
