@@ -1,13 +1,13 @@
 <?php
 
 ########################################################################
-# Extension Manager/Repository config file for ext: "tstemplate_info"
+# Extension Manager/Repository config file for ext "tstemplate_info".
 #
-# Auto generated 23-04-2008 10:54
+# Auto generated 22-05-2012 11:30
 #
 # Manual updates:
-# Only the data in the array - anything else is removed by next write.
-# "version" and "dependencies" must not be touched!
+# Only the data in the array - everything else is removed by next
+# writing. "version" and "dependencies" must not be touched!
 ########################################################################
 
 $EM_CONF[$_EXTKEY] = array(
@@ -20,6 +20,7 @@ $EM_CONF[$_EXTKEY] = array(
 	'priority' => '',
 	'loadOrder' => '',
 	'module' => '',
+	'doNotLoadInFE' => 1,
 	'state' => 'stable',
 	'internal' => 0,
 	'uploadfolder' => 0,
@@ -32,19 +33,21 @@ $EM_CONF[$_EXTKEY] = array(
 	'author_company' => 'Curby Soft Multimedia',
 	'CGLcompliance' => '',
 	'CGLcompliance_note' => '',
-	'version' => '0.1.0',
-	'_md5_values_when_last_written' => 'a:4:{s:9:"ChangeLog";s:4:"4105";s:27:"class.tx_tstemplateinfo.php";s:4:"9888";s:12:"ext_icon.gif";s:4:"ecbc";s:14:"ext_tables.php";s:4:"f4b1";}',
+	'version' => '4.7.1',
+	'_md5_values_when_last_written' => 'a:5:{s:9:"ChangeLog";s:4:"4105";s:27:"class.tx_tstemplateinfo.php";s:4:"2682";s:12:"ext_icon.gif";s:4:"a332";s:14:"ext_tables.php";s:4:"d827";s:13:"locallang.xlf";s:4:"194c";}',
 	'constraints' => array(
 		'depends' => array(
+			'php' => '5.3.0-0.0.0',
+			'typo3' => '4.7.0-0.0.0',
 			'tstemplate' => '',
-			'php' => '5.1.0-0.0.0',
-			'typo3' => '4.2.0-4.2.99',
 		),
 		'conflicts' => array(
 		),
 		'suggests' => array(
 		),
 	),
+	'suggests' => array(
+	),
 );
 
 ?>
\ No newline at end of file
