@@ -1,13 +1,13 @@
 <?php
 
 ########################################################################
-# Extension Manager/Repository config file for ext: "wizard_sortpages"
+# Extension Manager/Repository config file for ext "wizard_sortpages".
 #
-# Auto generated 23-04-2008 10:58
+# Auto generated 22-05-2012 11:30
 #
 # Manual updates:
-# Only the data in the array - anything else is removed by next write.
-# "version" and "dependencies" must not be touched!
+# Only the data in the array - everything else is removed by next
+# writing. "version" and "dependencies" must not be touched!
 ########################################################################
 
 $EM_CONF[$_EXTKEY] = array(
@@ -19,6 +19,7 @@ $EM_CONF[$_EXTKEY] = array(
 	'conflicts' => '',
 	'priority' => '',
 	'module' => '',
+	'doNotLoadInFE' => 1,
 	'state' => 'stable',
 	'internal' => 0,
 	'uploadfolder' => 0,
@@ -29,19 +30,21 @@ $EM_CONF[$_EXTKEY] = array(
 	'author' => 'Kasper Skaarhoj',
 	'author_email' => 'kasperYYYY@typo3.com',
 	'author_company' => 'Curby Soft Multimedia',
-	'version' => '0.1.0',
-	'_md5_values_when_last_written' => 'a:6:{s:38:"class.tx_wizardsortpages_webfunc_2.php";s:4:"d080";s:12:"ext_icon.gif";s:4:"d638";s:14:"ext_tables.php";s:4:"f74d";s:13:"locallang.xml";s:4:"4ca6";s:17:"locallang_csh.xml";s:4:"6194";s:23:"cshimages/wizards_1.png";s:4:"1ac8";}',
+	'version' => '4.7.1',
+	'_md5_values_when_last_written' => 'a:6:{s:38:"class.tx_wizardsortpages_webfunc_2.php";s:4:"5d98";s:12:"ext_icon.gif";s:4:"6751";s:14:"ext_tables.php";s:4:"f74d";s:13:"locallang.xlf";s:4:"ffb1";s:17:"locallang_csh.xlf";s:4:"cac8";s:23:"cshimages/wizards_1.png";s:4:"44a0";}',
 	'constraints' => array(
 		'depends' => array(
+			'php' => '5.3.0-0.0.0',
+			'typo3' => '4.7.0-0.0.0',
 			'func_wizards' => '',
-			'php' => '5.1.0-0.0.0',
-			'typo3' => '4.2.0-4.2.99',
 		),
 		'conflicts' => array(
 		),
 		'suggests' => array(
 		),
 	),
+	'suggests' => array(
+	),
 );
 
 ?>
\ No newline at end of file
